@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* BzfJoystick:
@@ -43,9 +43,9 @@ class BzfJoystick {
     virtual void	setXAxis(const std::string axis);
     virtual void	setYAxis(const std::string axis);
 
-    /* Force feedback support. Currently we only support 'rumble' force
-     * feedback- a motor in the controller vibrates it, as tactile feedback
-     * for explosions, collisions, engines starting, death, that sort of thing.
+    /* Rumble force feedback support - a motor in the controller vibrates it,
+     * as tactile feedback for explosions, collisions, engines starting, death,
+     * that sort of thing.
      *
      * A device that supports rumble will return true from ffHasRumble(),
      * and ffRumble() will start playing a force feedback effect. For devices
@@ -67,6 +67,38 @@ class BzfJoystick {
     virtual void	ffRumble(int count,
 				 float delay, float duration,
 				 float strong_motor, float weak_motor=0.0f);
+
+    /* Directional force feedback support - the controller pulls or pushes in
+     * a certain direction with a certain amount of force.
+     *
+     * Currently this is fairly complete, basically we support most types of
+     * periodic effects, resistance forces, and constant forces.  Compound effects,
+     * ramped forces, and enveloped effects are not supported at this time.
+     */
+    enum PeriodicType {
+      FF_Sine = 0,
+      FF_Square,
+      FF_Triangle,
+      FF_SawtoothUp,
+      FF_SawtoothDown
+    };
+    enum ResistanceType {
+      FF_Position = 0,
+      FF_Velocity,
+      FF_Acceleration
+    };
+    virtual bool	ffHasDirectional() const;
+    virtual void	ffDirectionalConstant(int count,
+					      float delay, float duration,
+					      float x_direction, float y_direction,
+					      float strength);
+    virtual void	ffDirectionalPeriodic(int count,
+					      float delay, float duration,
+					      float x_direction, float y_direction,
+					      float amplitude, float period,
+					      PeriodicType type);
+    virtual void	ffDirectionalResistance(float time, float coefficient,
+						float saturation, ResistanceType type);
 };
 
 #endif // BZF_JOYSTICK_H
