@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -96,11 +96,13 @@ class MeshObstacle : public Obstacle {
     const fvec3 *getVertices() const;
     const fvec3 *getNormals() const;
     const fvec2 *getTexcoords() const;
-    const int getVertexCount() const;
-    const int getNormalCount() const;
-    const int getTexcoordCount() const;
+    int getVertexCount() const;
+    int getNormalCount() const;
+    int getTexcoordCount() const;
     int getFaceCount() const;
     const MeshFace* getFace(int face) const;
+    const float* getPosition() const;
+    const float* getSize() const;
     bool useSmoothBounce() const;
     bool noClusters() const;
 
@@ -170,17 +172,17 @@ inline const fvec2 *MeshObstacle::getTexcoords() const
   return texcoords;
 }
 
-inline const int MeshObstacle::getVertexCount() const
+inline int MeshObstacle::getVertexCount() const
 {
   return vertexCount;
 }
 
-inline const int MeshObstacle::getNormalCount() const
+inline int MeshObstacle::getNormalCount() const
 {
   return normalCount;
 }
 
-inline const int MeshObstacle::getTexcoordCount() const
+inline int MeshObstacle::getTexcoordCount() const
 {
   return texcoordCount;
 }
@@ -195,6 +197,16 @@ inline const MeshFace* MeshObstacle::getFace(int face) const
   return faces[face];
 }
 
+inline const float* MeshObstacle::getPosition() const
+{
+  return pos;
+}
+
+inline const float* MeshObstacle::getSize() const
+{
+  return size;
+}
+
 inline bool MeshObstacle::useSmoothBounce() const
 {
   return smoothBounce;
