@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -38,7 +38,7 @@ class OpenGLLight {
     const GLfloat*	getPosition() const;
     const GLfloat*	getColor() const;
     const GLfloat*	getAttenuation() const;
-    const GLfloat	getMaxDist() const;
+    GLfloat		getMaxDist() const;
 
     void		setDirection(const GLfloat* xyz);
     void		setPosition(const GLfloat* xyz);
@@ -100,7 +100,7 @@ inline const GLfloat*	OpenGLLight::getAttenuation() const
   return atten;
 }
 
-inline const GLfloat	OpenGLLight::getMaxDist() const
+inline GLfloat		OpenGLLight::getMaxDist() const
 {
   return maxDist;
 }
