@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* OpenGLTexture:
@@ -76,6 +76,13 @@ class OpenGLTexture {
     Filter		getFilter();
     void		setFilter(Filter);
 
+    bool		getColorAverages(float rgbaRaw[4],
+					 bool factorAlpha) const;
+
+    void		freeContext();
+    void		initContext();
+
+
     static int		getFilterCount();
     static const char*	getFilterName(Filter id);
     static const char**	getFilterNames();
@@ -83,10 +90,6 @@ class OpenGLTexture {
     static Filter	getMaxFilter();
     static void		setMaxFilter(Filter);
 
-
-    void		freeContext();
-    void		initContext();
-
   private:
 			OpenGLTexture(const OpenGLTexture&);
     OpenGLTexture&	operator=(const OpenGLTexture&);
