@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* RenderNode:
@@ -24,6 +24,7 @@
 #include "common.h"
 #include "OpenGLGState.h"
 
+
 class RenderNode {
   public:
 			RenderNode() { }
@@ -31,9 +32,32 @@ class RenderNode {
 
     virtual void	render() = 0;
     virtual void	renderShadow() { render(); }
+    virtual void	renderRadar() { renderShadow(); }
     virtual const GLfloat* getPosition() const = 0;
+
+    static int		getTriangleCount();
+    static void		resetTriangleCount();
+
+  protected:
+    static void		addTriangleCount(int triCount);
+
+  private:
+    static int		triangleCount;
 };
 
+
+inline void RenderNode::addTriangleCount(int count)
+{
+  triangleCount += count;
+  return;
+}
+
+// do not tally unless debugging (for now)
+#ifndef DEBUG_RENDERING
+#  define addTriangleCount(x)
+#endif
+
+
 class RenderNodeList {
   public:
 			RenderNodeList();
@@ -65,7 +89,6 @@ inline void RenderNodeList::append(RenderNode* node)
 }
 
 
-
 class RenderNodeGStateList {
   public:
 			RenderNodeGStateList();
