@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef BZF_STATE_DATABASE_H
@@ -143,6 +143,11 @@ public:
    */
   std::string			get(const std::string& name) const;
 
+  /** get the INT value associated with a name. Clamp value within range.
+   *  Returns 0 (or min) if value is not set.
+   */
+  int	getIntClamped(const std::string& name, const int min, const int max) const;
+
   /** returns the pointer stored with a name.  returns NULL if the
    * name isn't set.
    */
@@ -191,10 +196,14 @@ public:
    */
   bool			  getDebug() const;
 
+ // true if we are in a mode where we are seting values that are to be defaults ( config and world time )
+  void			  setSaveDefault(bool save);
+  bool			  getSaveDefault() const;
 
   static const std::string	BZDB_AGILITYADVEL;
   static const std::string	BZDB_AGILITYTIMEWINDOW;
   static const std::string	BZDB_AGILITYVELDELTA;
+  static const std::string	BZDB_AMBIENTLIGHT;
   static const std::string	BZDB_ANGLETOLERANCE;
   static const std::string	BZDB_ANGULARAD;
   static const std::string	BZDB_AVENUESIZE;
@@ -206,10 +215,17 @@ public:
   static const std::string	BZDB_BURROWANGULARAD;
   static const std::string	BZDB_COLDETDEPTH;
   static const std::string	BZDB_COLDETELEMENTS;
+  static const std::string	BZDB_COUNTDOWNRESDELAY;
   static const std::string	BZDB_CULLDEPTH;
   static const std::string	BZDB_CULLELEMENTS;
   static const std::string	BZDB_CULLOCCLUDERS;
   static const std::string	BZDB_DISABLEBOTS;
+  static const std::string	BZDB_DRAWCELESTIAL;
+  static const std::string	BZDB_DRAWCLOUDS;
+  static const std::string	BZDB_DRAWGROUND;
+  static const std::string	BZDB_DRAWGROUNDLIGHTS;
+  static const std::string	BZDB_DRAWMOUNTAINS;
+  static const std::string	BZDB_DRAWSKY;
   static const std::string	BZDB_ENDSHOTDETECTION;
   static const std::string	BZDB_EXPLODETIME;
   static const std::string	BZDB_FLAGALTITUDE;
@@ -218,6 +234,11 @@ public:
   static const std::string	BZDB_FLAGPOLEWIDTH;
   static const std::string	BZDB_FLAGPOLESIZE;
   static const std::string	BZDB_FLAGRADIUS;
+  static const std::string	BZDB_FOGMODE;
+  static const std::string	BZDB_FOGDENSITY;
+  static const std::string	BZDB_FOGSTART;
+  static const std::string	BZDB_FOGEND;
+  static const std::string	BZDB_FOGCOLOR;
   static const std::string	BZDB_GMACTIVATIONTIME;
   static const std::string	BZDB_GMADLIFE;
   static const std::string	BZDB_GMTURNANGLE;
@@ -274,6 +295,7 @@ public:
   static const std::string	BZDB_SHOTSKEEPVERTICALV;
   static const std::string	BZDB_SQUISHFACTOR;
   static const std::string	BZDB_SQUISHTIME;
+  static const std::string	BZDB_SPEEDCHECKSLOGONLY;
   static const std::string	BZDB_SRRADIUSMULT;
   static const std::string	BZDB_SYNCLOCATION;
   static const std::string	BZDB_SYNCTIME;
@@ -384,6 +406,7 @@ private:
   typedef std::map<std::string,float> EvalMap;
   EvalMap			evalCache;
   bool			  debug;
+  bool			  saveDefault;
 };
 
 inline bool StateDatabase::getDebug() const
@@ -391,6 +414,12 @@ inline bool StateDatabase::getDebug() const
   return debug;
 }
 
+inline bool StateDatabase::getSaveDefault() const
+{
+  return saveDefault;
+}
+
+
 std::istream& operator >> (std::istream& src, StateDatabase::Expression& dst);
 std::string& operator >> (std::string& src, StateDatabase::Expression& dst);
 std::ostream& operator << (std::ostream& dst, const StateDatabase::Expression& src);
