@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* TankGeometryMgr:
@@ -84,12 +84,23 @@ namespace TankGeometryMgr {
 		     TankGeometryEnums::TankSize size,
 		     TankGeometryEnums::TankLOD lod);
 
+  int getPartTriangleCount(TankGeometryEnums::TankShadow shadow,
+			   TankGeometryEnums::TankPart part,
+			   TankGeometryEnums::TankSize size,
+			   TankGeometryEnums::TankLOD lod);
+
   const float* getScaleFactor(TankGeometryEnums::TankSize size);
 }
 
 
 namespace TankGeometryUtils {
 
+  enum TreadStyle {
+    Covered = 0,
+    Exposed = 1
+  };
+  void setTreadStyle(int style);
+
   // degrees / meter
   float getWheelScale();
   // texcoords / meter
@@ -102,34 +113,38 @@ namespace TankGeometryUtils {
   void doNormal3f(GLfloat x, GLfloat y, GLfloat z);
   void doTexCoord2f(GLfloat x, GLfloat y);
 
+  //
+  // NOTE:  these all return their triangle count
+  //
+
   // lowtank geometry builder
-  void buildLowBody (void);
-  void buildLowTurret (void);
-  void buildLowLCasing (void);
-  void buildLowRCasing (void);
-  void buildLowBarrel (void);
+  int buildLowBody (void);
+  int buildLowTurret (void);
+  int buildLowLCasing (void);
+  int buildLowRCasing (void);
+  int buildLowBarrel (void);
 
   // medtank geometry builder
-  void buildMedBody (void);
-  void buildMedTurret (void);
-  void buildMedLCasing (void);
-  void buildMedRCasing (void);
-  void buildMedBarrel (void);
+  int buildMedBody (void);
+  int buildMedTurret (void);
+  int buildMedLCasing (void);
+  int buildMedRCasing (void);
+  int buildMedBarrel (void);
 
   // hightank geometry builder
-  void buildHighBody (void);
-  void buildHighBarrel (void);
-  void buildHighTurret (void);
-  void buildHighLCasing (void);
-  void buildHighRCasing (void);
+  int buildHighBody (void);
+  int buildHighBarrel (void);
+  int buildHighTurret (void);
+  int buildHighLCasing (void);
+  int buildHighRCasing (void);
 
   // animated geometry builder
-  void buildHighLCasingAnim (void);
-  void buildHighRCasingAnim (void);
-  void buildHighLTread (int divs);
-  void buildHighRTread (int divs);
-  void buildHighLWheel (int wheel, float angle, int divs);
-  void buildHighRWheel (int wheel, float angle, int divs);
+  int buildHighLCasingAnim (void);
+  int buildHighRCasingAnim (void);
+  int buildHighLTread (int divs);
+  int buildHighRTread (int divs);
+  int buildHighLWheel (int wheel, float angle, int divs);
+  int buildHighRWheel (int wheel, float angle, int divs);
 }
 
 
