@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -33,7 +33,7 @@ struct Team {
 
     static const std::string  getImagePrefix(TeamColor); // const
     static const char*	getName(TeamColor); // const
-    static const TeamColor	getTeam(const std::string name); // const
+    static TeamColor	getTeam(const std::string name); // const
     static const float*	getTankColor(TeamColor); // const
     static const float*	getRadarColor(TeamColor team, bool rabbitMode = false); // const
     static bool	isColorTeam(TeamColor); // const
@@ -53,6 +53,7 @@ struct Team {
 	static float	hunterRadarColor[3];
 };
 
+
 #endif // BZF_TEAM_H
 
 // Local Variables: ***
