@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,13 +7,15 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef _TEXTURE_MATRIX_H_
 #define _TEXTURE_MATRIX_H_
 
+#include "common.h"
 
+/* system interface headers */
 #include <string>
 #include <vector>
 #include <iostream>
@@ -42,7 +44,7 @@ class TextureMatrix {
 			  float uSize, float vSize);
     void setDynamicCenter (float u, float v);
 
-    void update(float time);
+    void update(double time);
     const std::string& getName() const;
 
     int packSize() const;
@@ -100,3 +102,12 @@ class TextureMatrixManager {
 extern TextureMatrixManager TEXMATRIXMGR;
 
 #endif //_TEXTURE_MATRIX_H_
+
+// Local Variables: ***
+// mode:C++ ***
+// tab-width: 8 ***
+// c-basic-offset: 2 ***
+// indent-tabs-mode: t ***
+// End: ***
+// ex: shiftwidth=2 tabstop=8
+
