@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -89,7 +89,7 @@ public:
 
   /** converts a time difference into an array of integers
       representing days, hours, minutes, seconds */
-  static const void		convertTime(double raw, long int convertedTimes[]);
+  static void			convertTime(double raw, long int convertedTimes[]);
   /** prints an integer-array time difference in human-readable form */
   static const std::string	printTime(long int timeValue[]);
   /** prints an float time difference in human-readable form */
