@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef __WORDFILTER_H__
@@ -27,14 +27,6 @@
 #include <ctype.h>
 #include <sys/types.h>
 
-#ifdef BUILD_REGEX
-#  include "regex.h"
-#elif defined(HAVE_REGEX_H)
-#  include <regex.h>
-#else
-#  define regex_t void
-#endif
-
 /* common interface headers */
 #include "TextUtils.h"
 
@@ -280,7 +272,7 @@ inline int WordFilter::filterCharacters(char *input, unsigned int start, size_t
 
 inline void WordFilter::appendUniqueChar(std::string& string, char c) const
 {
-#ifdef HAVE_STD_COUNT
+#ifdef HAVE_STD__COUNT
 // ISO standard std::count
   if (std::count(string.begin(), string.end(), c) == 0) {
     string += c;
