@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -40,12 +40,6 @@
 
 
 extern int debugLevel;
-/* Like verbose debug messages? level 0 for development only */
-#define DEBUG0 formatDebug
-#define DEBUG1 if (debugLevel >= 1) formatDebug
-#define DEBUG2 if (debugLevel >= 2) formatDebug
-#define DEBUG3 if (debugLevel >= 3) formatDebug
-#define DEBUG4 if (debugLevel >= 4) formatDebug
 
 /* near zero by some epsilon convenience define since relying on
 * the floating point unit for proper equivalence is not safe
@@ -212,12 +206,12 @@ typedef unsigned char	uint8_t;
 #  ifndef HAVE_ISNAN
 #    ifdef __cplusplus
 #      ifdef isnan
-#        undef isnan
+#	undef isnan
 #      endif
        template<typename Tp>
        inline int isnan(Tp f)
        {
-         return (f!=f);
+	 return (f!=f);
        }
 #    else
 #      define isnan(f) ((f) != (f))
