@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /*
@@ -17,14 +17,14 @@
 #ifndef __WIN32_H__
 #define	__WIN32_H__
 
-#ifdef __MINGW32__
-#include <windows.h>
-#endif
+#define _WINSOCKAPI_
 
+#include <windows.h>
+#include <float.h>
 
 // missing constants
 #ifndef MAXFLOAT
-#define	MAXFLOAT	3.402823466e+38f
+#define	MAXFLOAT	FLT_MAX
 #endif
 
 #if (_MSC_VER > 1200) // VC7 or higher
@@ -72,6 +72,11 @@ typedef unsigned int	uint32_t;
 
 #  define PATH_MAX	MAX_PATH
 
+  namespace std {
+    template<typename _Tp>
+    int isnan(_Tp __f) { return _isnan((double)__f); }
+  }
+
 #endif // _MSC_VER
 #endif // __WIN32_H__
 
