@@ -1,14 +1,14 @@
 /* bzflag
-* Copyright (c) 1993 - 2005 Tim Riker
-*
-* This package is free software;  you can redistribute it and/or
-* modify it under the terms of the license found in the file
-* named COPYING that should have accompanied this file.
-*
-* THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
-* IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
-* WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-*/
+ * Copyright (c) 1993 - 2008 Tim Riker
+ *
+ * This package is free software;  you can redistribute it and/or
+ * modify it under the terms of the license found in the file
+ * named COPYING that should have accompanied this file.
+ *
+ * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 // BZFlag common header
 #include "common.h"
@@ -19,6 +19,7 @@
 // System headers
 #include <math.h>
 #include <string>
+#include <string.h>
 
 // Global implementation headers
 #include "bzfgl.h"
@@ -39,8 +40,9 @@
 template <>
 FontManager* Singleton<FontManager>::_instance = (FontManager*)0;
 
+
 // ANSI code GLFloat equivalents - these should line up with the enums in AnsiCodes.h
-static GLfloat BrightColors[8][3] = {
+static GLfloat BrightColors[9][3] = {
   {1.0f,1.0f,0.0f}, // yellow
   {1.0f,0.0f,0.0f}, // red
   {0.0f,1.0f,0.0f}, // green
@@ -48,10 +50,11 @@ static GLfloat BrightColors[8][3] = {
   {1.0f,0.0f,1.0f}, // purple
   {1.0f,1.0f,1.0f}, // white
   {0.5f,0.5f,0.5f}, // grey
-  {0.0f,1.0f,1.0f}  // cyan
+  {0.0f,1.0f,1.0f}, // cyan
+  {1.0f,0.5f,0.0f}  // orange (nonstandard)
 };
 
-GLfloat FontManager::underlineColor[3];
+GLfloat FontManager::underlineColor[4];
 void FontManager::callback(const std::string &, void *)
 {
   // set underline color
@@ -71,7 +74,10 @@ void FontManager::callback(const std::string &, void *)
   }
 }
 
-FontManager::FontManager() : Singleton<FontManager>(), dimFactor(0.7f)
+FontManager::FontManager() : Singleton<FontManager>(),
+			     opacity(1.0f),
+			     dimFactor(0.2f),
+			     darkness(1.0f)
 {
   faceNames.clear();
   fontFaces.clear();
@@ -172,7 +178,7 @@ void FontManager::loadAll(std::string directory)
 
 	  fontFaces[faceID][pFont->getSize()] = pFont;
 	} else {
-	  DEBUG4("Font Texture load failed: %s\n", file.getOSName().c_str());
+	  logDebugMessage(4,"Font Texture load failed: %s\n", file.getOSName().c_str());
 	  delete(pFont);
 	}
       }
@@ -192,20 +198,20 @@ int FontManager::getFaceID(std::string faceName)
   int faceID = 0;
   if (faceItr == faceNames.end()) {
     // see if there is a default
-    DEBUG4("Requested font %s not found, trying Default\n", faceName.c_str());
+    logDebugMessage(4,"Requested font %s not found, trying Default\n", faceName.c_str());
     faceName = "DEFAULT";
     faceItr = faceNames.find(faceName);
     if (faceItr == faceNames.end()) {
       // see if we have arial
-      DEBUG4("Requested font %s not found, trying Arial\n", faceName.c_str());
+      logDebugMessage(4,"Requested font %s not found, trying Arial\n", faceName.c_str());
       faceName = "ARIAL";
       faceItr = faceNames.find(faceName);
       if (faceItr == faceNames.end()) {
 	// hell we are outta luck, you just get the first one
-	DEBUG4("Requested font %s not found, trying first-loaded\n", faceName.c_str());
+	logDebugMessage(4,"Requested font %s not found, trying first-loaded\n", faceName.c_str());
 	faceItr = faceNames.begin();
 	if (faceItr == faceNames.end()) {
-	  DEBUG2("No fonts loaded\n");
+	  logDebugMessage(2,"No fonts loaded\n");
 	  return -1;	// we must have NO fonts, so you are screwed no matter what
 	}
       }
@@ -223,7 +229,7 @@ int FontManager::getNumFaces(void)
 const char* FontManager::getFaceName(int faceID)
 {
   if ((faceID < 0) || (faceID > getNumFaces())) {
-    DEBUG2("Trying to fetch name for invalid Font Face ID %d\n", faceID);
+    logDebugMessage(2,"Trying to fetch name for invalid Font Face ID %d\n", faceID);
     return NULL;
   }
 
@@ -231,20 +237,20 @@ const char* FontManager::getFaceName(int faceID)
 }
 
 void FontManager::drawString(float x, float y, float z, int faceID, float size,
-			     const std::string &text)
+			     const std::string &text, const float* resetColor)
 {
   if (text.size() == 0)
     return;
 
   if ((faceID < 0) || (faceID > getNumFaces())) {
-    DEBUG2("Trying to draw with invalid Font Face ID %d\n", faceID);
+    logDebugMessage(2,"Trying to draw with invalid Font Face ID %d\n", faceID);
     return;
   }
 
   ImageFont* pFont = getClosestRealSize(faceID, size, size);
 
   if (!pFont) {
-    DEBUG2("Could not find applicable font size for rendering; font face ID %d, "
+    logDebugMessage(2,"Could not find applicable font size for rendering; font face ID %d, "
 	   "requested size %f\n", faceID, size);
     return;
   }
@@ -278,7 +284,26 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
   bool pulsating = false;
   bool underline = false;
   // negatives are invalid, we use them to signal "no change"
-  GLfloat color[3] = {-1.0f, -1.0f, -1.0f};
+  GLfloat color[4] = {-1.0f, -1.0f, -1.0f, opacity};
+  if (resetColor != NULL) {
+    color[0] = resetColor[0] * darkness;
+    color[1] = resetColor[1] * darkness;
+    color[2] = resetColor[2] * darkness;
+  } else {
+    resetColor = BrightColors[WhiteColor];
+  }
+
+  const float darkDim = dimFactor * darkness;
+
+  // underline color changes for bright == false
+  GLfloat dimUnderlineColor[4] = { underlineColor[0] * darkDim,
+				   underlineColor[1] * darkDim,
+				   underlineColor[2] * darkDim,
+				   opacity };
+  underlineColor[3] = opacity;
+
+  // FIXME - this should not be necessary, but the bitmap font renderer needs it
+  //  OpenGLGState::resetState();
 
   /*
    * ANSI code interpretation is somewhat limited, we only accept values
@@ -314,17 +339,26 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
       glDepthMask(0);
       pFont->drawString(scale, color, &tmpText[startSend], len);
       if (underline) {
-	OpenGLGState::resetState();  // FIXME - full reset required?
-	if (underlineColor[0] >= 0)
-	  glColor3fv(underlineColor);
-	else if (color[0] >= 0)
-	  glColor3fv(color);
+	if (canScale) {
+	  glDisable(GL_TEXTURE_2D);
+	}
+	glEnable(GL_BLEND);
+	if (bright && underlineColor[0] >= 0) {
+	  glColor4fv(underlineColor);
+	} else if (underlineColor[0] >= 0) {
+	  glColor4fv(dimUnderlineColor);
+	} else if (color[0] >= 0) {
+	  glColor4fv(color);
+	}
 	// still have a translated matrix, these coordinates are
 	// with respect to the string just drawn
 	glBegin(GL_LINES);
 	glVertex2f(0.0f, 0.0f);
 	glVertex2f(width, 0.0f);
 	glEnd();
+	if (canScale) {
+	  glEnable(GL_TEXTURE_2D);
+	}
       }
       glDepthMask(depthMask);
       glPopMatrix();
@@ -340,16 +374,16 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
       tookCareOfANSICode = false;
       std::string tmpText = text.substr(endSend, (text.find('m', endSend) - endSend) + 1);
       // colors
-      for (int i = 0; i < 8; i++) {
+      for (int i = 0; i <= LastColor; i++) {
 	if (tmpText == ColorStrings[i]) {
 	  if (bright) {
-	    color[0] = BrightColors[i][0];
-	    color[1] = BrightColors[i][1];
-	    color[2] = BrightColors[i][2];
+	    color[0] = BrightColors[i][0] * darkness;
+	    color[1] = BrightColors[i][1] * darkness;
+	    color[2] = BrightColors[i][2] * darkness;
 	  } else {
-	    color[0] = BrightColors[i][0] * dimFactor;
-	    color[1] = BrightColors[i][1] * dimFactor;
-	    color[2] = BrightColors[i][2] * dimFactor;
+	    color[0] = BrightColors[i][0] * darkDim;
+	    color[1] = BrightColors[i][1] * darkDim;
+	    color[2] = BrightColors[i][2] * darkDim;
 	  }
 	  tookCareOfANSICode = true;
 	  break;
@@ -362,16 +396,16 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
 	  bright = true;
 	  pulsating = false;
 	  underline = false;
-	  color[0] = BrightColors[WhiteColor][0];
-	  color[1] = BrightColors[WhiteColor][1];
-	  color[2] = BrightColors[WhiteColor][2];
+	  color[0] = resetColor[0] * darkness;
+	  color[1] = resetColor[1] * darkness;
+	  color[2] = resetColor[2] * darkness;
 	} else if (tmpText == ANSI_STR_RESET_FINAL) {
 	  bright = false;
 	  pulsating = false;
 	  underline = false;
-	  color[0] = BrightColors[WhiteColor][0] * dimFactor;
-	  color[1] = BrightColors[WhiteColor][1] * dimFactor;
-	  color[2] = BrightColors[WhiteColor][2] * dimFactor;
+	  color[0] = resetColor[0] * darkDim;
+	  color[1] = resetColor[1] * darkDim;
+	  color[2] = resetColor[2] * darkDim;
 	} else if (tmpText == ANSI_STR_BRIGHT) {
 	  bright = true;
 	} else if (tmpText == ANSI_STR_DIM) {
@@ -385,7 +419,7 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
 	} else if (tmpText == ANSI_STR_NO_PULSATE) {
 	  pulsating = false;
 	} else {
-	  DEBUG2("ANSI Code %s not supported\n", tmpText.c_str());
+	  logDebugMessage(2,"ANSI Code %s not supported\n", tmpText.c_str());
 	}
       }
     }
@@ -406,9 +440,10 @@ void FontManager::drawString(float x, float y, float z, int faceID, float size,
 
 void FontManager::drawString(float x, float y, float z,
 			     const std::string &face, float size,
-			     const std::string &text)
+			     const std::string &text,
+			     const float* resetColor)
 {
-  drawString(x, y, z, getFaceID(face), size, text);
+  drawString(x, y, z, getFaceID(face), size, text, resetColor);
 }
 
 float FontManager::getStrLength(int faceID, float size,	const std::string &text,
@@ -418,14 +453,14 @@ float FontManager::getStrLength(int faceID, float size,	const std::string &text,
     return 0.0f;
 
   if ((faceID < 0) || (faceID > getNumFaces())) {
-    DEBUG2("Trying to find length of string for invalid Font Face ID %d\n", faceID);
+    logDebugMessage(2,"Trying to find length of string for invalid Font Face ID %d\n", faceID);
     return 0.0f;
   }
 
   ImageFont* pFont = getClosestRealSize(faceID, size, size);
 
   if (!pFont) {
-    DEBUG2("Could not find applicable font size for sizing; font face ID %d, "
+    logDebugMessage(2,"Could not find applicable font size for sizing; font face ID %d, "
 	   "requested size %f\n", faceID, size);
     return 0.0f;
   }
@@ -433,9 +468,13 @@ float FontManager::getStrLength(int faceID, float size,	const std::string &text,
   float scale = size / (float)pFont->getSize();
 
   // don't include ansi codes in the length, but allow outside funcs to skip this step
-  const std::string &stripped = alreadyStripped ? text : stripAnsiCodes(text);
-
-  return pFont->getStrLength(scale, stripped.c_str(), (int)stripped.size());
+  float strippedLength;
+  if (alreadyStripped) {
+    strippedLength = pFont->getStrLength(scale, text);
+  } else {
+    strippedLength = pFont->getStrLength(scale, stripAnsiCodes(text));
+  }
+  return strippedLength;
 }
 
 float FontManager::getStrLength(const std::string &face, float size,
@@ -504,7 +543,7 @@ ImageFont*    FontManager::getClosestRealSize(int faceID, float desiredSize, flo
   if (!canScale || desiredSize < 14.0f) {
     // get the next biggest font size from requested
     if (!font) {
-      DEBUG2("Could not find applicable font size for sizing; font face ID %d, "
+      logDebugMessage(2,"Could not find applicable font size for sizing; font face ID %d, "
 	     "requested size %f\n", faceID, desiredSize);
       return NULL;
     }
@@ -517,7 +556,7 @@ ImageFont*    FontManager::getClosestRealSize(int faceID, float desiredSize, flo
 
 void	    FontManager::getPulseColor(const GLfloat *color, GLfloat *pulseColor) const
 {
-  float pulseTime = TimeKeeper::getCurrent().getSeconds();
+  float pulseTime = (float)TimeKeeper::getCurrent().getSeconds();
 
   // depth is how dark it should get (1.0 is to black)
   float pulseDepth = BZDBCache::pulseDepth;
