@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -154,8 +154,9 @@ BZAdminClient::ServerCode BZAdminClient::checkMessage() {
     case MsgNewRabbit:
       if (messageMask[MsgNewRabbit]) {
 	vbuf = nboUnpackUByte(vbuf, p);
-	lastMessage.first = std::string("*** '") + players[p].name +
-	  "' is now the rabbit.";
+	if (p != NoPlayer)
+	  lastMessage.first = std::string("*** '") + players[p].name +
+	    "' is now the rabbit.";
       }
       break;
 
