@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* bzflag special common - 1st one */
@@ -37,12 +37,12 @@ ActionBinding::ActionBinding() {
   wayToBindActions.insert(std::make_pair(std::string("send recipient"), press));
   wayToBindActions.insert(std::make_pair(std::string("send admin"), press));
   wayToBindActions.insert(std::make_pair(std::string("toggle displayScore"), press));
-  wayToBindActions.insert(std::make_pair(std::string("viewZoom toggle"),
-					 press));
+  wayToBindActions.insert(std::make_pair(std::string("viewZoom toggle"), press));
   wayToBindActions.insert(std::make_pair(std::string("viewZoom in"), press));
   wayToBindActions.insert(std::make_pair(std::string("viewZoom out"), press));
   wayToBindActions.insert(std::make_pair(std::string("pause"), press));
   wayToBindActions.insert(std::make_pair(std::string("fullscreen"), press));
+  wayToBindActions.insert(std::make_pair(std::string("mousegrab"), press));
   wayToBindActions.insert(std::make_pair(std::string("iconify"), press));
 #ifdef SNAPPING
   wayToBindActions.insert(std::make_pair(std::string("screenshot"), press));
@@ -64,8 +64,7 @@ ActionBinding::ActionBinding() {
   wayToBindActions.insert(std::make_pair(std::string("drive reverse"), both));
   // End movement keys
 
-  wayToBindActions.insert(std::make_pair(std::string("roam cycle subject backward"),
-					 press));
+  wayToBindActions.insert(std::make_pair(std::string("roam cycle subject backward"), press));
   wayToBindActions.insert(std::make_pair(std::string("roam cycle subject forward"), press));
   wayToBindActions.insert(std::make_pair(std::string("roam cycle type forward"), press));
   wayToBindActions.insert(std::make_pair(std::string("roam zoom in"), both));
@@ -74,7 +73,10 @@ ActionBinding::ActionBinding() {
   wayToBindActions.insert(std::make_pair(std::string("servercommand"), press));
   wayToBindActions.insert(std::make_pair(std::string("toggle displayFlagHelp"), press));
   wayToBindActions.insert(std::make_pair(std::string("scrollpanel up"), press));
+  wayToBindActions.insert(std::make_pair(std::string("scrollpanel up_page"), press));
   wayToBindActions.insert(std::make_pair(std::string("scrollpanel down"), press));
+  wayToBindActions.insert(std::make_pair(std::string("scrollpanel down_page"), press));
+  wayToBindActions.insert(std::make_pair(std::string("scrollpanel bottom"), press));
   wayToBindActions.insert(std::make_pair(std::string("radarZoom in"), press));
   wayToBindActions.insert(std::make_pair(std::string("radarZoom out"), press));
   wayToBindActions.insert(std::make_pair(std::string("set displayRadarRange 0.25"), press));
@@ -82,17 +84,14 @@ ActionBinding::ActionBinding() {
   wayToBindActions.insert(std::make_pair(std::string("set displayRadarRange 1.0"), press));
   wayToBindActions.insert(std::make_pair(std::string("toggle slowKeyboard"), press));
   wayToBindActions.insert(std::make_pair(std::string("hunt"), press));
+  wayToBindActions.insert(std::make_pair(std::string("addhunt"), press));
   wayToBindActions.insert(std::make_pair(std::string("restart"), release));
   wayToBindActions.insert(std::make_pair(std::string("autopilot"), press));
 
-  wayToBindActions.insert(std::make_pair(std::string("messagepanel all"),
-					 press));
-  wayToBindActions.insert(std::make_pair(std::string("messagepanel chat"),
-					 press));
-  wayToBindActions.insert(std::make_pair(std::string("messagepanel server"),
-					 press));
-  wayToBindActions.insert(std::make_pair(std::string("messagepanel misc"),
-					 press));
+  wayToBindActions.insert(std::make_pair(std::string("messagepanel all"), press));
+  wayToBindActions.insert(std::make_pair(std::string("messagepanel chat"), press));
+  wayToBindActions.insert(std::make_pair(std::string("messagepanel server"), press));
+  wayToBindActions.insert(std::make_pair(std::string("messagepanel misc"), press));
 
   defaultBinding.insert(BindingTable::value_type("F12", "quit"));
   defaultBinding.insert(BindingTable::value_type("Left Mouse", "fire"));
@@ -146,10 +145,11 @@ ActionBinding::ActionBinding() {
   defaultBinding.insert(BindingTable::value_type("F11", "roam zoom normal"));
   defaultBinding.insert(BindingTable::value_type("O", "servercommand"));
   defaultBinding.insert(BindingTable::value_type("F", "toggle displayFlagHelp"));
-  defaultBinding.insert(BindingTable::value_type("Page Up", "scrollpanel up"));
-  defaultBinding.insert(BindingTable::value_type("Wheel Up", "scrollpanel up"));
-  defaultBinding.insert(BindingTable::value_type("Page Down", "scrollpanel down"));
-  defaultBinding.insert(BindingTable::value_type("Wheel Down", "scrollpanel down"));
+  defaultBinding.insert(BindingTable::value_type("Page Up", "scrollpanel up_page"));
+  defaultBinding.insert(BindingTable::value_type("Wheel Up", "scrollpanel up 3"));
+  defaultBinding.insert(BindingTable::value_type("Page Down", "scrollpanel down_page"));
+  defaultBinding.insert(BindingTable::value_type("Wheel Down", "scrollpanel down 3"));
+  defaultBinding.insert(BindingTable::value_type("End", "scrollpanel bottom"));
   defaultBinding.insert(BindingTable::value_type("1", "set displayRadarRange 0.25"));
   defaultBinding.insert(BindingTable::value_type("2", "set displayRadarRange 0.5"));
   defaultBinding.insert(BindingTable::value_type("3", "set displayRadarRange 1.0"));
@@ -157,6 +157,7 @@ ActionBinding::ActionBinding() {
   defaultBinding.insert(BindingTable::value_type("5", "radarZoom out"));
   defaultBinding.insert(BindingTable::value_type("A", "toggle slowKeyboard"));
   defaultBinding.insert(BindingTable::value_type("U", "hunt"));
+  defaultBinding.insert(BindingTable::value_type("7", "addhunt"));
   defaultBinding.insert(BindingTable::value_type("Right Mouse", "restart"));
   defaultBinding.insert(BindingTable::value_type("I", "restart"));
   defaultBinding.insert(BindingTable::value_type("9", "autopilot"));
@@ -225,7 +226,7 @@ void ActionBinding::associate(std::string key,
   bindingTable.insert(BindingTable::value_type(key, action));
   if (keyBind)
     bind(action, key);
-};
+}
 
 void ActionBinding::deassociate(std::string action) {
   BindingTable::iterator index, next;
@@ -239,7 +240,7 @@ void ActionBinding::deassociate(std::string action) {
       bindingTable.erase(index);
     }
   }
-};
+}
 
 void ActionBinding::bind(std::string action, std::string key) {
   PressStatusBind statusBind = wayToBindActions[action];
