@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* BZFlag common header */
@@ -18,29 +18,20 @@
 
 /* system headers */
 #include <assert.h>
-#include <stdio.h>
-#include <stdlib.h>
+#include <time.h>
 #include <string.h>
 
 /* common implementation headers */
-#include "bzfgl.h"
-#include "global.h"
-#include "BzfWindow.h"
-#include "ErrorHandler.h"
-#include "Team.h"
-#include "OpenGLGState.h"
-#include "StateDatabase.h"
 #include "BZDBCache.h"
-#include "AnsiCodes.h"
 #include "FontManager.h"
 #include "TextUtils.h"
+#include "ErrorHandler.h"
+#include "global.h"
 
 /* local implementation headers */
 #include "SceneRenderer.h"
-#include "MainWindow.h"
 #include "RadarRenderer.h"
-
-void			printFatalError(const char* fmt, ...);
+#include "bzflag.h"
 
 //
 // ControlPanelMessage
@@ -57,10 +48,10 @@ void ControlPanelMessage::breakLines(float maxLength, int fontFace, float fontSi
 
   // get message and its length
   const char* msg = string.c_str();
-  int lineLen     = string.length();
+  int lineLen     = (int)string.length();
 
   // if there are tabs in the message, find the last one
-  int lastTab = string.rfind('\t');
+  int lastTab = (int)string.rfind('\t');
 
   lines.clear();
   numlines=0;
@@ -141,7 +132,7 @@ void ControlPanelMessage::breakLines(float maxLength, int fontFace, float fontSi
 //
 int			ControlPanel::messagesOffset = 0;
 
-ControlPanel::ControlPanel(MainWindow& _mainWindow, SceneRenderer& renderer) :
+ControlPanel::ControlPanel(MainWindow& _mainWindow, SceneRenderer& _renderer) :
 				tabsOnRight(true),
 				tabs(NULL),
 				totalTabWidth(0),
@@ -150,8 +141,9 @@ ControlPanel::ControlPanel(MainWindow& _mainWindow, SceneRenderer& renderer) :
 				numBuffers(2),
 				changedMessage(0),
 				radarRenderer(NULL),
-				renderer(&renderer),
+				renderer(&_renderer),
 				fontFace(0),
+				dimming(1.0f),
 				du(0),
 				dv(0),
 				messageMode(MessageAll)
@@ -203,8 +195,6 @@ ControlPanel::~ControlPanel()
   BZDB.removeCallback("displayRadar", bzdbCallback, this);
   BZDB.removeCallback(StateDatabase::BZDB_RADARLIMIT, bzdbCallback, this);
 
-  extern bool echoToConsole;
-  extern bool echoAnsi;
   if (echoToConsole && echoAnsi) {
     std::cout << ColorStrings[FinalResetColor] << std::flush;
   }
@@ -230,7 +220,7 @@ void			ControlPanel::setControlColor(const GLfloat *color)
     memset(teamColor, 0, 3 * sizeof(float));
 }
 
-void			ControlPanel::render(SceneRenderer& renderer)
+void			ControlPanel::render(SceneRenderer& _renderer)
 {
   if (!BZDB.isTrue("displayConsole")) {
     // always draw the console if its fully opaque
@@ -243,7 +233,7 @@ void			ControlPanel::render(SceneRenderer& renderer)
   if (!resized) resize();
 
   // optimization for software rendering folks
-  if (!changedMessage && renderer.getPanelOpacity() == 1.0f) {
+  if (!changedMessage && _renderer.getPanelOpacity() == 1.0f) {
     return;
   }
 
@@ -264,13 +254,15 @@ void			ControlPanel::render(SceneRenderer& renderer)
   OpenGLGState::resetState();
 
   FontManager &fm = FontManager::instance();
+  fm.setOpacity(dimming);
 
   if (changedMessage > 0) {
     changedMessage--;
   }
   float fx = messageAreaPixels[0] + margin;
   float fy = messageAreaPixels[1] + margin + 1.0f;
-  int   ay = (renderer.getPanelOpacity() == 1.0f || !showTabs) ? 0 : int(lineHeight + 4);
+  int   ay = (_renderer.getPanelOpacity() == 1.0f || !showTabs) ? 0
+    : int(lineHeight + 4);
 
   glScissor(x + messageAreaPixels[0] - 1,
       y + messageAreaPixels[1],
@@ -278,13 +270,13 @@ void			ControlPanel::render(SceneRenderer& renderer)
       messageAreaPixels[3] + ay);
   OpenGLGState::resetState();
 
-  if (renderer.getPanelOpacity() > 0.0f) {
+  if (_renderer.getPanelOpacity() > 0.0f) {
     // nice blended messages background
-    if (BZDBCache::blend && renderer.getPanelOpacity() < 1.0f)
+    if (BZDBCache::blend && _renderer.getPanelOpacity() < 1.0f)
       glEnable(GL_BLEND);
 
     // clear the background
-    glColor4f(0.0f, 0.0f, 0.0f, renderer.getPanelOpacity());
+    glColor4f(0.0f, 0.0f, 0.0f, _renderer.getPanelOpacity());
     glRecti(messageAreaPixels[0] - 1, // clear an extra pixel column to simplify fuzzy float stuff later
 	    messageAreaPixels[1],
 	    messageAreaPixels[0] + messageAreaPixels[2],
@@ -297,9 +289,9 @@ void			ControlPanel::render(SceneRenderer& renderer)
 
 	// current mode is given a dark background to match the control panel
 	if (messageMode == MessageModes(tab)) {
-	  glColor4f(0.0f, 0.0f, 0.0f, renderer.getPanelOpacity());
+	  glColor4f(0.0f, 0.0f, 0.0f, _renderer.getPanelOpacity());
 	} else {
-	  glColor4f(0.10f, 0.10f, 0.10f, renderer.getPanelOpacity());
+	  glColor4f(0.10f, 0.10f, 0.10f, _renderer.getPanelOpacity());
 	}
 
 	if (tabsOnRight) {
@@ -319,7 +311,7 @@ void			ControlPanel::render(SceneRenderer& renderer)
       } // end iteration over tabs
     }
 
-    if (BZDBCache::blend && renderer.getPanelOpacity() < 1.0f)
+    if (BZDBCache::blend && _renderer.getPanelOpacity() < 1.0f)
       glDisable(GL_BLEND);
   }
 
@@ -329,7 +321,7 @@ void			ControlPanel::render(SceneRenderer& renderer)
     int lines = int(messages[messageMode].size());
     if (lines > 0) {
 
-      const float size = std_max(float(maxLines) / lines, 0.02f);
+      const float size = std::max(float(maxLines) / lines, 0.02f);
       const float offset = float(messagesOffset) / lines;
       const int maxTop = messageAreaPixels[1] + messageAreaPixels[3];
       int top = messageAreaPixels[1] + int((offset + size) * (float)messageAreaPixels[3]);
@@ -351,11 +343,11 @@ void			ControlPanel::render(SceneRenderer& renderer)
 
       // current mode is bright, others are not so bright
       if (messageMode == MessageModes(tab)) {
-	glColor3f(1.0f, 1.0f, 1.0f);
+	glColor4f(1.0f, 1.0f, 1.0f, dimming);
       } else if (unRead[MessageModes(tab)]) {
-	glColor3f(0.5f, 0.0f, 0.0f);
+	glColor4f(0.5f, 0.0f, 0.0f, dimming);
       } else {
-	glColor3f(0.5f, 0.5f, 0.5f);
+	glColor4f(0.5f, 0.5f, 0.5f, dimming);
       }
 
       if (tabsOnRight) {
@@ -373,19 +365,23 @@ void			ControlPanel::render(SceneRenderer& renderer)
     }
   }
 
-  // draw messages
-  //
-  // It works by first breaking the string into a vector of strings (done
-  //  elsewhere), each of which will fit the control panel, and tallying
-  //  the number of lines, then moving up the proper number of lines and
-  //  displaying downward -- that is, it kinda backtracks for each line
-  //  that will wrap.
-  //
-  //  messageAreaPixels[2] = Width of Message Window in Pixels
-  //  maxLines	     = Max messages lines that can be displayed
-  //  maxScrollPages       = This number * maxLines is the total maximum
-  //			 lines of messages (and scrollback). It is
-  //			 stored as a BZDB parameter.
+  /* draw messages
+   *
+   * It works by first breaking the string into a vector of strings
+   * (done elsewhere), each of which will fit the control panel, and
+   * tallying the number of lines, then moving up the proper number of
+   * lines and displaying downward -- that is, it kinda backtracks for
+   * each line that will wrap.
+   *
+   * messageAreaPixels[2] = Width of Message Window in Pixels.
+   *
+   * maxLines = Max messages lines that can be displayed at once per
+   * page.  This COULD be a BZDB parameter (but isn't).
+   *
+   * maxScrollPages = This number * maxLines is the total maximum
+   * lines of messages (and scrollback). It is stored as a BZDB
+   * parameter.
+   */
 
   glScissor(x + messageAreaPixels[0],
 	    y + messageAreaPixels[1],
@@ -393,7 +389,7 @@ void			ControlPanel::render(SceneRenderer& renderer)
 	    messageAreaPixels[3] - (showTabs ? int(lineHeight + 4) : 0) + ay);
 
   if (messageMode >= 0) {
-    i = messages[messageMode].size() - 1;
+    i = (int)messages[messageMode].size() - 1;
   } else {
     i = -1;
   }
@@ -402,16 +398,38 @@ void			ControlPanel::render(SceneRenderer& renderer)
     if (i < 0)
       i = 0;
   }
+
+  const std::string highlightPattern = BZDB.get("highlightPattern");
+  bool useHighlight = (highlightPattern.size() > 0);
+  regex_t re;
+  if (useHighlight) {
+    if (regcomp(&re, highlightPattern.c_str(), REG_EXTENDED | REG_ICASE) != 0) {
+      useHighlight = false; // bad regex
+    }
+  }
+
   for (j = 0; i >= 0 && j < maxLines; i--) {
     // draw each line of text
     int numLines = messages[messageMode][i].numlines;
-    int numStrings = messages[messageMode][i].lines.size();
+    int numStrings = (int)messages[messageMode][i].lines.size();
     int msgy = numLines - 1;
     int msgx = 0;
 
+    // see if this message need to be highlighted (check each line)
+    bool highlight = false;
+    if (useHighlight) {
+      for (int l = 0; l < numStrings; l++)  {
+	const std::string &msg = messages[messageMode][i].lines[l];
+	std::string raw = stripAnsiCodes(msg);
+	if (regexec(&re, raw.c_str(), 0, NULL, 0) == 0) {
+	  highlight = true;
+	}
+      }
+    }
+
     // default to drawing text in white
-    GLfloat whiteColor[3] = {1.0f, 1.0f, 1.0f};
-    glColor3fv(whiteColor);
+    GLfloat whiteColor[4] = {1.0f, 1.0f, 1.0f, dimming};
+    glColor4fv(whiteColor);
 
     bool isTab = false;
 
@@ -433,8 +451,18 @@ void			ControlPanel::render(SceneRenderer& renderer)
       assert(msgy >= 0);
 
       // only draw message if inside message area
-      if (j + msgy < maxLines)
-	fm.drawString(fx + msgx, fy + msgy * lineHeight, 0, fontFace, fontSize, msg);
+      if (j + msgy < maxLines) {
+	if (!highlight) {
+	  fm.drawString(fx + msgx, fy + msgy * lineHeight, 0, fontFace, fontSize, msg);
+	} else {
+	  // highlight this line
+	  std::string newMsg = ANSI_STR_PULSATING;
+	  newMsg += ANSI_STR_UNDERLINE;
+	  newMsg += ANSI_STR_FG_CYAN;
+	  newMsg += stripAnsiCodes(msg);
+	  fm.drawString(fx + msgx, fy + msgy * lineHeight, 0, fontFace, fontSize, newMsg);
+	}
+      }
 
       // next line
       msgy--;
@@ -442,6 +470,12 @@ void			ControlPanel::render(SceneRenderer& renderer)
     j += numLines;
     fy += int(lineHeight * numLines);
   }
+
+  // free the regex memory
+  if (useHighlight) {
+    regfree(&re);
+  }
+
   glScissor(x + messageAreaPixels[0] - 2,
 	    y + messageAreaPixels[1] - 2,
 	    messageAreaPixels[2] + 3,
@@ -452,8 +486,16 @@ void			ControlPanel::render(SceneRenderer& renderer)
   long xpos;
   long ypos;
 
+  float outlineOpacity = RENDERER.getPanelOpacity();
+  float fudgeFactor = BZDBCache::hudGUIBorderOpacityFactor;	// bzdb cache this manybe?
+  if ( outlineOpacity < 1.0f )
+	outlineOpacity = (outlineOpacity*fudgeFactor) + (1.0f - fudgeFactor);
+
+  if (BZDBCache::blend)
+	 glEnable(GL_BLEND);
+
   // nice border
-  glColor3f(teamColor[0], teamColor[1], teamColor[2] );
+  glColor4f(teamColor[0], teamColor[1], teamColor[2],outlineOpacity );
   glBegin(GL_LINE_LOOP); {
     // bottom left
     xpos = x + messageAreaPixels[0] - 1;
@@ -531,7 +573,14 @@ void			ControlPanel::render(SceneRenderer& renderer)
     }
   } glEnd();
 
+  if (BZDBCache::blend)
+	  glDisable(GL_BLEND);
+
+  glColor4f(teamColor[0], teamColor[1], teamColor[2],1.0f );
+
   glPopMatrix();
+
+  fm.setOpacity(1.0f);
 }
 
 void			ControlPanel::resize()
@@ -646,23 +695,32 @@ void			ControlPanel::exposeCallback(void* self)
   ((ControlPanel*)self)->invalidate();
 }
 
-void			ControlPanel::setMessagesOffset(int offset, int whence)
+void			ControlPanel::setMessagesOffset(int offset, int whence, bool paged)
 {
+  if (paged) {
+    if (abs(offset) <= 1) {
+      offset = offset * (maxLines - 1);
+    } else {
+      offset = offset * maxLines;
+    }
+  }
+
   // offset = offset from whence (offset of 0 is the bottom/most recent)
   // whence = 0, 1, or 2 (akin to SEEK_SET, SEEK_CUR, SEEK_END)
+
   switch (whence) {
     case 0:
       if (offset < (int)messages[messageMode].size())
 	messagesOffset = offset;
       else
-	messagesOffset = messages[messageMode].size() - 1;
+	messagesOffset = (int)messages[messageMode].size() - 1;
       break;
     case 1:
       if (offset > 0) {
 	if (messagesOffset + offset < (int)messages[messageMode].size())
 	  messagesOffset += offset;
 	else
-	  messagesOffset = messages[messageMode].size() - 1;
+	  messagesOffset = (int)messages[messageMode].size() - 1;
       } else if (offset < 0) {
 	if (messagesOffset + offset >= 0)
 	  messagesOffset += offset;
@@ -694,66 +752,108 @@ void			ControlPanel::setMessagesMode(int _messageMode)
 }
 
 void			ControlPanel::addMessage(const std::string& line,
-						 const int mode)
+						 const int realmode)
 {
   ControlPanelMessage item(line);
   item.breakLines(messageAreaPixels[2] - 2 * margin, fontFace, fontSize);
 
-  int maxScrollPages = BZDB.evalInt("scrollPages");
-  if (maxScrollPages <= 0) {
-    maxScrollPages = atoi(BZDB.getDefault("scrollPages").c_str());
-    BZDB.setInt("scrollPages", maxScrollPages);
+  int _maxScrollPages = BZDB.evalInt("scrollPages");
+  if (_maxScrollPages <= 0) {
+    _maxScrollPages = atoi(BZDB.getDefault("scrollPages").c_str());
+    BZDB.setInt("scrollPages", _maxScrollPages);
   }
 
-  // Add to "All" tab
-  if ((int)messages[MessageAll].size() < maxLines * maxScrollPages) {
-    // not full yet so just append it
-    messages[MessageAll].push_back(item);
-  } else {
-    // rotate list and replace oldest (in newest position after rotate)
-    messages[MessageAll].pop_front();
-    messages[MessageAll].push_back(item);
-  }
+  // the effective tab
+  const int tabmode = (realmode == MessageCurrent) ? messageMode : realmode;
 
-  // Add to other tab
-  if (mode >= MessageChat && mode < MessageModeCount) {
-    if ((int)messages[mode].size() < maxLines * maxScrollPages) {
-      // not full yet so just append it
-      messages[mode].push_back(item);
-    } else {
-      // rotate list and replace oldest (in newest position after rotate)
-      messages[mode].pop_front();
-      messages[mode].push_back(item);
-    }
-    if (messageMode != MessageAll && messageMode != mode) {
-      if (!unRead[mode] && (int)BZDB.eval("showtabs") > 0)
+  // add to the appropriate tabs
+  for (int tab = MessageAll; tab < MessageModeCount; tab++) {
+
+    if ((tab == tabmode) // add to its own mode
+	// add to the All tab, unless using Current mode
+	|| ((tab == MessageAll) && (realmode != MessageCurrent))
+	// always add to all tabs
+	|| (realmode == MessageAllTabs)) {
+
+      // insert the message into the tab
+      if ((int)messages[tab].size() < maxLines * _maxScrollPages) {
+	// not full yet so just append it
+	messages[tab].push_back(item);
+      } else {
+	// rotate list and replace oldest (in newest position after rotate)
+	messages[tab].pop_front();
+	messages[tab].push_back(item);
+      }
+
+      // visible changes, force a console refresh
+      if (messageMode == tab) {
 	invalidate();
-      unRead[mode] = true;
+      }
+
+      // mark the tab as unread (if viewing tabs)
+      const bool showTabs = (BZDB.evalInt("showtabs") > 0);
+      if (showTabs && (messageMode != tab) && (messageMode != MessageAll)) {
+	unRead[tab] = true;
+      }
     }
   }
 
-  // this stuff has no effect on win32 (there's no console)
-  extern bool echoToConsole;
-  extern bool echoAnsi;
-  if (echoToConsole) {
+  if (echoToConsole){
+#ifdef _WIN32
+    // this is cheap but it will work on windows
+    FILE *fp = fopen ("stdout.txt","a+");
+    if (fp){
+      fprintf(fp,"%s\n", stripAnsiCodes(line).c_str());
+      fclose(fp);
+    }
+#else
     if (echoAnsi) {
       std::cout << line << ColorStrings[ResetColor] << std::endl;
     } else {
       std::cout << stripAnsiCodes(line) << std::endl;
     }
     fflush(stdout);
+#endif
   }
-
-  // need to refresh console if new msg is visible on current tab
-  if (messageMode == MessageAll || messageMode == mode)
-    invalidate();
 }
 
-void			ControlPanel::setRadarRenderer(RadarRenderer* rr)
+
+void ControlPanel::saveMessages(const std::string& filename,
+				bool stripAnsi) const
+{
+  FILE* file = fopen(filename.c_str(), "a+");
+  if (!file) {
+    return;
+  }
+
+  const time_t nowTime = time (NULL);
+  fprintf(file, "\n----------------------------------------\n");
+  fprintf(file, "Messages saved: %s", ctime(&nowTime));
+  fprintf(file, "----------------------------------------\n\n");
+
+  // add to the appropriate tabs
+  std::deque<ControlPanelMessage>::const_iterator msg = messages[MessageAll].begin()++;
+  for (; msg != messages[MessageAll].end(); ++msg) {
+    const std::string& line = msg->string;
+    if (stripAnsi) {
+      fprintf(file, "%s\n", stripAnsiCodes(line).c_str());
+    } else {
+      fprintf(file, "%s%s\n", line.c_str(), ColorStrings[ResetColor].c_str());
+    }
+  }
+
+  fclose(file);
+
+  return;
+}
+
+
+void ControlPanel::setRadarRenderer(RadarRenderer* rr)
 {
   radarRenderer = rr;
 }
 
+
 // Local Variables: ***
 // mode: C++ ***
 // tab-width: 8 ***
