@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef	BZF_CONTROL_PANEL_H
@@ -17,14 +17,20 @@
   #pragma warning(disable: 4786)
 #endif
 
+// common - 1st
 #include "common.h"
-#include "MainWindow.h"
-#include "global.h"
-#include "OpenGLGState.h"
+
+// system headers
 #include <string>
 #include <vector>
 #include <deque>
 
+//common headers
+#include "bzfgl.h"
+
+// local headers
+#include "MainWindow.h"
+
 class RadarRenderer;
 class SceneRenderer;
 
@@ -50,12 +56,17 @@ class ControlPanel {
     void		setNumberOfFrameBuffers(int);
 
     void		addMessage(const std::string&, const int mode = 3);
-    void		setMessagesOffset(int offset, int whence);
+    void		setMessagesOffset(int offset, int whence, bool paged);
     void		setMessagesMode(int _messageMode);
     int		getMessagesMode() {return messageMode;};
     void		setStatus(const char*);
     void		setRadarRenderer(RadarRenderer*);
 
+    void		setDimming(float dimming);
+
+    void		saveMessages(const std::string& filename,
+				     bool stripAnsi) const;
+
   private:
     // no copying!
 			ControlPanel(const ControlPanel&);
@@ -66,10 +77,12 @@ class ControlPanel {
     static void		bzdbCallback(const std::string& name, void* data);
 
     enum MessageModes {
-      MessageAll = 0,
-      MessageChat = 1,
-      MessageServer = 2,
-      MessageMisc = 3,
+      MessageAllTabs = -2,
+      MessageCurrent = -1,
+      MessageAll     = 0,
+      MessageChat    = 1,
+      MessageServer  = 2,
+      MessageMisc    = 3,
       MessageModeCount
     };
     bool tabsOnRight;
@@ -88,6 +101,8 @@ class ControlPanel {
 
     int			fontFace;
     float		fontSize;
+
+    float		dimming;
     float		du, dv;
     int			radarAreaPixels[4];
     int			messageAreaPixels[4];
@@ -100,8 +115,16 @@ class ControlPanel {
     float		margin;
     float		lineHeight;
     bool		unRead[MessageModeCount];
+
 };
 
+inline void ControlPanel::setDimming(float newDimming)
+{
+  const float newDim = 1.0f - newDimming;
+  dimming = (newDim > 1.0f) ? 1.0f : (newDim < 0.0f) ? 0.0f : newDim;
+}
+
+
 #endif // BZF_CONTROL_PANEL_H
 
 // Local Variables: ***
