@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,18 +7,31 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef DOWNLOADS_H
 #define DOWNLOADS_H
 
+#include "common.h"
+
+/* system interface headers */
+#include <string>
+
+
 namespace Downloads {
-  void doDownloads();
-  bool updateDownloads(bool& rebuild);
+  void startDownloads(bool doDownloads,
+		      bool updateDownloads,
+		      bool referencing);
+  void finalizeDownloads();
   void removeTextures(); // free the downloaded GL textures
+  bool requestFinalized();
 }
 
+bool authorizedServer(const std::string& hostname);
+bool parseHostname(const std::string& url, std::string& hostname);
+
+
 #endif
 
 // Local Variables: ***
