@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,18 +7,12 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#include "common.h"
-
 // implementation header
 #include "EntryZone.h"
 
-// common headers
-#include "Pack.h"
-
-
 EntryZone::EntryZone()
 {
   pos[0] = pos[1] = pos[2] = 0.0f;
@@ -28,7 +22,7 @@ EntryZone::EntryZone()
   teams.clear();
   safety.clear();
   return;
-};
+}
 
 
 void* EntryZone::unpack(void* buf)
@@ -60,7 +54,7 @@ void* EntryZone::unpack(void* buf)
   }
 
   return buf;
-};
+}
 
 
 // Local Variables: ***
