@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /*
@@ -18,16 +18,22 @@
 #ifndef	__HUDUITYPEIN_H__
 #define	__HUDUITYPEIN_H__
 
+#include "common.h"
+
+/* system interface headers */
 #include <string>
+
+/* common interface headers */
 #include "BzfEvent.h"
 #include "HUDuiControl.h"
 
+
 class HUDuiTypeIn : public HUDuiControl {
   public:
 			HUDuiTypeIn();
 			~HUDuiTypeIn();
 
-	void		setObfuscation(bool on);
+    void		setObfuscation(bool on);
     int			getMaxLength() const;
     std::string		getString() const;
 
@@ -45,7 +51,7 @@ class HUDuiTypeIn : public HUDuiControl {
     std::string		string;
     int			cursorPos;
     bool		allowEdit;
-	bool		obfuscate;
+    bool		obfuscate;
 };
 
 #endif // __HUDUITYPEIN_H__
