@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef	__MAINMENU_H__
@@ -20,9 +20,6 @@
 #include "HUDuiDefaultKey.h"
 
 class JoinMenu;
-#ifdef HAVE_KRB5
-class LoginMenu;
-#endif
 class OptionsMenu;
 class QuitMenu;
 
@@ -38,7 +35,7 @@ public:
   void resize(int width, int height);
   void createControls();
 
-  static const int getFontFace();
+  static int getFontFace();
 
 private:
 
@@ -49,12 +46,10 @@ private:
   HUDuiControl*	options;
   HUDuiControl*	help;
   HUDuiControl*	leave;
+  HUDuiControl*	save;
   HUDuiControl*	quit;
 
   JoinMenu*	joinMenu;
-#ifdef HAVE_KRB5
-  LoginMenu*	loginMenu;
-#endif
   OptionsMenu*	optionsMenu;
   QuitMenu*	quitMenu;
 };
