@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #include "Plan.h"
@@ -36,7 +36,7 @@ Plan::~Plan()
 bool Plan::isValid()
 {
 	TimeKeeper now = TimeKeeper();
-	float delta = now - planExpiration;
+	float delta = float(now - planExpiration);
 	return (delta < 0.0f);
 }
 
@@ -162,14 +162,14 @@ bool Plan::avoidBullet(float &rotation, float &speed)
 	const float *shotPos = shot->getPosition();
 	const float *shotVel = shot->getVelocity();
 	float shotAngle = atan2f(shotVel[1],shotVel[0]);
-	float shotUnitVec[2] = {cos(shotAngle), sin(shotAngle)};
+	float shotUnitVec[2] = {cosf(shotAngle), sinf(shotAngle)};
 
 	float trueVec[2] = {(pos[0]-shotPos[0])/minDistance,(pos[1]-shotPos[1])/minDistance};
 	float dotProd = trueVec[0]*shotUnitVec[0]+trueVec[1]*shotUnitVec[1];
 
 	if (((World::getWorld()->allowJumping() || (myTank->getFlag()) == Flags::Jumping
 	|| (myTank->getFlag()) == Flags::Wings))
-	&& (minDistance < (std_max(dotProd,0.5f) * BZDBCache::tankLength * 2.25f))
+	&& (minDistance < (std::max(dotProd,0.5f) * BZDBCache::tankLength * 2.25f))
 	&& (myTank->getFlag() != Flags::NoJumping)) {
 		myTank->setJump();
 		return (myTank->getFlag() != Flags::Wings);
@@ -240,7 +240,7 @@ ShotPath *Plan::findWorstBullet(float &minDistance)
 			if (dist < minDistance) {
 				const float *shotVel = shot->getVelocity();
 				float shotAngle = atan2f(shotVel[1], shotVel[0]);
-				float shotUnitVec[2] = {cos(shotAngle), sin(shotAngle)};
+				float shotUnitVec[2] = {cosf(shotAngle), sinf(shotAngle)};
 
 				float trueVec[2] = { (pos[0] - shotPos[0]) / dist, (pos[1] - shotPos[1]) / dist };
 				float dotProd = trueVec[0] * shotUnitVec[0] + trueVec[1] * shotUnitVec[1];
@@ -274,7 +274,7 @@ ShotPath *Plan::findWorstBullet(float &minDistance)
 		if (dist < minDistance) {
 			const float *shotVel = shot->getVelocity();
 			float shotAngle = atan2f(shotVel[1], shotVel[0]);
-			float shotUnitVec[2] = {cos(shotAngle), sin(shotAngle)};
+			float shotUnitVec[2] = {cosf(shotAngle), sinf(shotAngle)};
 
 			float trueVec[2] = { (pos[0] - shotPos[0]) / dist, (pos[1] - shotPos[1]) / dist };
 			float dotProd = trueVec[0] * shotUnitVec[0] + trueVec[1] * shotUnitVec[1];
@@ -302,6 +302,15 @@ PlanStack::PlanStack()
 	plans.push(pPlan);
 }
 
+PlanStack::~PlanStack()
+{
+	while (plans.size() > 0) {
+		Plan* pPlan = plans.top();
+		delete pPlan;
+		plans.pop();
+	}
+}
+
 void PlanStack::execute(float &rotation, float &speed)
 {
 	if (Plan::avoidBullet(rotation, speed))
