@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,16 +7,14 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* interface header */
-#include "common.h"
 #include "Roster.h"
 
 /* local implementation headers */
 #include "World.h"
-#include "WorldPlayer.h"
 
 
 NameList silencePlayers;
@@ -97,7 +95,7 @@ BaseLocalPlayer* getLocalPlayer(PlayerId id)
   if (myTank->getId() == id) return myTank;
 #ifdef ROBOT
   for (int i = 0; i < numRobots; i++)
-    if (robots[i]->getId() == id)
+    if (robots[i] && robots[i]->getId() == id)
       return robots[i];
 #endif
   return NULL;
