@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,12 +7,15 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef __ROSTER_H__
 #define __ROSTER_H__
 
+// common - 1st
+#include "common.h"
+
 /* system interface headers */
 #include <vector>
 #include <string>
@@ -49,7 +52,6 @@ BaseLocalPlayer*	getLocalPlayer(PlayerId id);
 TeamColor		PlayerIdToTeam(PlayerId id);
 PlayerId		TeamToPlayerId(TeamColor team);
 
-
 #endif /* __ROSTER_H__ */
 
 // Local Variables: ***
