@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /*
@@ -20,12 +20,6 @@
 #include "common.h"
 
 #include <string>
-#ifdef HAVE_KRB5
-	#ifdef MAXHOSTNAMELEN
-		#undef MAXHOSTNAMELEN
-	#endif
-#include <krb5.h>
-#endif
 
 #include "global.h"
 #include "Address.h"
@@ -54,7 +48,7 @@ class ServerLink {
     };
 
 			ServerLink(const Address& serverAddress,
-					int port = ServerPort, int number = 0);
+					int port = ServerPort);
 			~ServerLink();
 
     State		getState() const;
@@ -76,10 +70,6 @@ class ServerLink {
     void		sendCaptureFlag(TeamColor);
     void		sendGrabFlag(int flagIndex);
     void		sendDropFlag(const float* position);
-#ifdef HAVE_KRB5
-    void		sendKerberosTicket(const char      *principal,
-					   const krb5_data *ticket);
-#endif
     void		sendKilled(const PlayerId&, int reason,
 				   int shotId, const FlagType* flag, int phydrv);
   // FIXME -- This is very ugly, but required to build bzadmin with gcc 2.9.5.
