@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -280,11 +280,11 @@ void ServerStartMenu::scanWorldFiles (const std::string& searchDir,
     HANDLE h = FindFirstFile(pattern[i].c_str(), &findData);
     if (h != INVALID_HANDLE_VALUE) {
       std::string file;
-      while (FindNextFile(h, &findData)) {
+      do {
 	file = findData.cFileName;
 	worldFiles[file] = searchDir + file;
 	items->push_back(file);
-      }
+      } while (FindNextFile(h, &findData));
     }
   }
 #else
@@ -507,7 +507,7 @@ void ServerStartMenu::execute()
 	setStatus("Failed... server program is not executable.");
       else
 	setStatus(TextUtils::format("Failed... unknown error (%d).", errno, serverCmd).c_str());
-      DEBUG1("Failed to start server (%s) - error %d.\n", serverCmd, errno);
+      logDebugMessage(1,"Failed to start server (%s) - error %d.\n", serverCmd, errno);
     }
     else {
       setStatus("Server started.");
@@ -523,22 +523,22 @@ void ServerStartMenu::execute()
     if (pid != -1) {
       int i;
       for (i = 0; i < 12; i++) {
-        if (kill(pid, SIGTERM) == 0) {
-          TimeKeeper::sleep(0.25); // be gracious for max 3 seconds
-        } else {
-          if (errno == ESRCH) {
-            break; // the pid doesn't exist
-          }
-        }
+	if (kill(pid, SIGTERM) == 0) {
+	  TimeKeeper::sleep(0.25); // be gracious for max 3 seconds
+	} else {
+	  if (errno == ESRCH) {
+	    break; // the pid doesn't exist
+	  }
+	}
       }
       if (i == 12) {
-        kill(pid, SIGKILL); // be brutal
+	kill(pid, SIGKILL); // be brutal
       }
     }
 
     // fork
     pid = fork();
-    
+
     if (pid == -1) {
       setStatus("Failed... cannot fork.");
     }
@@ -563,13 +563,13 @@ void ServerStartMenu::execute()
       if (waitpid(pid, &pStatus, WNOHANG) != 0) {
 	pid = -1;
 	char failBuf[64];
-        if (WIFEXITED(pStatus)) {
-          snprintf(failBuf, 64, "Failed (exit = %i).", WEXITSTATUS(pStatus));
-        } else if (WIFSIGNALED(pStatus)) {
-          snprintf(failBuf, 64, "Failed (signal = %i).", WTERMSIG(pStatus));
-        } else {
-          strcpy(failBuf, "Failed.");
-        }
+	if (WIFEXITED(pStatus)) {
+	  snprintf(failBuf, 64, "Failed (exit = %i).", WEXITSTATUS(pStatus));
+	} else if (WIFSIGNALED(pStatus)) {
+	  snprintf(failBuf, 64, "Failed (signal = %i).", WTERMSIG(pStatus));
+	} else {
+	  strcpy(failBuf, "Failed.");
+	}
 	setStatus(failBuf);
       } else {
 	setStatus("Server started.");
