@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,64 +7,101 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* interface header */
 #include "ShockWaveStrategy.h"
 
 /* common implementation headers */
-#include "StateDatabase.h"
-#include "Team.h"
+#include "SceneRenderer.h"
 
 /* local implementation headers */
 #include "LocalPlayer.h"
-
-/* FIXME - from playing.h */
-Player* lookupPlayer(PlayerId id);
+#include "playing.h"
+#include "World.h"
 
 
-ShockWaveStrategy::ShockWaveStrategy(ShotPath* path) :
-  ShotStrategy(path),
+ShockWaveStrategy::ShockWaveStrategy(ShotPath *_path) :
+  ShotStrategy(_path),
   radius(BZDB.eval(StateDatabase::BZDB_SHOCKINRADIUS)),
   radius2(radius * radius)
 {
   // setup shot
-  FiringInfo& f = getFiringInfo(path);
+  FiringInfo& f = getFiringInfo(_path);
   f.lifetime *= BZDB.eval(StateDatabase::BZDB_SHOCKADLIFE);
 
   // make scene node
-  shockNode = new SphereSceneNode(path->getPosition(), radius);
-  Player* p = lookupPlayer(path->getPlayer());
-  TeamColor team = p ? p->getTeam() : RogueTeam;
-  const float* c = Team::getRadarColor(team);
-  shockNode->setColor(c[0], c[1], c[2], 0.75f);
+  const float* pos = _path->getPosition();
+  if (RENDERER.useQuality() >= 3) {
+    shockNode = new SphereLodSceneNode(pos, radius);
+    shockNode->setShockWave(true);
+  } else {
+    shockNode = new SphereBspSceneNode(pos, radius);
+  }
+
+  // get team
+  if (_path->getPlayer() == ServerPlayer) {
+    TeamColor tmpTeam = _path->getFiringInfo().shot.team;
+    team = (tmpTeam < RogueTeam) ? RogueTeam :
+	   (tmpTeam > RabbitTeam) ? RogueTeam : tmpTeam;
+  } else {
+    Player* p = lookupPlayer(_path->getPlayer());
+    team = p ? p->getTeam() : RogueTeam;
+  }
+
+  bool rabbitMode = World::getWorld()->allowRabbit();
+  const float* c = Team::getRadarColor(team, rabbitMode);
+  if (RENDERER.useQuality() >= 3) {
+    shockNode->setColor(c[0], c[1], c[2], 0.5f);
+  } else {
+    shockNode->setColor(c[0], c[1], c[2], 0.75f);
+  }
 }
 
+
 ShockWaveStrategy::~ShockWaveStrategy()
 {
   delete shockNode;
 }
 
+
 void ShockWaveStrategy::update(float dt)
 {
   radius += dt * (BZDB.eval(StateDatabase::BZDB_SHOCKOUTRADIUS) - BZDB.eval(StateDatabase::BZDB_SHOCKINRADIUS)) / getPath().getLifetime();
   radius2 = radius * radius;
 
   // update shock wave scene node
-  const GLfloat frac = (radius - BZDB.eval(StateDatabase::BZDB_SHOCKINRADIUS)) /
-    (BZDB.eval(StateDatabase::BZDB_SHOCKOUTRADIUS) - BZDB.eval(StateDatabase::BZDB_SHOCKINRADIUS));
   shockNode->move(getPath().getPosition(), radius);
-  Player* p = lookupPlayer(getPath().getPlayer());
+
+  // team color
   const LocalPlayer* myTank = LocalPlayer::getMyTank();
-  TeamColor team = p && !(myTank->getFlag() == Flags::Colorblindness) ? p->getTeam() : RogueTeam;
-  const float* c = Team::getRadarColor(team);
-  shockNode->setColor(c[0], c[1], c[2], 0.75f - 0.5f * frac);
+  TeamColor currentTeam;
+  if ((myTank->getFlag() == Flags::Colorblindness) &&
+      (getPath().getPlayer() != ServerPlayer)) {
+    currentTeam = RogueTeam;
+  } else {
+    currentTeam = team;
+  }
+
+  bool rabbitMode = World::getWorld()->allowRabbit();
+  const float* c = Team::getRadarColor(currentTeam, rabbitMode);
+
+  // fade old-style shockwaves
+  if (RENDERER.useQuality() >= 3) {
+    shockNode->setColor(c[0], c[1], c[2], 0.5f);
+  } else {
+    const float shockIn = BZDB.eval(StateDatabase::BZDB_SHOCKINRADIUS);
+    const float shockOut = BZDB.eval(StateDatabase::BZDB_SHOCKOUTRADIUS);
+    const GLfloat frac = (radius - shockIn) / (shockOut - shockIn);
+    shockNode->setColor(c[0], c[1], c[2], 0.75f - (0.5f * frac));
+  }
 
   // expire when full size
   if (radius >= BZDB.eval(StateDatabase::BZDB_SHOCKOUTRADIUS)) setExpired();
 }
 
+
 float ShockWaveStrategy::checkHit(const BaseLocalPlayer* tank, float position[3]) const
 {
   // return if player is inside radius of destruction -- note that a
