@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -48,9 +48,12 @@ public:
   FlagType*   getBestFlag() const;
 
   // tally functions
-  void	      recordFire(FlagType* flag);
+  void	      recordFire(FlagType* flag, const float *pVec, const float *shotVec);
   void	      recordHit(FlagType* flag);
 
+  double getLastShotTimeDelta ( void ) const {return lastShotTimeDelta;}
+  double getLastShotDeviation ( void ) const {return lastShotDeviation;}
+
 private:
   int	      normalFired;
   int	      normalHit;
@@ -64,6 +67,11 @@ private:
   int	      shockWaveHit;
   int	      thiefFired;
   int	      thiefHit;
+
+  double	  lastShotTimeDelta;
+  double	  lastShotTime;
+
+  float		  lastShotDeviation;
 };
 
 
