@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -33,7 +33,7 @@ public:
   void execute(void);
   void addStats(Player* player, std::vector<HUDuiControl*>& list);
 
-  static const int getFontFace();
+  static int getFontFace();
 
 private:
 
