@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,24 +7,21 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* interface header */
 #include "WorldBuilder.h"
 
 /* common implementation headers */
-#include "StateDatabase.h"
-#include "Pack.h"
 #include "TextUtils.h"
 #include "Protocol.h"
 #include "DynamicColor.h"
 #include "TextureMatrix.h"
-#include "BzMaterial.h"
 #include "PhysicsDriver.h"
-#include "MeshTransform.h"
 #include "FlagSceneNode.h"
 #include "ObstacleMgr.h"
+#include "BaseBuilding.h"
 
 /* compression library header */
 #include "../zlib/zlib.h"
@@ -45,6 +42,8 @@ WorldBuilder::~WorldBuilder()
 
 void* WorldBuilder::unpack(void* buf)
 {
+  TimeKeeper start = TimeKeeper::getCurrent();
+
   // unpack world database from network transfer
   // read style header
   uint16_t code, len;
@@ -56,7 +55,7 @@ void* WorldBuilder::unpack(void* buf)
   uint16_t serverMapVersion;
   buf = nboUnpackUShort(buf, serverMapVersion);
   if (serverMapVersion != mapVersion) {
-    DEBUG1 ("WorldBuilder::unpack() bad map version\n");
+    logDebugMessage(1,"WorldBuilder::unpack() bad map version\n");
     return NULL;
   }
 
@@ -71,7 +70,7 @@ void* WorldBuilder::unpack(void* buf)
   if (uncompress ((Bytef*)uncompressedWorld, &destLen,
 		  (Bytef*)compressedWorld, compressedSize) != Z_OK) {
     delete[] uncompressedWorld;
-    DEBUG1 ("WorldBuilder::unpack() could not decompress\n");
+    logDebugMessage(1,"WorldBuilder::unpack() could not decompress\n");
     return NULL;
   }
   char* uncompressedEnd = uncompressedWorld + uncompressedSize;;
@@ -141,12 +140,12 @@ void* WorldBuilder::unpack(void* buf)
   nboUseErrorChecking(false);
   if (nboGetBufferError()) {
     delete[] uncompressedWorld;
-    DEBUG1 ("WorldBuilder::unpack() overrun\n");
+    logDebugMessage(1,"WorldBuilder::unpack() overrun\n");
     return NULL;
   }
   if ((char*)buf != uncompressedEnd) {
     delete[] uncompressedWorld;
-    DEBUG1 ("WorldBuilder::unpack() ending mismatch (%i)\n",
+    logDebugMessage(1,"WorldBuilder::unpack() ending mismatch (%i)\n",
 	    (char*)buf - uncompressedEnd);
     return NULL;
   }
@@ -157,7 +156,7 @@ void* WorldBuilder::unpack(void* buf)
   buf = nboUnpackUShort(buf, code);
   if ((code != WorldCodeEnd) || (len != WorldCodeEndSize)) {
     delete[] uncompressedWorld;
-    DEBUG1 ("WorldBuilder::unpack() bad ending\n");
+    logDebugMessage(1,"WorldBuilder::unpack() bad ending\n");
     return NULL;
   }
 
@@ -185,10 +184,18 @@ void* WorldBuilder::unpack(void* buf)
 
   world->makeLinkMaterial();
 
+  world->makeMeshDrawMgrs();
+
   // NOTE: relying on checkCollisionManager() to do the first loading
   //       of ColiisionManager, because the BZDB variables come in later,
   //       and would cause a double loading if we did it now.
 
+  if (debugLevel >= 3) {
+    TimeKeeper end = TimeKeeper::getCurrent();
+    const float elapsed = (float)(end - start);
+    logDebugMessage(0,"WorldBuilder::unpack() processed in %f seconds.\n", elapsed);
+  }
+
   return buf;
 }
 
@@ -224,15 +231,11 @@ void* WorldBuilder::unpackGameSettings(void* buf)
 
 void WorldBuilder::preGetWorld()
 {
-  // if no inertia gameStyle then make sure accelerations are zero (disabled)
-  if (!(world->gameStyle & short(InertiaGameStyle))) {
-    setInertia(0.0, 0.0);
-  }
-
   // prepare players array
   if (world->players) {
     delete[] world->players;
   }
+  // FIXME
   // world->maxPlayers do not work as bzfs uses more player slot than
   // real players. Any tcp connection is assigned a slot.
   // So I put now 216. We should fix it though.
@@ -283,12 +286,6 @@ void WorldBuilder::setGameStyle(short gameStyle)
   world->gameStyle = gameStyle;
 }
 
-void WorldBuilder::setInertia(float linearAccel,	float angularAccel)
-{
-  world->linearAcceleration = linearAccel;
-  world->angularAcceleration = angularAccel;
-}
-
 void WorldBuilder::setMaxPlayers(int maxPlayers)
 {
   world->maxPlayers = maxPlayers;
