@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef	__WORLDBUILDER_H__
@@ -15,18 +15,6 @@
 
 #include "common.h"
 
-/* system interface headers */
-#include <vector>
-
-/* common interface headers */
-#include "WallObstacle.h"
-#include "MeshObstacle.h"
-#include "BoxBuilding.h"
-#include "PyramidBuilding.h"
-#include "BaseBuilding.h"
-#include "Teleporter.h"
-#include "TetraBuilding.h"
-
 /* local interface headers */
 #include "World.h"
 
@@ -45,7 +33,6 @@ class WorldBuilder {
     World*		peekWorld();	// doesn't give up ownership
 
     void		setGameStyle(short gameStyle);
-    void		setInertia(float linearAccel, float angularAccel);
     void		setMaxPlayers(int maxPlayers);
     void		setMaxShots(int maxSimultaneousShots);
     void		setMaxFlags(int maxFlags);
