@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,10 +7,11 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#include "common.h"
+// get our interface
+#include "bzflag.h"
 
 /* system headers */
 #include <assert.h>
@@ -37,8 +38,8 @@
 /* common headers */
 #include "Address.h"
 #include "BZDBCache.h"
+#include "BZDBLocal.h"
 #include "BundleMgr.h"
-#include "BzfDisplay.h"
 #include "BzfMedia.h"
 #include "BzfVisual.h"
 #include "BzfWindow.h"
@@ -49,13 +50,13 @@
 #include "ErrorHandler.h"
 #include "FileManager.h"
 #include "FontManager.h"
+#include "GUIOptionsMenu.h"
 #include "KeyManager.h"
 #include "OSFile.h"
 #include "OpenGLGState.h"
 #include "ParseColor.h"
 #include "PlatformFactory.h"
 #include "Protocol.h"
-#include "SceneRenderer.h"
 #include "ServerListCache.h"
 #include "StateDatabase.h"
 #include "Team.h"
@@ -70,23 +71,27 @@
 
 /* local headers */
 #include "ActionBinding.h"
-#include "MainWindow.h"
 #include "ServerStartMenu.h"
 #include "callbacks.h"
 #include "playing.h"
 #include "sound.h"
+#include "playing.h"
 
 // invoke incessant rebuilding for build versioning
 #include "version.h"
 
+// defaults for bzdb
+#include "defaultBZDB.h"
+
+// client prefrences
+#include "clientConfig.h"
 
 int beginendCount = 0;
 
-extern std::vector<std::string>& getSilenceList();
 const char*		argv0;
 static bool		anonymous = false;
 static std::string	anonymousName("anonymous");
-static std::string	alternateConfig;
+std::string		alternateConfig;
 static bool		noAudio = false;
 struct tm		userTime;
 bool			echoToConsole = false;
@@ -95,120 +100,7 @@ int			debugLevel = 0;
 
 static BzfDisplay*	display = NULL;
 
-// default database entries
-struct DefaultDBItem {
-  const char*			name;
-  const char*			value;
-  bool				persistent;
-  StateDatabase::Permission	permission;
-  StateDatabase::Callback	callback;
-};
 
-static DefaultDBItem	defaultDBItems[] = {
-  { "udpnet",			"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "timedate",			"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "email",			"default",		true,	StateDatabase::ReadWrite,	NULL },
-  { "team",			"Rogue",		true,	StateDatabase::ReadWrite,	NULL },
-  { "list",			DefaultListServerURL,	true,	StateDatabase::ReadWrite,	NULL },
-  { "motdServer",		DefaultMOTDServer,	true,	StateDatabase::ReadWrite,	NULL },
-  { "volume",			"10",			true,	StateDatabase::ReadWrite,	NULL },
-  { "latitude",			"37.5",			true,	StateDatabase::ReadWrite,	NULL },
-  { "longitude",		"122",			true,	StateDatabase::ReadWrite,	NULL },
-  { "radarSort",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "radarStyle",		"2",			true,	StateDatabase::ReadWrite,	NULL },
-  { "radarTankPixels",		"2.0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "coloredradarshots",	"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "linedradarshots",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "sizedradarshots",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "panelopacity",		"0.3",			true,	StateDatabase::ReadWrite,	NULL },
-  { "radarsize",		"4",			true,	StateDatabase::ReadWrite,	NULL },
-  { "mouseboxsize",		"5",			true,	StateDatabase::ReadWrite,	NULL },
-  { "cpanelfontsize",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "scorefontsize",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "colorful",			"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "showtabs",			"2",			true,   StateDatabase::ReadWrite,	NULL },
-  { "underlineColor",		"cyan",			true,	StateDatabase::ReadWrite,	NULL },
-  { "zbuffer",			"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "killerhighlight",		"2",			true,	StateDatabase::ReadWrite,	NULL },
-  { "serverCacheAge",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "slowKeyboard",		"0",			false,	StateDatabase::ReadWrite,	NULL },
-  { "displayRadarFlags",	"1",			false,	StateDatabase::ReadWrite,	NULL },
-  { "displayMainFlags",		"1",			false,	StateDatabase::ReadWrite,	NULL },
-  { "displayScore",		"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "displayZoom",		"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "displayFlagHelp",		"1",			true,	StateDatabase::ReadWrite,	setFlagHelp },
-  { "displayConsole",		"1",			false,	StateDatabase::ReadWrite,	NULL },
-  { "displayRadar",		"1",			false,	StateDatabase::ReadWrite,	NULL },
-  { "displayRadarRange",	"0.5",			false,	StateDatabase::ReadWrite,	NULL },
-  { "displayFOV",		"60.0",			false,  StateDatabase::ReadWrite,	NULL },
-  { "roamZoomMax",		"120",			false,	StateDatabase::ReadWrite,	NULL },
-  { "roamZoomMin",		"15",			false,	StateDatabase::ReadWrite,	NULL },
-  { "maxQuality",		"3",			false,	StateDatabase::ReadWrite,	NULL },
-  { "groundTexRepeat",		"0.1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "groundHighResTexRepeat",	"0.05",			true,	StateDatabase::ReadWrite,	NULL },
-  { "boxWallTexRepeat",		"1.5",			true,	StateDatabase::ReadWrite,	NULL },
-  { "boxWallHighResTexRepeat",	"5.0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "pyrWallTexRepeat",		"3.0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "pyrWallHighResTexRepeat",	"8.0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "allowInputChange",		"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "pulseDepth",		"0.4",			true,	StateDatabase::ReadWrite,	NULL },
-  { "pulseRate",		"1.0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "userRainScale",		"1.0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "userMirror",		"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "showTreads",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "animatedTreads",		"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "userTrackFade",		"1.0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "trackMarkCulling",		"3",			true,	StateDatabase::ReadWrite,	NULL },
-  { "scrollPages",		"20",			true,	StateDatabase::ReadWrite,	NULL },
-  { "remoteSounds",		"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "leadingShotLine",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "saveIdentity",		"2",			true,	StateDatabase::ReadWrite,	NULL },
-  { "showCollisionGrid",	"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "showCullingGrid",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "showCoordinates",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-  { "jumpTyping",		"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "maxCacheMB",		"32",			true,	StateDatabase::ReadWrite,	NULL },
-  { "doDownloads",		"1",			true,	StateDatabase::ReadWrite,	NULL },
-  { "updateDownloads",		"0",			true,	StateDatabase::ReadWrite,	NULL },
-
-  // default texture names
-  { "stdGroundTexture",		"std_ground",		true,	StateDatabase::ReadWrite,	NULL },
-  { "zoneGroundTexture",	"zone_ground",		true,	StateDatabase::ReadWrite,	NULL },
-  { "boxWallTexture",		"boxwall",		true,	StateDatabase::ReadWrite,	NULL },
-  { "boxTopTexture",		"roof",			true,	StateDatabase::ReadWrite,	NULL },
-  { "pyrWallTexture",		"pyrwall",		true,	StateDatabase::ReadWrite,	NULL },
-  { "cautionTexture",		"caution",		true,	StateDatabase::ReadWrite,	NULL },
-  { "waterTexture",		"water",		true,	StateDatabase::ReadWrite,	NULL },
-
-  // default fonts
-  { "consoleFont",		"VeraMonoBold",		true,	StateDatabase::ReadWrite,	NULL },
-  { "sansSerifFont",		"TogaSansBold",		true,	StateDatabase::ReadWrite,	NULL },
-  { "serifFont",		"TogaSerifBold",	true,	StateDatabase::ReadWrite,	NULL },
-
-  // team based object sufixes
-  { "tankTexture",		"tank",			true,	StateDatabase::ReadWrite,	NULL },
-  { "boltTexture",		"bolt",			true,	StateDatabase::ReadWrite,	NULL },
-  { "laserTexture",		"laser",		true,	StateDatabase::ReadWrite,	NULL },
-  { "baseTopTexture",		"basetop",		true,	StateDatabase::ReadWrite,	NULL },
-  { "baseWallTexture",		"basewall",		true,	StateDatabase::ReadWrite,	NULL },
-
-  // team prefixes
-  { "redTeamPrefix",		"red_",			true,	StateDatabase::ReadWrite,	NULL },
-  { "blueTeamPrefix",		"blue_",		true,	StateDatabase::ReadWrite,	NULL },
-  { "greenTeamPrefix",		"green_",		true,	StateDatabase::ReadWrite,	NULL },
-  { "purpleTeamPrefix",		"purple_",		true,	StateDatabase::ReadWrite,	NULL },
-  { "rabbitTeamPrefix",		"rabbit_",		true,	StateDatabase::ReadWrite,	NULL },
-  { "hunterTeamPrefix",		"hunter_",		true,	StateDatabase::ReadWrite,	NULL },
-  { "rogueTeamPrefix",		"rogue_",		true,	StateDatabase::ReadWrite,	NULL },
-
-  // type prefixes
-  { "superPrefix",		"super_",		true,	StateDatabase::ReadWrite,	NULL },
-
-  // URL timeouts
-  { "httpTimeout",		"15",			true,	StateDatabase::ReadWrite,	NULL }
-
-
-};
 
 #ifdef ROBOT
 // ROBOT -- tidy up
@@ -220,229 +112,13 @@ int numRobotTanks = 0;
 // application initialization
 //
 
-static const char*	configQualityValues[] = {
-				"low",
-				"medium",
-				"high",
-				"experimental"
-			};
-static const char*	configViewValues[] = {
-				"normal",
-				"stereo",
-				"stacked",
-				"three",
-				"anaglyph",
-				"interlaced"
-			};
-
-static std::string	getOldConfigFileName()
+// so that Windows can kill the wsa stuff if needed
+int bail ( int returnCode )
 {
-#if !defined(_WIN32)
-
-  std::string name = getConfigDirName();
-  name += "config";
-
-  // add in hostname on UNIX
-  if (getenv("HOST")) {
-    name += ".";
-    name += getenv("HOST");
-  }
-
-  return name;
-
-#elif defined(_WIN32) /* !defined(_WIN32) */
-
-  // get location of personal files from system.  this appears to be
-  // the closest thing to a home directory on windows.  use root of
-  // C drive as a default in case we can't get the path or it doesn't
-  // exist.
-  std::string oldConfigName = "bzflag19.bzc";
-  std::string name = getConfigDirName();
-  name += oldConfigName;
-  return name;
-
-#endif /* !defined(_WIN32) */
-}
-
-#if !defined(_WIN32)		// who uses this sucker any more?
-static std::string	getReallyOldConfigFileName()
-{
-  std::string name = getConfigDirName();
-  name += "config";
-  return name;
-}
+#ifdef _WIN32
+	WSACleanup();
 #endif
-
-std::string getCurrentConfigFileName(void)
-{
-  std::string configFile = BZ_CONFIG_FILE_NAME;
-
-  std::string name = getConfigDirName(BZ_CONFIG_DIR_VERSION);
-  name += configFile;
-
-#if !defined(_WIN32)
-  // add in hostname on UNIX
-  if (getenv("HOST")) {
-    name += ".";
-    name += getenv("HOST");
-  }
-#endif
-  return name;
-}
-
-// this function will look for the config, if it's not there,
-// it will TRY and find an old one and copy it
-// so that the update function can upgrade it to the current version
-// the assumption is that there is a unique config per version
-void findConfigFile(void)
-{
-  // look for the current file
-  std::string configName = getCurrentConfigFileName();
-  FILE *fp = fopen(configName.c_str(), "rb");
-  if (fp) {
-    // we found the current file, nothing to do, just return
-    fclose(fp);
-    return;
-  }
-
-  // try and find the old file
-  std::string oldConfigName = getOldConfigFileName();
-  fp = fopen(oldConfigName.c_str(), "rb");
-  if (fp) {
-    // there is an old config so lets copy it to the new dir and let the update take care of it.
-#if defined(_WIN32)
-    fclose(fp);
-    // make the dir if we need to
-    mkdir(getConfigDirName(BZ_CONFIG_DIR_VERSION).c_str());
-    // copy the old config to the new dir location with the new name
-    CopyFile(oldConfigName.c_str(), configName.c_str(),true);
-
-#else	// the other OSs should do what they need to do
-    mkdir(getConfigDirName(BZ_CONFIG_DIR_VERSION).c_str(), 0755);
-
-    FILE *newFile = fopen(configName.c_str(),"wb");
-    if (newFile) {
-      fseek(fp, 0, SEEK_END);
-      int len = ftell(fp);
-      fseek(fp, 0, SEEK_SET);
-
-      unsigned char* temp = (unsigned char*) malloc(len);
-
-      fread(temp, len, 1, fp);
-      fwrite(temp, len, 1, newFile);
-
-      free(temp);
-
-      fclose(newFile);
-      fclose(fp);
-    }
-#endif
-  }
-
-  // try and find the REALLY old file
-  // who uses this sucker any more?
-#if !defined(_WIN32)
-  std::string realyOldConfigName = getReallyOldConfigFileName();
-  fp = fopen(realyOldConfigName.c_str(), "rb");
-  if (fp) {
-    // there is an old config so lets copy it to the new dir and let the update take care of it.
-    // apparently only linux needs this so do the magic
-    mkdir(getConfigDirName(BZ_CONFIG_DIR_VERSION).c_str(), 0755);
-
-    FILE *newFile = fopen(configName.c_str(),"wb");
-    if (newFile) {
-      fseek(fp, 0, SEEK_END);
-      int len = ftell(fp);
-      fseek(fp, 0, SEEK_SET);
-
-      unsigned char* temp = (unsigned char*) malloc(len);
-
-      fread(temp, len, 1, fp);
-      fwrite(temp, len, 1, newFile);
-
-      free(temp);
-      fclose(newFile);
-      fclose(fp);
-    }
-  }
-#endif
-}
-
-void updateConfigFile(void)
-{
-  int		configVersion = 0;
-  if (BZDB.isSet("config_version"))
-    configVersion = (int)BZDB.eval("config_version");
-
-  switch (configVersion) {
-  case 0: // 1.10-1.12
-    // update from old unversioned config
-    // roaming fixes - remove keys bound to "roam translate *" and "roam rotate *"
-    KEYMGR.unbindCommand("roam translate left");
-    KEYMGR.unbindCommand("roam translate right");
-    KEYMGR.unbindCommand("roam translate up");
-    KEYMGR.unbindCommand("roam translate down");
-    KEYMGR.unbindCommand("roam translate forward");
-    KEYMGR.unbindCommand("roam translate backward");
-    KEYMGR.unbindCommand("roam rotate left");
-    KEYMGR.unbindCommand("roam rotate right");
-    KEYMGR.unbindCommand("roam rotate up");
-    KEYMGR.unbindCommand("roam rotate down");
-    KEYMGR.unbindCommand("roam rotate stop");
-
-    // add new default keybindings if there's no conflict
-
-    // iconify
-    BzfKeyEvent key;
-    if (KEYMGR.stringToKeyEvent("F4", key)
-	&& (KEYMGR.get(key, true) == ""))
-      KEYMGR.bind(key, true, "iconify");
-    // toggle console & radar
-    if (KEYMGR.stringToKeyEvent("Q", key)
-	&& (KEYMGR.get(key, true) == ""))
-      KEYMGR.bind(key, true, "toggleRadar");
-    if (KEYMGR.stringToKeyEvent("W", key)
-	&& (KEYMGR.get(key, true) == ""))
-      KEYMGR.bind(key, true, "toggleConsole");
-    // controlpanel tabs - all or nothing
-    if (KEYMGR.stringToKeyEvent("Shift+F1", key)
-	&& (KEYMGR.get(key, true) == "")
-	&& KEYMGR.stringToKeyEvent("Shift+F2", key)
-	&& (KEYMGR.get(key, true) == "")
-	&& KEYMGR.stringToKeyEvent("Shift+F3", key)
-	&& (KEYMGR.get(key, true) == "")
-	&& KEYMGR.stringToKeyEvent("Shift+F4", key)
-	&& (KEYMGR.get(key, true) == "")) {
-      KEYMGR.stringToKeyEvent("Shift+F1", key);
-      KEYMGR.bind(key, true, "messagepanel all");
-      KEYMGR.stringToKeyEvent("Shift+F2", key);
-      KEYMGR.bind(key, true, "messagepanel chat");
-      KEYMGR.stringToKeyEvent("Shift+F3", key);
-      KEYMGR.bind(key, true, "messagepanel server");
-      KEYMGR.stringToKeyEvent("Shift+F4", key);
-      KEYMGR.bind(key, true, "messagepanel misc");
-    }
-
-    // TODO - any other breaking changes from 1.10 to 2.0
-
-  case 1: // 1.11.20
-    if (KEYMGR.stringToKeyEvent("Tab", key)
-	&& (KEYMGR.get(key, false) == ""))
-      KEYMGR.bind(key, false, "jump");
-
-  case 2: // 2.0
-    break; // no action, current version
-
-  default: // hm, we don't know about this one...
-    printError(TextUtils::format("Config file is tagged version \"%d\", "
-				   "which was not expected (too new perhaps). "
-				   "Trying to load anyhow.", configVersion));
-    break;
-  }
-
-  // set us as the updated version
-  configVersion = BZ_CONFIG_FILE_VERSION;
-  BZDB.setInt("config_version", configVersion);
+	return returnCode;
 }
 
 static void		setTeamColor(TeamColor team, const std::string& str)
@@ -468,10 +144,15 @@ static void		setVisual(BzfVisual* visual)
   visual->setDoubleBuffer(true);
   visual->setRGBA(1, 1, 1, 0);
 
-  // ask for a zbuffer if not disabled.  we might choose not to use it
-  // if we do ask for it.
-  if (!BZDB.isSet("zbuffer") || BZDB.get("zbuffer") != "disable")
-    visual->setDepth(16);
+  // ask for a zbuffer if not disabled.  we might
+  // choose not to use it if we do ask for it.
+  if (!BZDB.isSet("zbuffer") || (BZDB.get("zbuffer") != "disable")) {
+    int depthLevel = 16;
+    if (BZDB.isSet("forceDepthBits")) {
+      depthLevel = BZDB.evalInt("forceDepthBits");
+    }
+    visual->setDepth(depthLevel);
+  }
 
   // optional
 #if defined(DEBUG_RENDERING)
@@ -488,31 +169,34 @@ static void		setVisual(BzfVisual* visual)
 static void		usage()
 {
   printFatalError("usage: %s"
-	" [-3dfx]"
-	" [-no3dfx]"
+	" [-3dfx] [-no3dfx]"
 	" [-anonymous]"
 	" [-badwords <filterfile>]"
 	" [-config <configfile>]"
+	" [-configdir <config dir name>]"
 	" [-d | -debug]"
-	" [-dir | -directory <data-directory>]"
-	" [-echo]"
-	" [-echoAnsi]"
-	" [-geometry <geometry-spec>]"
+	" [-date mm/dd/yyyy]"
+	" [{-dir | -directory} <data-directory>]"
+	" [-e | -echo]"
+	" [-ea | -echoAnsi]"
+	" [{-g | -geometry} <geometry-spec>]"
+	" [-h | -help | --help]"
 	" [-latitude <latitude>] [-longitude <longitude>]"
 	" [-list <list-server-url>] [-nolist]"
 	" [-locale <locale>]"
+	" [-m | -mute]"
+	" [-motd <motd-url>] [-nomotd]"
 	" [-multisample]"
-	" [-mute]"
 #ifdef ROBOT
 	" [-solo <num-robots>]"
 #endif
 	" [-team {red|green|blue|purple|rogue|observer}]"
 	" [-time hh:mm:ss] [-notime]"
-	" [-version]"
+	" [-v | -version | --version]"
 	" [-view {normal|stereo|stacked|three|anaglyph|interlaced}]"
 	" [-window]"
 	" [-zoom <zoom-factor>]"
-	" [callsign@]server[:port]\n\nExiting.", argv0);
+	" [callsign[:password]@]server[:port]\n\nExiting.", argv0);
   if (display != NULL) {
     delete display;
     display=NULL;
@@ -539,16 +223,20 @@ static void		parse(int argc, char** argv)
     } else if (strcmp(argv[i], "-config") == 0) {
       checkArgc(i, argc, argv[i]);
       // the setting has already been done in parseConfigName()
-    } else if ((strcmp(argv[i], "-d") == 0) ||
+	} else if (strcmp(argv[i], "-configdir") == 0) {
+		checkArgc(i, argc, argv[i]);
+		// the setting has already been done in parseConfigName()
+	} else if ((strcmp(argv[i], "-d") == 0) ||
 	       (strcmp(argv[i], "-debug") == 0)) {
       debugLevel++;
     } else if ((strcmp(argv[i], "-dir") == 0) ||
 	       (strcmp(argv[i], "-directory") == 0)) {
       checkArgc(i, argc, argv[i]);
-      if (strlen(argv[i]) == 0)
+      if (strlen(argv[i]) == 0) {
 	BZDB.unset("directory");
-	  else
-		BZDB.set("directory", argv[i]);
+      } else {
+	BZDB.set("directory", argv[i]);
+      }
     } else if (strcmp(argv[i], "-e") == 0 || strcmp(argv[i], "-echo") == 0) {
       echoToConsole = true;
     } else if (strcmp(argv[i], "-ea") == 0 || strcmp(argv[i], "-echoAnsi") == 0) {
@@ -591,7 +279,7 @@ static void		parse(int argc, char** argv)
     } else if (strcmp(argv[i], "-list") == 0) {
       checkArgc(i, argc, argv[i]);
       if (strcmp(argv[i], "default") == 0) {
-	BZDB.unset("list");
+	BZDB.set("list", BZDB.getDefault("list"));
       } else {
 	startupInfo.listServerURL = argv[i];
 	BZDB.set("list", argv[i]);
@@ -601,7 +289,14 @@ static void		parse(int argc, char** argv)
       BZDB.set("locale", argv[i]);
     } else if (strcmp(argv[i], "-motd") == 0) {
       checkArgc(i, argc, argv[i]);
-      BZDB.set("motdServer", argv[i]);
+      if (strcmp(argv[i], "default") == 0) {
+	BZDB.set("motdServer", BZDB.getDefault("motdServer"));
+      } else {
+	BZDB.set("motdServer", argv[i]);
+      }
+      BZDB.unset("disableMOTD");
+    } else if (strcmp(argv[i], "-nomotd") == 0) {
+      BZDB.set("disableMOTD", "1");
     } else if (strcmp(argv[i], "-nolist") == 0) {
       startupInfo.listServerURL = "";
       BZDB.set("list", "");
@@ -648,6 +343,7 @@ static void		parse(int argc, char** argv)
 		getAppVersion(),
 		getProtocolVersion(),
 		bzfcopyright);
+      bail(0);
       exit(0);
     } else if (strcmp(argv[i], "-window") == 0) {
       BZDB.set("_window", "1");
@@ -777,6 +473,13 @@ static void		parse(int argc, char** argv)
 
 static void		parseConfigName(int argc, char** argv)
 {
+	for (int i = 1; i < argc; i++) {
+		if (strcmp(argv[i], "-configdir") == 0) {
+			checkArgc(i, argc, argv[i]);
+			setCustomConfigDir(argv[i]);
+			alternateConfig += argv[i];
+		}
+	}
   for (int i = 1; i < argc; i++) {
     if (strcmp(argv[i], "-config") == 0) {
       checkArgc(i, argc, argv[i]);
@@ -792,8 +495,7 @@ static void		parseConfigName(int argc, char** argv)
 // (so user won't have to wait through performance testing again).
 //
 
-void			dumpResources(BzfDisplay* display,
-				SceneRenderer& renderer)
+void			dumpResources()
 {
   // collect new configuration
 
@@ -819,28 +521,24 @@ void			dumpResources(BzfDisplay* display,
   if (isSoundOpen()) {
     BZDB.set("volume", TextUtils::format("%d", getSoundVolume()));
   }
-  GLint value;
-  glGetIntegerv(GL_DEPTH_BITS, &value);
-  if (value == 0) {
-    BZDB.set("zbuffer", "0");
+
+  if (RENDERER.getWindow().getWindow()->hasGammaControl()) {
+    BZDB.set("gamma",
+	     TextUtils::format("%f", RENDERER.getWindow().getWindow()->getGamma()));
   }
 
-  if (renderer.getWindow().getWindow()->hasGammaControl()) {
-    BZDB.set("gamma", TextUtils::format("%f", renderer.getWindow().getWindow()->getGamma()));
-  }
-
-  BZDB.set("quality", configQualityValues[renderer.useQuality()]);
+  BZDB.set("quality", configQualityValues[RENDERER.useQuality()]);
   if (!BZDB.isSet("_window") && display->getResolution() != -1 &&
       display->getResolution(display->getResolution())) {
     BZDB.set("resolution", display->getResolution(display->getResolution())->name);
   }
   BZDB.set("startcode", ServerStartMenu::getSettings());
 
-  BZDB.set("panelopacity", TextUtils::format("%f", renderer.getPanelOpacity()));
+  BZDB.set("panelopacity", TextUtils::format("%f", RENDERER.getPanelOpacity()));
 
-  BZDB.set("radarsize", TextUtils::format("%d", renderer.getRadarSize()));
+  BZDB.set("radarsize", TextUtils::format("%d", RENDERER.getRadarSize()));
 
-  BZDB.set("mouseboxsize", TextUtils::format("%d", renderer.getMaxMotionFactor()));
+  BZDB.set("mouseboxsize", TextUtils::format("%d", RENDERER.getMaxMotionFactor()));
 
   // don't save these configurations
   BZDB.setPersistent("_window", false);
@@ -879,8 +577,7 @@ static bool		needsFullscreen()
 
   // fullscreen if view is not default
   std::string value = BZDB.get("view");
-  for (int i = 1; i < (int)(sizeof(configViewValues) /
-			sizeof(configViewValues[0])); i++)
+  for (int i = 1; i < (int)configViewValues.size(); i++)
     if (value == configViewValues[i])
       return true;
 
@@ -911,6 +608,7 @@ static void createCacheSignature ()
   return;
 }
 
+
 //
 // main()
 //	initialize application and enter event loop
@@ -937,8 +635,7 @@ int			main(int argc, char** argv)
 		    (int)LOBYTE(wsaData.wVersion),
 		    (int)HIBYTE(wsaData.wVersion),
 		    major, minor);
-    WSACleanup();
-    return 1;
+    return bail(1);
   }
 #endif
 
@@ -955,9 +652,37 @@ int			main(int argc, char** argv)
     printFatalError("This release expired on %s. \n"
 		"Please upgrade to the latest release. \n"
 		"Exiting.", timeBombString());
+	bail(0);
     exit(0);
   }
 
+#if defined(_WIN32)
+  {
+    /* write HKEY_CURRENT_USER\Software\BZFlag\CurrentRunningPath with the
+     * current path.  this lets Xfire know that this bzflag.exe running from
+     * here really is bzflag, not some imposter.
+     * since it may be useful to someone else, it's not protected by USE_XFIRE
+     */
+
+    // get our path
+    char temppath[MAX_PATH], temppath2[MAX_PATH];
+    char tempdrive[10];
+    GetModuleFileName(NULL, temppath, MAX_PATH);
+    // strip filename/extension
+    _splitpath(temppath, tempdrive, temppath2, NULL, NULL);
+    _makepath(temppath, tempdrive, temppath2, NULL, NULL);
+
+    // write the registry key in question
+    HKEY key = NULL;
+    if (RegCreateKeyEx(HKEY_CURRENT_USER, "Software\\BZFlag",
+	0, NULL, REG_OPTION_VOLATILE, KEY_ALL_ACCESS, NULL,
+	&key, NULL) == ERROR_SUCCESS) {
+      RegSetValueEx(key, "CurrentRunningPath", 0, REG_SZ, (LPBYTE)temppath,
+		   (DWORD)strlen(temppath));
+    }
+  }
+#endif
+
   createCacheSignature();
 
   // initialize global objects and classes
@@ -975,6 +700,8 @@ int			main(int argc, char** argv)
   }
 
   BZDBCache::init();
+  BZDBLOCAL.init();
+
   Flags::init();
 
   if (getenv("BZFLAGID")) {
@@ -995,17 +722,8 @@ int			main(int argc, char** argv)
   CommandsStandard::add();
   unsigned int i;
 
-  // prepare DB entries
-  for (i = 0; i < countof(defaultDBItems); ++i) {
-    assert(defaultDBItems[i].name != NULL);
-    if (defaultDBItems[i].value != NULL) {
-      BZDB.set(defaultDBItems[i].name, defaultDBItems[i].value);
-      BZDB.setDefault(defaultDBItems[i].name, defaultDBItems[i].value);
-    }
-    BZDB.setPersistent(defaultDBItems[i].name, defaultDBItems[i].persistent);
-    BZDB.setPermission(defaultDBItems[i].name, defaultDBItems[i].permission);
-    BZDB.addCallback(defaultDBItems[i].name, defaultDBItems[i].callback, NULL);
-  }
+  initConfigData();
+  loadBZDBDefaults();
 
   // parse for the config filename
   // the rest of the options are parsed after the config file
@@ -1088,6 +806,12 @@ int			main(int argc, char** argv)
     // ignore window name in config file (it's used internally)
     BZDB.unset("_window");
     BZDB.unset("_multisample");
+
+
+    // however, if the "__window" setting is enabled, let it through
+    if (BZDB.isSet("__window"))
+      if (BZDB.isTrue("__window"))
+	BZDB.set("_window", "1");
   }
 
   // use UDP? yes
@@ -1096,6 +820,18 @@ int			main(int argc, char** argv)
   // parse arguments
   parse(argc, argv);
 
+#ifdef _WIN32
+  // this is cheap but it will work on windows
+  // clear out the stdout file
+  if (echoToConsole){
+	  FILE	*fp = fopen ("stdout.txt","w");
+	  if (fp) {
+		  fprintf(fp,"stdout started\r\n" );
+		  fclose(fp);
+	  }
+  }
+#endif
+
   if (BZDB.isSet("directory")) {
     //Convert to unix paths so that escaping isn't an issue
     std::string directory = BZDB.get("directory");
@@ -1203,7 +939,7 @@ int			main(int argc, char** argv)
   display = platformFactory->createDisplay(NULL, NULL);
   if (!display) {
     printFatalError("Can't open display.  Exiting.");
-    return 1;
+    return bail(1);
   }
 
   // choose visual
@@ -1214,7 +950,7 @@ int			main(int argc, char** argv)
   BzfWindow* window = platformFactory->createWindow(display, visual);
   if (!window->isValid()) {
     printFatalError("Can't create window.  Exiting.");
-    return 1;
+    return bail(1);
   }
   window->setTitle("bzflag");
 
@@ -1233,31 +969,34 @@ int			main(int argc, char** argv)
 
   // set data directory if user specified
   if (BZDB.isSet("directory")) {
+    /* already specified, so just set/use it */
     PlatformFactory::getMedia()->setMediaDirectory(BZDB.get("directory"));
   } else {
 
-    // !!! fix this stupid check.. GetMacOSXDataPath() is NULL without app bundle.
-
-#if defined(__APPLE__)
-    extern char *GetMacOSXDataPath(void);
-    PlatformFactory::getMedia()->setMediaDirectory(GetMacOSXDataPath());
-    BZDB.set("directory", GetMacOSXDataPath());
-    BZDB.setPersistent("directory", false);
-#elif (defined(_WIN32) || defined(WIN32))
+#if (defined(_WIN32) || defined(WIN32))
     char exePath[MAX_PATH];
     GetModuleFileName(NULL,exePath,MAX_PATH);
     char* last = strrchr(exePath,'\\');
     if (last)
       *last = '\0';
     strcat(exePath,"\\data");
-    PlatformFactory::getMedia()->setMediaDirectory(exePath);
+    BzfMedia *media = PlatformFactory::getMedia();
+    if (media)
+      media->setMediaDirectory(exePath);
 #else
     // It's only checking existence of l10n directory
-    DIR *localedir = opendir("data/l10n/");
-    if (localedir == NULL) {
-      PlatformFactory::getMedia()->setMediaDirectory(INSTALL_DATA_DIR);
-    } else {
+    std::string mediadir = DEFAULT_MEDIA_DIR;
+    mediadir += "/l10n";
+    DIR *localedir = opendir(mediadir.c_str());
+    if (localedir != NULL) {
+      /* found 'data' dir */
+      BzfMedia *media = PlatformFactory::getMedia();
+      if (media)
+	media->setMediaDirectory(DEFAULT_MEDIA_DIR);
       closedir(localedir);
+    } else {
+      /* bah, just set the compile-time path */
+      PlatformFactory::getMedia()->setMediaDirectory(INSTALL_DATA_DIR);
     }
 #endif
   }
@@ -1269,7 +1008,7 @@ int			main(int argc, char** argv)
   // try to get a font - only returns -1 if there are no fonts at all
   if (fm.getFaceID(BZDB.get("consoleFont")) < 0) {
     printFatalError("No fonts found  (the -directory option may help).  Exiting");
-    return 1;
+    return bail(1);
   }
 
   // initialize locale system
@@ -1318,8 +1057,10 @@ int			main(int argc, char** argv)
   // the resolution to use)
   const bool useFullscreen = needsFullscreen();
   if (useFullscreen) {
+#ifndef HAVE_SDL
     // tell window to be fullscreen
-    window->setFullscreen();
+    window->setFullscreen(true);
+#endif
 
     // set the size if one was requested.  this overrides the default
     // size (which is the display or passthrough size).
@@ -1336,10 +1077,9 @@ int			main(int argc, char** argv)
   // now make the main window wrapper.  this'll cause the OpenGL context
   // to be bound for the first time.
   MainWindow* pmainWindow = new MainWindow(window, joystick);
-  MainWindow& mainWindow = *pmainWindow;
-  if (mainWindow.isInFault()) {
+  if (pmainWindow->isInFault()) {
     printFatalError("Error creating window - Exiting");
-    return 1;
+    return bail(1);
   }
 
   std::string videoFormat;
@@ -1356,7 +1096,7 @@ int			main(int argc, char** argv)
   // set fullscreen again so MainWindow object knows it's full screen
   if (useFullscreen)
     // this will also call window create
-    mainWindow.setFullscreen();
+    pmainWindow->setFullscreen();
   else
     window->create();
 
@@ -1370,10 +1110,10 @@ int			main(int argc, char** argv)
 
   // set main window's minimum size (arbitrary but should be big enough
   // to see stuff in control panel)
-  mainWindow.setMinSize(256, 192);
+  pmainWindow->setMinSize(256, 192);
 
   // initialize graphics state
-  mainWindow.getWindow()->makeCurrent();
+  pmainWindow->getWindow()->makeCurrent();
   glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
   glClearDepth(1.0);
   glClearStencil(0);
@@ -1391,6 +1131,7 @@ int			main(int argc, char** argv)
       delete display;
       display=NULL;
     }
+	bail(1);
     exit(1);
   }
   OpenGLGState::init();
@@ -1443,10 +1184,9 @@ int			main(int argc, char** argv)
       delete display;
       display=NULL;
     }
+	bail(1);
     exit(1);
 
-  } else {
-    DEBUG3("Using the following GL_RENDERER: %s\n", glRenderer);
   }
 
   // add the zbuffer callback here, after the OpenGL context is initialized
@@ -1463,8 +1203,9 @@ int			main(int argc, char** argv)
 
   // set gamma if set in resources and we have gamma control
   if (BZDB.isSet("gamma")) {
-    if (mainWindow.getWindow()->hasGammaControl())
-      mainWindow.getWindow()->setGamma((float)atof(BZDB.get("gamma").c_str()));
+    if (pmainWindow->getWindow()->hasGammaControl())
+      pmainWindow->getWindow()->setGamma
+	((float)atof(BZDB.get("gamma").c_str()));
   }
 
   // set the scene renderer's window
@@ -1477,10 +1218,10 @@ int			main(int argc, char** argv)
     }
     if (BZDB.isSet("quality")) {
       std::string value = BZDB.get("quality");
-      const int qualityLevels = countof(configQualityValues);
-      for (int i = 0; i < qualityLevels; i++) {
-	if (value == configQualityValues[i]) {
-	  RENDERER.setQuality(i);
+      const int qualityLevels = (int)configQualityValues.size();
+      for (int j = 0; j < qualityLevels; j++) {
+	if (value == configQualityValues[j]) {
+	  RENDERER.setQuality(j);
 	  break;
 	}
       }
@@ -1496,8 +1237,7 @@ int			main(int argc, char** argv)
     if (BZDB.isSet("view")) {
       RENDERER.setViewType(SceneRenderer::Normal);
       std::string value = BZDB.get("view");
-      for (int i = 0; i < (int)(sizeof(configViewValues) /
-				sizeof(configViewValues[0])); i++)
+      for (i = 0; i < configViewValues.size(); i++)
 	if (value == configViewValues[i]) {
 	  RENDERER.setViewType((SceneRenderer::ViewType)i);
 	  break;
@@ -1509,28 +1249,30 @@ int			main(int argc, char** argv)
 
     if (BZDB.isSet("panelopacity"))
       RENDERER.setPanelOpacity(BZDB.eval("panelopacity"));
+
     if (BZDB.isSet("radarsize"))
-      RENDERER.setRadarSize(atoi(BZDB.get("radarsize").c_str()));
+      RENDERER.setRadarSize(BZDB.getIntClamped("radarsize", 0, GUIOptionsMenu::maxRadarSize));
+
     if (BZDB.isSet("mouseboxsize"))
       RENDERER.setMaxMotionFactor(atoi(BZDB.get("mouseboxsize").c_str()));
   }
 
   // grab the mouse only if allowed
   if (BZDB.isSet("mousegrab") && !BZDB.isTrue("mousegrab")) {
-    mainWindow.setNoMouseGrab();
-    mainWindow.enableGrabMouse(false);
+    pmainWindow->setNoMouseGrab();
+    pmainWindow->enableGrabMouse(false);
   } else {
-    mainWindow.enableGrabMouse(true);
+    pmainWindow->enableGrabMouse(true);
   }
 
   // set window quadrant
   if (RENDERER.getViewType() == SceneRenderer::ThreeChannel)
-    mainWindow.setQuadrant(MainWindow::UpperRight);
+    pmainWindow->setQuadrant(MainWindow::UpperRight);
   else if (RENDERER.getViewType() == SceneRenderer::Stacked)
-    mainWindow.setQuadrant(MainWindow::LowerHalf);
+    pmainWindow->setQuadrant(MainWindow::LowerHalf);
 #ifndef USE_GL_STEREO
   else if (RENDERER.getViewType() == SceneRenderer::Stereo)
-    mainWindow.setQuadrant(MainWindow::UpperRight);
+    pmainWindow->setQuadrant(MainWindow::UpperRight);
 #endif
 
   // clear the grid graphics if they are not accessible
@@ -1578,11 +1320,14 @@ int			main(int argc, char** argv)
   startPlaying(display, RENDERER);
 
   // save resources
-  dumpResources(display, RENDERER);
-  if (alternateConfig == "")
-    CFGMGR.write(getCurrentConfigFileName());
-  else
-    CFGMGR.write(alternateConfig);
+  if (BZDB.isTrue("saveSettings")) {
+    dumpResources();
+    if (alternateConfig == "") {
+      CFGMGR.write(getCurrentConfigFileName());
+    } else {
+      CFGMGR.write(alternateConfig);
+    }
+  }
 
   // shut down
   if (filter != NULL)
@@ -1599,6 +1344,18 @@ int			main(int argc, char** argv)
   delete bm;
   Flags::kill();
 
+#if defined(_WIN32)
+  {
+    /* clear HKEY_CURRENT_USER\Software\BZFlag\CurrentRunningPath if it
+     * exists */
+    HKEY key = NULL;
+    if (RegOpenKeyEx(HKEY_CURRENT_USER, "Software\\BZFlag",
+	0, KEY_ALL_ACCESS, &key) == ERROR_SUCCESS) {
+      RegSetValueEx(key, "CurrentRunningPath", 0, REG_SZ, (LPBYTE)"\0", 1);
+    }
+  }
+#endif
+
 #ifdef _WIN32
   // clean up
   WSACleanup();
