@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -227,7 +227,9 @@ static std::string cmdIconify(const std::string&,
 {
   if (args.size() != 0)
     return "usage: iconify";
-  mainWindow->iconify();
+
+  if (!BZDB.isTrue("Win32NoMin"))
+	 mainWindow->iconify();
   return std::string();
 }
 
@@ -432,12 +434,21 @@ static std::string cmdAutoPilot(const std::string&,
   if (args.size() != 0)
     return "usage: autopilot";
 
-  if (BZDB.isTrue(StateDatabase::BZDB_DISABLEBOTS)) {
+  // don't enable autopilot until we've fully joined and checked the value
+  // of the server-side _disableBots
+  if (! BZDB.isSet(StateDatabase::BZDB_DISABLEBOTS))
+    return std::string();
+
+  LocalPlayer *myTank = LocalPlayer::getMyTank();
+
+  if (!BZDB.isTrue(StateDatabase::BZDB_TANKWIDTH))
+    return std::string();
+
+  if (BZDB.isTrue(StateDatabase::BZDB_DISABLEBOTS) && ! myTank->isAutoPilot()) {
     hud->setAlert(0, "autopilot not allowed on this server", 1.0f, true);
     return std::string();
   }
 
-  LocalPlayer *myTank = LocalPlayer::getMyTank();
   if (myTank != NULL && myTank->getTeam() != ObserverTeam) {
     if (myTank->isAutoPilot()) {
 
@@ -504,11 +515,12 @@ static std::string cmdViewZoom(const std::string&,
     return "usage: viewZoom {in|out|toggle}";
 
   float fov = BZDB.eval("displayFOV");
+  float defFov = BZDB.eval("defaultFOV");
 
   if (args[0] == "out") {
     fov += 1.0f;
-    if (fov > 60.0f)
-      fov = 60.0f;
+    if (fov > defFov)
+      fov = defFov;
     BZDB.setFloat("displayFOV", fov);
   } else if (args[0] == "in") {
     fov -= 1.0f;
@@ -517,20 +529,20 @@ static std::string cmdViewZoom(const std::string&,
     BZDB.setFloat("displayFOV", fov);
   } else if (args[0] == "toggle") {
     if (fov < 15.5f) {
-      fov = 60.0f;
+      fov = defFov;
     } else {
       fov = 15.0f;
     }
     BZDB.setFloat("displayFOV", fov);
     // also toggle the observer fov
-    if (ROAM.getZoom() != 60.0f) {
-      ROAM.setZoom(60.0f);
+    if (ROAM.getZoom() != defFov) {
+      ROAM.setZoom(defFov);
     } else {
       ROAM.setZoom(15.0f);
     }
   } else if (args[0] == "reset") {
-    fov = 60.0f;
-    ROAM.setZoom(60.0f);
+    fov = defFov;
+    ROAM.setZoom(defFov);
     BZDB.setFloat("displayFOV", fov);
   } else {
     return "usage: viewZoom {in|out|toggle|reset}";
