@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,20 +7,27 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#include <math.h>
-#include "common.h"
+// interface header
 #include "sound.h"
-#include "global.h"
+
+// system headers
+#include <vector>
+#include <map>
+#include <string.h>
+
+// common headers
+#include "BzfMedia.h"
 #include "TimeKeeper.h"
 #include "PlatformFactory.h"
-#include "BzfMedia.h"
+#include "BZDBCache.h"
+#include "TextUtils.h"
 
-const float		SpeedOfSound = 343.0f;			// meters/sec
-const int		MaxEvents = 30;
-const float		InterAuralDistance = 0.1f;		// meters
+static const float SpeedOfSound = 343.0f;		// meters/sec
+static const int   MaxEvents = 30;
+static const float InterAuralDistance = 0.1f;		// meters
 
 /*
  * producer/consumer shared data types and defines
@@ -45,17 +52,85 @@ struct SoundCommand {
     float		data[4];
 };
 
-typedef struct {
+class AudioSamples
+{
+public:
+	AudioSamples();
+	AudioSamples(const AudioSamples& r);
+	~AudioSamples();
+	AudioSamples& operator = (const AudioSamples& r);
+
   long			length;		/* total number samples in data */
   long			mlength;	/* total number samples in mono */
+	long			rmlength;	/* total number samples in monoRaw */
   double		dmlength;	/* mlength as a double minus one */
   float*		data;		/* left in even, right in odd */
   float*		mono;		/* avg of channels for world sfx */
   float*		monoRaw;	/* mono with silence before & after */
   double		duration;	/* time to play sound */
-} AudioSamples;
+  std::string	file;
+};
 
 
+AudioSamples::AudioSamples()
+{
+	length = 0;
+	mlength = 0;
+	rmlength = 0;
+	dmlength = 0;
+	data = NULL;
+	mono = NULL;
+	monoRaw = NULL;
+	duration = 0;
+}
+
+AudioSamples::~AudioSamples()
+{
+	if (data)
+		delete[] data;
+
+	if (monoRaw)
+		delete[] monoRaw;
+}
+
+AudioSamples& AudioSamples::operator = ( const AudioSamples& r)
+{
+	if (data)
+		delete[] data;
+
+	if (monoRaw)
+		delete[] monoRaw;
+
+	length = r.length;
+	mlength = r.mlength;
+	dmlength = r.dmlength;
+	rmlength = r.rmlength;
+	data = new float[length];
+	memcpy(data,r.data,sizeof(float)*length);
+	monoRaw = new float[rmlength];
+	memcpy(monoRaw,r.monoRaw,sizeof(float)*rmlength);
+	duration = r.duration;
+
+	mono = monoRaw + (r.mono-r.monoRaw);
+	file = r.file;
+	return *this;
+}
+
+AudioSamples::AudioSamples ( const AudioSamples& r)
+{
+	length = r.length;
+	mlength = r.mlength;
+	dmlength = r.dmlength;
+	rmlength = r.rmlength;
+	data = new float[length];
+	memcpy(data,r.data,sizeof(float)*length);
+	monoRaw = new float[rmlength];
+	memcpy(monoRaw,r.monoRaw,sizeof(float)*rmlength);
+	mono = monoRaw + (r.mono-r.monoRaw);
+	duration = r.duration;
+	file = r.file;
+}
+
 /*
  * local functions
  */
@@ -65,7 +140,7 @@ static void		audioLoop(void*);
 static bool		allocAudioSamples();
 static void		freeAudioSamples(void);
 static int		resampleAudio(const float* in,
-				int frames, int rate, AudioSamples* out);
+				int frames, int rate, AudioSamples* out, const char *name);
 
 
 /*
@@ -102,51 +177,121 @@ static const char*	soundFiles[] = {
 				"thief",
 				"burrow",
 				"message_private",
-				"message_team"
+				"message_team",
+				"message_admin",
+				"flap",
+				"bounce"
 			};
-#define	SFX_COUNT	((int)(countof(soundFiles)))
+#define	STD_SFX_COUNT	((int)(countof(soundFiles)))	// the number of "Standard" sounds
 
 /*
  * producer/consumer shared arena
  */
 
-static AudioSamples	soundSamples[SFX_COUNT];
+static std::vector<AudioSamples>	soundSamples;
+
+static std::map<std::string, int> customSamples;
+
 static long		audioBufferSize;
 static int		soundLevel;
 
+static BzfMedia*	media = NULL;
+
+/* speed of sound stuff */
+static float		timeSizeOfWorld;		/* in seconds */
+static TimeKeeper	startTime;
+static double		prevTime, curTime;
+
+typedef struct {
+  AudioSamples*		samples;		/* event sound effect */
+  bool		busy;			/* true iff in use */
+  long			ptr;			/* current sample */
+  double		ptrFracLeft;		/* fractional step ptr */
+  double		ptrFracRight;		/* fractional step ptr */
+  int			flags;			/* state info */
+  float			x, y, z;		/* event location */
+  double		time;			/* time of event */
+  float			lastLeftAtten;
+  float			lastRightAtten;
+  float			dx, dy, dz;		/* last relative position */
+  float			d;			/* last relative distance */
+  float			dLeft;			/* last relative distance */
+  float			dRight;			/* last relative distance */
+  float			amplitude;		/* last sfx amplitude */
+} SoundEvent;
+
+/* list of events currently pending */
+static SoundEvent	events[MaxEvents];
+static int		portUseCount;
+static double		endTime;
+
+/* fade in/out table */
+const int		FadeDuration = 16;
+static float		fadeIn[FadeDuration];
+static float		fadeOut[FadeDuration];
+
+/* scratch buffer for adding contributions from sources */
+static float*		scratch;
+
+static bool		usingSameThread = false;
+
+static bool		audioInnerLoop();
 
 void			openSound(const char*)
 {
+  unsigned int i;
+
   if (usingAudio) return;			// already opened
 
-  if (!PlatformFactory::getMedia()->openAudio())
+  media = PlatformFactory::getMedia();
+  if (!media->openAudio())
     return;
 
-  // initialize buffers
-  for (int i = 0; i < SFX_COUNT; i++) {
-    soundSamples[i].data = NULL;
-    soundSamples[i].mono = NULL;
-    soundSamples[i].monoRaw = NULL;
-  }
-
   // open audio data files
   if (!allocAudioSamples()) {
-    PlatformFactory::getMedia()->closeAudio();
+    media->closeAudio();
 #ifndef DEBUG
     std::cout << "WARNING: Unable to open audio data files" << std::endl;
 #endif
     return;					// couldn't get samples
   }
 
+  audioBufferSize = media->getAudioBufferChunkSize() << 1;
+
+  /* initialize */
+  float worldSize = BZDBCache::worldSize;
+  timeSizeOfWorld = 1.414f * worldSize / SpeedOfSound;
+  for (i = 0; i < (int)MaxEvents; i++) {
+    events[i].samples = NULL;
+    events[i].busy = false;
+  }
+  portUseCount = 0;
+  for (i = 0; i < (int)FadeDuration; i += 2) {
+    fadeIn[i] = fadeIn[i+1] =
+		sinf((float)(M_PI / 2.0 * (double)i / (double)(FadeDuration-2)));
+    fadeOut[i] = fadeOut[i+1] = 1.0f - fadeIn[i];
+  }
+  scratch = new float[audioBufferSize];
+
+  startTime = TimeKeeper::getCurrent();
+  curTime = 0.0;
+  endTime = -1.0;
+
+  usingSameThread = !media->hasAudioThread();
+
+  if (media->hasAudioCallback()) {
+    media->startAudioCallback(audioInnerLoop);
+  } else {
   // start audio thread
-  if (!PlatformFactory::getMedia()->startAudioThread(audioLoop, NULL)) {
-    PlatformFactory::getMedia()->closeAudio();
+  if (!usingSameThread && !media->startAudioThread(audioLoop, NULL)) {
+    media->closeAudio();
     freeAudioSamples();
 #ifndef DEBUG
     std::cout << "WARNING: Unable to start the audio thread" << std::endl;
 #endif
     return;
   }
+  }
 
   setSoundVolume(10);
 
@@ -173,6 +318,8 @@ void			closeSound(void)
   // reset audio hardware
   PlatformFactory::getMedia()->closeAudio();
 
+  delete[] scratch;
+
   // free memory used for sfx samples
   freeAudioSamples();
 
@@ -188,14 +335,15 @@ static bool		allocAudioSamples()
 {
   bool anyFile = false;
 
-  for (int i = 0; i < SFX_COUNT; i++) {
+	// load the default samples
+  for (int i = 0; i < STD_SFX_COUNT; i++) {
     // read it
     int numFrames, rate;
-    float* samples = PlatformFactory::getMedia()->
-				readSound(soundFiles[i], numFrames, rate);
-    if (samples && resampleAudio(samples, numFrames, rate, soundSamples + i)) {
+    float* samples = PlatformFactory::getMedia()->readSound(soundFiles[i], numFrames, rate);
+		AudioSamples newSample;
+    if (samples && resampleAudio(samples, numFrames, rate, &newSample,soundFiles[i]))
       anyFile = true;
-    }
+		soundSamples.push_back(newSample);
     delete[] samples;
   }
 
@@ -204,14 +352,12 @@ static bool		allocAudioSamples()
 
 static void		freeAudioSamples(void)
 {
-  for (int i = 0; i < SFX_COUNT; i++) {
-    delete[] soundSamples[i].data;
-    delete[] soundSamples[i].monoRaw;
-  }
+	// do nothing.
+	// the samples are self freeing now
 }
 
 static int		resampleAudio(const float* in,
-				int frames, int rate, AudioSamples* out)
+				int frames, int rate, AudioSamples* out, const char* name)
 {
   // attenuation on all sounds
   static const float GlobalAtten = 0.5f;
@@ -234,13 +380,15 @@ static int		resampleAudio(const float* in,
 		   (float)PlatformFactory::getMedia()->getAudioOutputRate());
 
   // fill in samples structure
+  out->file = name;
   out->length = 2 * frames;
   out->mlength = out->length >> 1;
+  out->rmlength = out->mlength + 2 * safetyMargin;
   out->dmlength = double(out->mlength - 1);
   out->duration = (float)out->mlength /
 		  (float)PlatformFactory::getMedia()->getAudioOutputRate();
   out->data = new float[out->length];
-  out->monoRaw = new float[out->mlength + 2 * safetyMargin];
+  out->monoRaw = new float[out->rmlength];
   out->mono = out->monoRaw + safetyMargin;
   if (!out->data || !out->monoRaw) {
     delete[] out->data;
@@ -300,19 +448,31 @@ void			speedSoundReceiver(float vx, float vy, float vz)
   sendSound(&s);
 }
 
-void			playWorldSound(int soundCode,
-				float x, float y, float z, bool important)
+void			playSound(int soundCode, const float pos[3],
+				  bool important, bool localSound)
+{
+  if (localSound) {
+    playLocalSound(soundCode);
+  } else {
+    playWorldSound(soundCode, pos, important);
+  }
+  return;
+}
+
+void			playWorldSound(int soundCode, const float pos[3],
+				       bool important)
 {
   if (soundLevel <= 0) {
     return;
   }
   SoundCommand s;
+  if ((int)soundSamples.size() <= soundCode) return;
   if (soundSamples[soundCode].length == 0) return;
   s.cmd = important ? SQC_IWORLD_SFX : SQC_WORLD_SFX;
   s.code = soundCode;
-  s.data[0] = x;
-  s.data[1] = y;
-  s.data[2] = z;
+  s.data[0] = pos[0];
+  s.data[1] = pos[1];
+  s.data[2] = pos[2];
   s.data[3] = 0.0f;
   sendSound(&s);
 }
@@ -323,6 +483,7 @@ void			playLocalSound(int soundCode)
     return;
   }
   SoundCommand s;
+  if ((int)soundSamples.size() <= soundCode) return;
   if (soundSamples[soundCode].length == 0) return;
   s.cmd = SQC_LOCAL_SFX;
   s.code = soundCode;
@@ -333,6 +494,31 @@ void			playLocalSound(int soundCode)
   sendSound(&s);
 }
 
+void			playLocalSound(std::string sound)
+{
+	int  soundCode = -1;
+
+	std::map<std::string,int>::iterator itr = customSamples.find(TextUtils::tolower(sound));
+	if (itr == customSamples.end())
+	{
+		int numFrames, rate;
+		float* samples = PlatformFactory::getMedia()->readSound(TextUtils::tolower(sound).c_str(), numFrames, rate);
+		AudioSamples newSample;
+		if (samples && resampleAudio(samples, numFrames, rate, &newSample,sound.c_str()))
+		{
+			soundSamples.push_back(newSample);
+			soundCode = (int)soundSamples.size()-1;
+			customSamples[TextUtils::tolower(sound)] = soundCode;
+		}
+		delete[] samples;
+	}
+	else
+		soundCode = itr->second;
+
+	if (soundCode > 0)
+		playLocalSound(soundCode);
+}
+
 void			playFixedSound(int soundCode,
 						float x, float y, float z)
 {
@@ -340,6 +526,7 @@ void			playFixedSound(int soundCode,
     return;
   }
   SoundCommand s;
+  if ((int)soundSamples.size() <= soundCode) return;
   if (soundSamples[soundCode].length == 0) return;
   s.cmd = SQC_FIXED_SFX;
   s.code = soundCode;
@@ -388,29 +575,6 @@ int			getSoundVolume()
  *	and ptr is incremented by 2 for each (stereo) sample.
  */
 
-typedef struct {
-  AudioSamples*		samples;		/* event sound effect */
-  bool		busy;			/* true iff in use */
-  long			ptr;			/* current sample */
-  double		ptrFracLeft;		/* fractional step ptr */
-  double		ptrFracRight;		/* fractional step ptr */
-  int			flags;			/* state info */
-  float			x, y, z;		/* event location */
-  double		time;			/* time of event */
-  float			lastLeftAtten;
-  float			lastRightAtten;
-  float			dx, dy, dz;		/* last relative position */
-  float			d;			/* last relative distance */
-  float			dLeft;			/* last relative distance */
-  float			dRight;			/* last relative distance */
-  float			amplitude;		/* last sfx amplitude */
-} SoundEvent;
-
-/* list of events currently pending */
-static SoundEvent	events[MaxEvents];
-static int		portUseCount;
-static double		endTime;
-
 /* last position of the receiver */
 static float		lastX, lastY, lastZ, lastTheta;
 static float		lastXLeft, lastYLeft;
@@ -428,19 +592,6 @@ static float		velY;
 static float		volumeAtten = 1.0f;
 static int		mutingOn = 0;
 
-/* scratch buffer for adding contributions from sources */
-static float*		scratch;
-
-/* fade in/out table */
-const int		FadeDuration = 16;
-static float		fadeIn[FadeDuration];
-static float		fadeOut[FadeDuration];
-
-/* speed of sound stuff */
-static float		timeSizeOfWorld;		/* in seconds */
-static TimeKeeper	startTime;
-static double		prevTime, curTime;
-
 static void		recalcEventDistance(SoundEvent* e)
 {
   e->dx = e->x - lastX;
@@ -553,7 +704,7 @@ static void		receiverMoved(float* data)
   lastYRight = lastY - 0.5f * InterAuralDistance * leftY;
 
   for (int i = 0; i < MaxEvents; i++)
-    if (events[i].busy && events[i].flags & SEF_WORLD)
+    if (events[i].busy && (events[i].flags & SEF_WORLD))
       recalcEventDistance(events + i);
 }
 
@@ -921,16 +1072,10 @@ static int		findBestLocalSlot()
 //
 // audioLoop() simply generates samples and keeps the audio hw fed
 //
-static BzfMedia*	media = NULL;
-static bool		usingSameThread = false;
-
-static bool		audioInnerLoop(bool noWaiting)
+static bool		audioInnerLoop()
 {
     int i, j;
 
-    // sleep until audio buffers hit low water mark or new command available
-    media->audioSleep(true, noWaiting ? 0.0 : endTime);
-
     /* get time step */
     prevTime = curTime;
     curTime = TimeKeeper::getCurrent() - startTime;
@@ -980,7 +1125,7 @@ static bool		audioInnerLoop(bool noWaiting)
 	  if (i == MaxEvents) break;
 	  event = events + i;
 
-	  event->samples = soundSamples + cmd.code;
+	  event->samples = &soundSamples[cmd.code];
 	  event->ptr = 0;
 	  event->flags = 0;
 	  event->time = curTime;
@@ -1002,7 +1147,7 @@ static bool		audioInnerLoop(bool noWaiting)
 	  if (i == MaxEvents) break;
 	  event = events + i;
 
-	  event->samples = soundSamples + cmd.code;
+	  event->samples = &soundSamples[cmd.code];
 	  event->ptrFracLeft = 0.0;
 	  event->ptrFracRight = 0.0;
 	  event->flags = SEF_WORLD | SEF_IGNORING;
@@ -1023,7 +1168,7 @@ static bool		audioInnerLoop(bool noWaiting)
 	  if (i == MaxEvents) break;
 	  event = events + i;
 
-	  event->samples = soundSamples + cmd.code;
+	  event->samples = &soundSamples[cmd.code];
 	  event->ptrFracLeft = 0.0;
 	  event->ptrFracRight = 0.0;
 	  event->flags = SEF_FIXED | SEF_WORLD;
@@ -1079,48 +1224,23 @@ static bool		audioInnerLoop(bool noWaiting)
 
 static void		audioLoop(void*)
 {
-  int i;
-
-  media = PlatformFactory::getMedia();
-  audioBufferSize = media->getAudioBufferChunkSize() << 1;
-
-  /* initialize */
-  float worldSize = BZDB.eval(StateDatabase::BZDB_WORLDSIZE);
-  timeSizeOfWorld = 1.414f * worldSize / SpeedOfSound;
-  for (i = 0; i < MaxEvents; i++) {
-    events[i].samples = NULL;
-    events[i].busy = false;
-  }
-  portUseCount = 0;
-  for (i = 0; i < FadeDuration; i += 2) {
-    fadeIn[i] = fadeIn[i+1] =
-		sinf(M_PI / 2.0f * (float)i / (float)(FadeDuration-2));
-    fadeOut[i] = fadeOut[i+1] = 1.0f - fadeIn[i];
-  }
-  scratch = new float[audioBufferSize];
-
-  startTime = TimeKeeper::getCurrent();
-  curTime = 0.0;
-  endTime = -1.0;
-
-  // if using same thread then return immediately
-  usingSameThread = !media->hasAudioThread();
-  if (usingSameThread) return;
-
   // loop until requested to stop
-  bool done = false;
-  while (!done) {
-    if (audioInnerLoop(false))
-      done = true;
-  }
+  while (true) {
+    // sleep until audio buffers hit low water mark or new command available
+    media->audioSleep(true, endTime);
 
-  delete[] scratch;
+    if (audioInnerLoop())
+      break;
+  }
 }
 
 void			updateSound()
 {
-  if (isSoundOpen() && usingSameThread)
-    audioInnerLoop(true);
+  if (isSoundOpen() && usingSameThread) {
+    // sleep until audio buffers hit low water mark or new command available
+    media->audioSleep(true, 0.0);
+    audioInnerLoop();
+  }
 }
 
 // Local Variables: ***
