@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -15,6 +15,7 @@
 
 #include <vector>
 #include <string>
+#include <string.h>
 
 #include "TimeKeeper.h"
 #include "Address.h"
@@ -269,6 +270,14 @@ private:
       and removes those who have. */
   void expire();
 
+  /** This function removes bans dependent on their origin
+      (local or from master list) **/
+  void purge(bool master);
+
+  /** This function purges all local bans
+      so the local banfile can be reloaded **/
+  void purgeLocals(void);
+
   typedef std::vector<BanInfo> banList_t;
   banList_t banList;
 
