@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -52,7 +52,10 @@ void CustomGate::writeToGroupDef(GroupDefinition *groupdef) const
 		   fabsf(size[0]), fabsf(size[1]), fabsf(size[2]),
 		   border, horizontal, driveThrough, shootThrough);
 
-  tele->setName(telename);
+  if (!telename.size() && name.size())
+    tele->setName(name);
+  else
+    tele->setName(telename);
 
   groupdef->addObstacle(tele);
 }
