@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef __CUSTOM_MESH_H__
@@ -50,6 +50,10 @@ class CustomMesh : public WorldFileObstacle {
     int phydrv;
     bool noclusters;
     bool smoothBounce;
+    bool decorative;
+
+    std::vector<std::string> lodOptions;
+    class MeshDrawInfo* drawInfo;
 
     CustomMeshFace* face;
     std::vector<CustomMeshFace*> faces;
