@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -12,6 +12,9 @@
 
 #include "common.h"
 
+// system headers
+#include <string.h>
+
 /* interface header */
 #include "CustomWaterLevel.h"
 
