@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,19 +7,22 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* interface header */
 #include "CustomWeapon.h"
 
+
 /* system headers */
 #include <sstream>
 #include <string>
+#include <string.h>
 #include <math.h>
 
 /* local implementation headers */
 #include "WorldWeapons.h"
+#include "TextUtils.h"
 
 TimeKeeper CustomWeapon::sync = TimeKeeper::getCurrent();
 
@@ -34,8 +37,11 @@ CustomWeapon::CustomWeapon()
   initdelay = 10.0f;
   delay.push_back(10.0f);
   type = Flags::Null;
-}
+  teamColor = RogueTeam;
 
+  triggerType = bz_eNullEvent;
+  eventTeam = -1;
+}
 
 bool CustomWeapon::read(const char *cmd, std::istream& input) {
   if (strcmp(cmd, "initdelay") == 0) {
@@ -53,8 +59,7 @@ bool CustomWeapon::read(const char *cmd, std::istream& input) {
       if (d < minWeaponDelay) {
 	std::cout << "skipping weapon delay of " << d << " seconds" << std::endl;
 	continue;
-      }
-      else {
+      } else {
 	delay.push_back(d);
       }
     }
@@ -69,6 +74,14 @@ bool CustomWeapon::read(const char *cmd, std::istream& input) {
     if (type == NULL)
       return false;
   }
+  else if (strcmp(cmd, "color") == 0) {
+    int team;
+    if (!(input >> team)) {
+      std::cout << "weapon color requires a team number" << std::endl;
+    } else {
+      teamColor = (TeamColor)team;
+    }
+  }
   else if (strcmp(cmd, "tilt") == 0) {
     if (!(input >> tilt)) {
       std::cout << "weapon tilt requires a value" << std::endl;
@@ -76,6 +89,28 @@ bool CustomWeapon::read(const char *cmd, std::istream& input) {
     // convert to radians
     tilt = (float)(tilt * (M_PI / 180.0));
   }
+  else if (strcmp(cmd, "trigger") == 0) {
+    std::string triggerName;
+    input >> triggerName;
+
+    triggerType = bz_eNullEvent;
+
+    TextUtils::tolower(triggerName);
+    if (triggerName == "oncap") {
+      triggerType = bz_eCaptureEvent;
+    } else if (triggerName == "onspawn") {
+      triggerType = bz_ePlayerSpawnEvent;
+    } else if (triggerName == "ondie") {
+      triggerType = bz_ePlayerDieEvent;
+    } else {
+      std::cout << "weapon trigger type:" << triggerName << " unknown" << std::endl;
+      return true;
+    }
+    logDebugMessage(4,"Adding world weapon triggered '%s'\n", triggerName.c_str());
+  }
+  else if (strcmp(cmd, "eventteam") == 0) {
+    input >> eventTeam;
+  }
   else if (!WorldFileLocation::read(cmd, input)) {
     return false;
   }
@@ -83,10 +118,17 @@ bool CustomWeapon::read(const char *cmd, std::istream& input) {
   return true;
 }
 
-
 void CustomWeapon::writeToWorld(WorldInfo* world) const
 {
-  world->addWeapon(type, pos, rotation, tilt, initdelay, delay, sync);
+  if (triggerType == bz_eNullEvent) {
+    world->addWeapon(type, pos, rotation, tilt,
+		     teamColor, initdelay, delay, sync);
+  } else {
+    WorldWeaponGlobalEventHandler* eventHandler =
+      new WorldWeaponGlobalEventHandler(type, pos, rotation, tilt,
+					(TeamColor)eventTeam);
+    worldEventManager.addEvent(triggerType, eventHandler);
+  }
 }
 
 
