@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 #ifndef __CUSTOMZONE_H__
 #define __CUSTOMZONE_H__
@@ -15,9 +15,20 @@
 /* interface header */
 #include "WorldFileLocation.h"
 
+/* system headers */
+#include <vector>
+#include <string>
+#include <map>
+
 /* local implementation headers */
-#include "WorldInfo.h"
-#include "EntryZones.h"
+//#include "WorldInfo.h"
+class WorldInfo;
+class FlagType;
+
+
+typedef std::vector<std::string> QualifierList;
+typedef std::map<FlagType*, int> ZoneFlagMap; // type, count
+
 
 class CustomZone : public WorldFileLocation {
   public:
@@ -31,36 +42,55 @@ class CustomZone : public WorldFileLocation {
     void addFlagSafety(float x, float y, WorldInfo* worldInfo);
 
     const QualifierList &getQualifiers() const;
+    const ZoneFlagMap& getZoneFlagMap() const;
+
     float getArea() const;
     void getRandomPoint(float *pt) const;
     float getDistToPoint (const float *pos) const;
 
-  protected:
+  public:
+    static const std::string& getFlagIdQualifier(int flagId);
+    static int getFlagIdFromQualifier(const std::string&);
+
+    static const std::string& getFlagTypeQualifier(FlagType* flagType);
+    static FlagType* getFlagTypeFromQualifier(const std::string&);
+
+    static const std::string& getFlagSafetyQualifier(int team);
+    static int getFlagSafetyFromQualifier(const std::string&);
+
+    static const std::string& getPlayerTeamQualifier(int team);
+    static int getPlayerTeamFromQualifier(const std::string&);
+
+  private:
+    void addZoneFlagCount(FlagType* flagType, int count);
+
+  private:
+    ZoneFlagMap zoneFlagMap;
     QualifierList qualifiers;
 };
 
+
 inline const QualifierList& CustomZone::getQualifiers() const
 {
   return qualifiers;
 }
 
+
+inline const ZoneFlagMap& CustomZone::getZoneFlagMap() const
+{
+  return zoneFlagMap;
+}
+
+
 inline float CustomZone::getArea() const
 {
-  float x = 1.0f, y = 1.0f, z = 1.0f;
-
-  if (size[0] > 1.0f) {
-    x = size[0];
-  }
-  if (size[1] > 1.0f) {
-    y = size[1];
-  }
-  if (size[2] > 1.0f) {
-    z = size[2];
-  }
-
+  float x = (size[0] >= 1.0f) ? size[0] : 1.0f;
+  float y = (size[1] >= 1.0f) ? size[1] : 1.0f;
+  float z = (size[2] >= 1.0f) ? size[2] : 1.0f;
   return (x * y * z);
 }
 
+
 #endif  /* __CUSTOMZONE_H__ */
 
 // Local variables: ***
