@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifdef _MSC_VER
@@ -16,6 +16,7 @@
 #include "common.h"
 #include "Pack.h"
 #include <math.h>
+#include <string.h>
 #include <sstream>
 
 #include "WorldFileObject.h"
@@ -90,14 +91,14 @@ bool WorldFileLocation::read(const char *cmd, std::istream& input)
     transform.addSpin(angle, normal);
   }
   else if (strcasecmp ("xform", cmd) == 0) {
-    std::string name;
-    if (!(input >> name)) {
+    std::string _name;
+    if (!(input >> _name)) {
       std::cout << "parameters errors " << std::endl;
       return false;
     }
-    int xform = TRANSFORMMGR.findTransform(name);
+    int xform = TRANSFORMMGR.findTransform(_name);
     if (xform == -1) {
-      std::cout << "couldn't find Transform: " << name << std::endl;
+      std::cout << "couldn't find Transform: " << _name << std::endl;
     } else {
       transform.addReference(xform);
     }
