@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* interface header */
@@ -28,6 +28,7 @@
 #include "BzMaterial.h"
 #include "PhysicsDriver.h"
 #include "MeshTransform.h"
+#include "MeshDrawInfo.h"
 #include "TimeKeeper.h"
 
 /* obstacle implementation headers */
@@ -44,6 +45,11 @@
 #include "ConeObstacle.h"
 #include "SphereObstacle.h"
 
+/* local implementation headers */
+#include "FlagInfo.h"
+#include "PlayerInfo.h"
+#include "CustomZone.h"
+
 /* compression library header */
 #include "../zlib/zlib.h"
 
@@ -57,6 +63,7 @@ WorldInfo::WorldInfo() :
   gravity = -9.81f;
   waterLevel = -1.0f;
   waterMatRef = NULL;
+	finished = false;
 }
 
 WorldInfo::~WorldInfo()
@@ -64,6 +71,7 @@ WorldInfo::~WorldInfo()
   delete[] database;
   links.clear();
   OBSTACLEMGR.clear();
+	finished = false;
 }
 
 
@@ -94,10 +102,12 @@ void WorldInfo::addZone(const CustomZone *zone)
 }
 
 void WorldInfo::addWeapon(const FlagType *type, const float *origin,
-                          float direction, float tilt,
-			  float initdelay, const std::vector<float> &delay, TimeKeeper &sync)
+			  float direction, float tilt, TeamColor teamColor,
+			  float initdelay, const std::vector<float> &delay,
+			  TimeKeeper &sync)
 {
-  worldWeapons.add(type, origin, direction, tilt, initdelay, delay, sync);
+  worldWeapons.add(type, origin, direction, tilt,
+		   teamColor, initdelay, delay, sync);
 }
 
 void WorldInfo::addWaterLevel (float level, const BzMaterial* matref)
@@ -136,10 +146,10 @@ void WorldInfo::addTeleporter(float x, float y, float z, float r,
 }
 
 void WorldInfo::addBase(const float pos[3], float r,
-			const float size[3], int color,
+			const float _size[3], int color,
 			bool /* drive */, bool /* shoot */)
 {
-  BaseBuilding* base = new BaseBuilding(pos, r, size, color);
+  BaseBuilding* base = new BaseBuilding(pos, r, _size, color);
   OBSTACLEMGR.addWorldObstacle(base);
 }
 
@@ -164,6 +174,8 @@ void WorldInfo::makeWaterMaterial()
   material.setUseTextureAlpha(true); // make sure that alpha is enabled
   material.setUseColorOnTexture(false); // only use the color as a backup
   material.setUseSphereMap(false);
+  material.setNoRadar(true);
+  material.setNoShadow(true);
   waterMatRef = MATERIALMGR.addMaterial(&material);
 
   return;
@@ -184,6 +196,12 @@ WorldWeapons& WorldInfo::getWorldWeapons()
   return worldWeapons;
 }
 
+EntryZones& WorldInfo::getEntryZones()
+{
+  return entryZones;
+}
+
+
 void		    WorldInfo::loadCollisionManager()
 {
   COLLISIONMGR.load();
@@ -229,7 +247,7 @@ bool WorldInfo::rectHitCirc(float dx, float dy, const float *p, float r) const
   return true;
 }
 
-bool WorldInfo::inRect(const float *p1, float angle, const float *size,
+bool WorldInfo::inRect(const float *p1, float angle, const float *_size,
 		       float x, float y, float r) const
 {
   // translate origin
@@ -244,7 +262,7 @@ bool WorldInfo::inRect(const float *p1, float angle, const float *size,
   pb[1] = c * pa[1] + s * pa[0];
 
   // do test
-  return rectHitCirc(size[0], size[1], pb, r);
+  return rectHitCirc(_size[0], _size[1], pb, r);
 }
 
 
@@ -376,24 +394,66 @@ InBuildingType WorldInfo::classifyHit (const Obstacle* obstacle) const
 }
 
 
-bool WorldInfo::getZonePoint(const std::string &qualifier, float *pt) const
+bool WorldInfo::getFlagDropPoint(const FlagInfo* fi, const float* pos,
+				float* pt) const
 {
-  if (!entryZones.getZonePoint(qualifier, pt)) {
-    return false;
-  }
+  FlagType* flagType = fi->flag.type;
+  const int team = (int)flagType->flagTeam;
+  const bool teamFlag = (team != NoTeam);
 
-  return true;
+  if (teamFlag) {
+    const std::string& safetyQual =
+      CustomZone::getFlagSafetyQualifier(team);
+    if (entryZones.getClosePoint(safetyQual, pos, pt)) {
+      return true;
+    }
+  } else {
+    const std::string& idQual =
+      CustomZone::getFlagIdQualifier(fi->getIndex());
+    if (entryZones.getClosePoint(idQual, pos, pt)) {
+      return true;
+    }
+    const std::string& typeQual =
+      CustomZone::getFlagTypeQualifier(flagType);
+    if (entryZones.getClosePoint(typeQual, pos, pt)) {
+      return true;
+    }
+  }
+  return false;
 }
 
 
-bool WorldInfo::getSafetyPoint(const std::string &qualifier,
-			       const float *pos, float *pt) const
+bool WorldInfo::getFlagSpawnPoint(const FlagInfo* fi, float* pt) const
 {
-  if (!entryZones.getSafetyPoint(qualifier, pos, pt)) {
-    return false;
+  FlagType* flagType = fi->flag.type;
+  const int team = (int)flagType->flagTeam;
+  const bool teamFlag = (team != NoTeam);
+
+  const std::string& idQual =
+    CustomZone::getFlagIdQualifier(fi->getIndex());
+  if (entryZones.getRandomPoint(idQual, pt)) {
+    return true;
   }
 
-  return true;
+  if (!teamFlag) {
+    const std::string& typeQual =
+      CustomZone::getFlagTypeQualifier(flagType);
+    if (entryZones.getRandomPoint(typeQual, pt)) {
+      return true;
+    }
+  }
+  return false;
+}
+
+
+bool WorldInfo::getPlayerSpawnPoint(const PlayerInfo* pi, float* pt) const
+{
+  const std::string& teamQual =
+    CustomZone::getPlayerTeamQualifier((int)pi->getTeam());
+  if (entryZones.getRandomPoint(teamQual, pt)) {
+    return true;
+  }
+  return false;
 }
 
 
@@ -414,6 +474,8 @@ void WorldInfo::finishWorld()
     maxHeight = 0.0f;
   }
 
+  finished = true;
+
   return;
 }
 
@@ -499,10 +561,10 @@ int WorldInfo::packDatabase()
   database = gzDB;
   delete[] oldDB;
 
-  DEBUG1 ("Map size: uncompressed = %i, compressed = %i\n",
+  logDebugMessage(1,"Map size: uncompressed = %i, compressed = %i\n",
 	   uncompressedSize, databaseSize);
 
-  DEBUG3("Compression: %.3f seconds\n", endTime - startTime);
+  logDebugMessage(3,"Compression: %.3f seconds\n", endTime - startTime);
 
   return 1;
 }
@@ -522,6 +584,7 @@ int WorldInfo::getUncompressedSize() const
   return uncompressedSize;
 }
 
+
 // Local Variables: ***
 // mode: C++ ***
 // tab-width: 8 ***
