@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifdef _MSC_VER
@@ -20,6 +20,7 @@
 // system headers
 #include <fstream>
 #include <stdio.h>
+#include <string.h>
 
 // local implementation headers
 #include "StateDatabase.h"
@@ -136,146 +137,118 @@ std::string Bundle::getLocalString(const std::string &key) const
 	unmapped.insert( key );
     std::string stripped = stripAnsiCodes (key);
 	std::string debugStr = "Unmapped Locale String: " + stripped + "\n";
-	DEBUG1("%s", debugStr.c_str());
+	logDebugMessage(1,"%s", debugStr.c_str());
       }
     }
     return key;
   }
 }
 
-void Bundle::ensureNormalText(std::string &msg)
-{
-// This is an ugly hack. If you don't like it fix it.
-// BZFlag's font bitmaps don't contain letters with accents, so strip them here
-// Would be nice if some kind sole added them.
+const char utf8bytes[256] = {
+  1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+  1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+  1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+  1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+  1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+  1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+  2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2, 2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,
+  3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3, 4,4,4,4,4,4,4,4,5,5,5,5,6,6,6,6
+};
 
-  for (std::string::size_type i = 0; i < msg.length(); i++) {
-    char c = msg.at(i);
+#if 0
+    // TODO: find the utf-8 values for these
     switch (c) {
-      case '':
-      case '':
-      case '':
-      case '':
-      case '':
-      case '':
+      case '':
+      case '':
 	msg[i] = 'a';
       break;
-      case '':
-	msg[i] = 'a';
-	i++;
-	msg.insert(i, 1, 'a');
-      break;
-      case '':
-      case '':
-	msg[i] = 'a';
-	i++;
-	msg.insert(i, 1, 'e');
-      break;
-      case '':
-      case '':
-      case '':
+      case '':
+      case '':
 	msg[i] = 'A';
       break;
-      case '':
-      case '':
-	msg[i] = 'A';
-	i++;
-	msg.insert(i, 1, 'e');
-      break;
-      case '':
-	msg[i] = 'A';
-	i++;
-	msg.insert(i, 1, 'a');
-      break;
-      case '':
-	msg[i] = 'c';
-      break;
-      case '':
-      case '':
-      case '':
-      case '':
-	msg[i] = 'e';
-      break;
-      case '':
-      case '':
-      case '':
-      case '':
+      case '':
 	msg[i] = 'i';
       break;
-      case '':
-      case '':
-      case '':
-      case '':
+      case '':
 	msg[i] = 'o';
       break;
-      case '':
-      case '':
-	msg[i] = 'o';
-	i++;
-	msg.insert(i, 1, 'e');
-      break;
-      case '':
+      case '':
 	msg[i] = 'O';
       break;
-      case '':
-      case '':
-	msg[i] = 'O';
-	i++;
-	msg.insert(i, 1, 'e');
-      break;
-      case '':
-      case '':
-      case '':
-	msg[i] = 'u';
-      break;
-      case '':
-	msg[i] = 'u';
-	i++;
-	msg.insert(i, 1, 'e');
-      break;
-      case '':
-	msg[i] = 'U';
-	i++;
-	msg.insert(i, 1, 'e');
-      break;
-      case '':
-	msg[i] = 'n';
-      break;
-      case '':
+      case '':
 	msg[i] = 'Y';
       break;
-      case '':
-	msg[i] = 's';
-	i++;
-	msg.insert(i, 1, 's');
-      break;
-      case '':
-      case '':
-	msg[i] = ' ';
-      break;
+    }
+#endif
 
-      default: // A temporary patch, to catch untranslated chars.. To be removed eventually
-	if (((c >= 'A') && (c <= 'Z'))
-	    || ((c >= 'a') && (c <= 'z'))
-	    || ((c >= '0') && (c <= '9'))
-	    || (c == '}') || (c == '{') || (c == ' ')
-	    || (c == ':') || (c == '/') || (c == '-')
-	    || (c == ',') || (c == '&') || (c == '?')
-	    || (c == '<') || (c == '>') || (c == '.')
-	    || (c == '(') || (c == ')') || (c == '%')
-	    || (c == '!') || (c == '+') || (c == '-')
-	    || (c == '$') || (c == ';') || (c == '@')
-	    || (c == '[') || (c == ']')
-	    || (c == '=') || (c == '\''))
-	;
-	else {
-		msg = std::string("unsupported char:") + c;
-		return;
+// TODO: sort this and bsearch it. perhaps divided by utf8 length
+const char *translationTable[][2] = {
+  {"â", "a"}, {"à", "a"}, {"á", "a"}, {"ã", "a"},
+  {"å", "aa"},
+  {"ä", "ae"}, {"æ", "ae"},
+  {"Â", "A"},
+  {"Ä", "AE"}, {"Æ", "AE"},
+  {"Å", "AA"},
+  {"ç", "c"},
+  {"é", "e"}, {"è", "e"}, {"ê", "e"}, {"ë", "e"},
+  {"î", "i"}, {"ï", "i"}, {"í", "i"},
+  {"ô", "o"}, {"ó", "o"}, {"õ", "o"},
+  {"ö", "oe"}, {"ø", "oe"},
+  {"Ö", "OE"}, {"Ø", "OE"},
+  {"û", "u"}, {"ù", "u"}, {"ú", "u"},
+  {"ü", "ue"},
+  {"Ü", "UE"},
+  {"ñ", "n"},
+  {"ß", "ss"},
+  {"¿", "?"},
+  {"¡", "!"},
+};
+
+void Bundle::ensureNormalText(std::string &msg)
+{
+  // BZFlag's font system only supports ascii
+  // convert msg to ascii
+  // If you don't like it fix it.
+
+  for (std::string::size_type i = 0; i < msg.length(); i++) {
+    unsigned char c = msg.at(i);
+    if (((c >= 'A') && (c <= 'Z'))
+	|| ((c >= 'a') && (c <= 'z'))
+	|| ((c >= '0') && (c <= '9'))
+	|| (c == '}') || (c == '{') || (c == ' ')
+	|| (c == ':') || (c == '/') || (c == '-')
+	|| (c == ',') || (c == '&') || (c == '?')
+	|| (c == '<') || (c == '>') || (c == '.')
+	|| (c == '(') || (c == ')') || (c == '%')
+	|| (c == '!') || (c == '+') || (c == '-')
+	|| (c == '$') || (c == ';') || (c == '@')
+	|| (c == '[') || (c == ']')
+	|| (c == '=') || (c == '\'')) {
+      ; // this char's ok by me
+    } else {
+      std::string replacement = "0x";
+      unsigned int trans;
+      // TODO: optimize this
+      for (trans = 0; trans < sizeof(translationTable) / sizeof (char *) / 2; trans++) {
+	if (!strncmp(translationTable[trans][0],&(msg.c_str()[i]),utf8bytes[(int)c])) {
+	  replacement = translationTable[trans][1];
+	  break;
 	}
-      break;
-
+      }
+      if (trans == sizeof(translationTable) / sizeof (char *) / 2) {
+	// didn't find a match
+	for (int j = 0; j < utf8bytes[(int)c]; j++) {
+	//for (int j = 0; j < 1; j++) {
+	  char hexchar[30];
+	  sprintf(hexchar, "%2X", (unsigned char)msg.at(i+j));
+	  replacement += hexchar;
+	}
+      }
+      msg.replace(i,utf8bytes[(int)c],replacement);
+      i += replacement.length() - 1;
     }
   }
+  //std::cout << "\"" + msg + "\"\n";
 }
 
 
