@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #if defined(_MSC_VER)
@@ -25,6 +25,7 @@
 #include <iostream>
 #include <math.h>
 #include <string>
+#include <string.h>
 
 // local implementation headers
 #include "ErrorHandler.h"
@@ -64,7 +65,7 @@ void	_debugLookups(const std::string &name)
     for (std::multimap<int,std::string>::iterator it2 = order.begin(); it2 != order.end(); ++it2) {
       if (-it2->first / interval < 1.0f)
 	break;
-      DEBUG1("%-25s = %.2f acc/sec\n", it2->second.c_str(), -it2->first / interval);
+      logDebugMessage(1,"%-25s = %.2f acc/sec\n", it2->second.c_str(), -it2->first / interval);
     }
     last = now;
   }
@@ -83,6 +84,7 @@ StateDatabase* Singleton<StateDatabase>::_instance = (StateDatabase*)0;
 const std::string StateDatabase::BZDB_AGILITYADVEL	= std::string("_agilityAdVel");
 const std::string StateDatabase::BZDB_AGILITYTIMEWINDOW	= std::string("_agilityTimeWindow");
 const std::string StateDatabase::BZDB_AGILITYVELDELTA	= std::string("_agilityVelDelta");
+const std::string StateDatabase::BZDB_AMBIENTLIGHT	= std::string("_ambientLight");
 const std::string StateDatabase::BZDB_ANGLETOLERANCE    = std::string("_angleTolerance");
 const std::string StateDatabase::BZDB_ANGULARAD		= std::string("_angularAd");
 const std::string StateDatabase::BZDB_AVENUESIZE	= std::string("_avenueSize");
@@ -94,11 +96,18 @@ const std::string StateDatabase::BZDB_BURROWSPEEDAD     = std::string("_burrowSp
 const std::string StateDatabase::BZDB_BURROWANGULARAD   = std::string("_burrowAngularAd");
 const std::string StateDatabase::BZDB_COLDETDEPTH       = std::string("_coldetDepth");
 const std::string StateDatabase::BZDB_COLDETELEMENTS    = std::string("_coldetElements");
+const std::string StateDatabase::BZDB_COUNTDOWNRESDELAY	= std::string("_countdownResumeDelay");
 const std::string StateDatabase::BZDB_CULLDEPTH		= std::string("_cullDepth");
 const std::string StateDatabase::BZDB_CULLELEMENTS      = std::string("_cullElements");
 const std::string StateDatabase::BZDB_CULLOCCLUDERS     = std::string("_cullOccluders");
 const std::string StateDatabase::BZDB_DISABLEBOTS       = std::string("_disableBots");
-const std::string StateDatabase::BZDB_ENDSHOTDETECTION       = std::string("_endShotDetection");
+const std::string StateDatabase::BZDB_DRAWCELESTIAL	= std::string("_drawCelestial");
+const std::string StateDatabase::BZDB_DRAWCLOUDS	= std::string("_drawClouds");
+const std::string StateDatabase::BZDB_DRAWGROUND	= std::string("_drawGround");
+const std::string StateDatabase::BZDB_DRAWGROUNDLIGHTS	= std::string("_drawGroundLights");
+const std::string StateDatabase::BZDB_DRAWMOUNTAINS	= std::string("_drawMountains");
+const std::string StateDatabase::BZDB_DRAWSKY		= std::string("_drawSky");
+const std::string StateDatabase::BZDB_ENDSHOTDETECTION  = std::string("_endShotDetection");
 const std::string StateDatabase::BZDB_EXPLODETIME       = std::string("_explodeTime");
 const std::string StateDatabase::BZDB_FLAGALTITUDE      = std::string("_flagAltitude");
 const std::string StateDatabase::BZDB_FLAGEFFECTTIME    = std::string("_flagEffectTime");
@@ -106,6 +115,11 @@ const std::string StateDatabase::BZDB_FLAGHEIGHT	= std::string("_flagHeight");
 const std::string StateDatabase::BZDB_FLAGPOLEWIDTH     = std::string("_flagPoleWidth");
 const std::string StateDatabase::BZDB_FLAGPOLESIZE      = std::string("_flagPoleSize");
 const std::string StateDatabase::BZDB_FLAGRADIUS	= std::string("_flagRadius");
+const std::string StateDatabase::BZDB_FOGMODE		= std::string("_fogMode");
+const std::string StateDatabase::BZDB_FOGDENSITY	= std::string("_fogDensity");
+const std::string StateDatabase::BZDB_FOGSTART		= std::string("_fogStart");
+const std::string StateDatabase::BZDB_FOGEND		= std::string("_fogEnd");
+const std::string StateDatabase::BZDB_FOGCOLOR		= std::string("_fogColor");
 const std::string StateDatabase::BZDB_FRICTION		= std::string("_friction");
 const std::string StateDatabase::BZDB_GMACTIVATIONTIME	= std::string("_gmActivationTime");
 const std::string StateDatabase::BZDB_GMADLIFE		= std::string("_gmAdLife");
@@ -160,6 +174,7 @@ const std::string StateDatabase::BZDB_SHOTRANGE		= std::string("_shotRange");
 const std::string StateDatabase::BZDB_SHOTSPEED		= std::string("_shotSpeed");
 const std::string StateDatabase::BZDB_SHOTTAILLENGTH	= std::string("_shotTailLength");
 const std::string StateDatabase::BZDB_SHOTSKEEPVERTICALV= std::string("_shotsKeepVerticalVelocity");
+const std::string StateDatabase::BZDB_SPEEDCHECKSLOGONLY= std::string("_speedChecksLogOnly");
 const std::string StateDatabase::BZDB_SRRADIUSMULT	= std::string("_srRadiusMult");
 const std::string StateDatabase::BZDB_SQUISHFACTOR	= std::string("_squishFactor");
 const std::string StateDatabase::BZDB_SQUISHTIME	= std::string("_squishTime");
@@ -216,7 +231,7 @@ StateDatabase::Item::Item() : value(),
 //
 
 
-StateDatabase::StateDatabase() : debug(false)
+StateDatabase::StateDatabase() : debug(false), saveDefault(false)
 {
   // do nothing
 }
@@ -234,14 +249,15 @@ void			StateDatabase::set(const std::string& name,
   if (access >= index->second.permission) {
     index->second.value  = value;
     index->second.isSet  = true;
-    index->second.isTrue = (index->second.value != "0" &&
-			    index->second.value != "False" &&
-			    index->second.value != "false" &&
-			    index->second.value != "FALSE" &&
-			    index->second.value != "no" &&
-			    index->second.value != "No" &&
-			    index->second.value != "NO" &&
-			    index->second.value != "disable");
+    std::string valuelow = TextUtils::tolower(value);
+    index->second.isTrue = (valuelow != "0" &&
+			    valuelow != "off" &&
+			    valuelow != "false" &&
+			    valuelow != "no" &&
+			    valuelow != "disable");
+
+	if (saveDefault)
+		index->second.defValue = value;
     notify(index);
   }
 }
@@ -356,6 +372,22 @@ std::string		StateDatabase::get(const std::string& name) const
     return index->second.value;
 }
 
+int		StateDatabase::getIntClamped(const std::string& name, const int min, const int max) const
+{
+  int val;
+  debugLookups(name);
+  Map::const_iterator index = items.find(name);
+  if (index == items.end() || !index->second.isSet)
+    val=0;
+  else
+    val = atoi(index->second.value.c_str());
+  if (val < min)
+    return min;
+  else if (val > max)
+    return max;
+  return val;
+}
+
 void *		StateDatabase::getPointer(const std::string& name) const
 {
   debugLookups(name);
@@ -393,6 +425,8 @@ float			StateDatabase::eval(const std::string& name)
   }
   Expression pre, inf;
   std::string value = index->second.value;
+  if (!value.size())
+	  return NaN;
   value >> inf;
   pre = infixToPrefix(inf);
   float retn = evaluate(pre);
@@ -484,14 +518,14 @@ StateDatabase::Map::iterator
 void			StateDatabase::notify(Map::iterator index)
 {
   evalCache.erase(index->first);
-  index->second.callbacks.iterate(&onCallback, const_cast<void*>(reinterpret_cast<const void*>(&index->first)));
+  index->second.callbacks.iterate(&onCallback, const_cast<void*>(static_cast<const void*>(&index->first)));
 }
 
 bool			StateDatabase::onCallback(Callback callback,
 						  void* userData,
 						  void* iterateData)
 {
-  callback(*reinterpret_cast<std::string*>(iterateData), userData);
+  callback(*static_cast<std::string*>(iterateData), userData);
   return true;
 }
 
@@ -521,7 +555,9 @@ void		     StateDatabase::setDebug(bool print) {
   debug = print;
 }
 
-
+void		     StateDatabase::setSaveDefault(bool save) {
+	saveDefault = save;
+}
 
 StateDatabase::ExpressionToken::ExpressionToken()
 {
@@ -815,8 +851,10 @@ std::string& operator >> (std::string& src, StateDatabase::Expression& dst)
     while (src[0] == ' ' || src[0] == '\t') {
       src = src.substr(1);
     }
-    src >> temp;
-    dst.push_back(temp);
+    if (src.length() != 0) {
+      src >> temp;
+      dst.push_back(temp);
+    }
   }
   return src;
 }
@@ -845,11 +883,12 @@ StateDatabase::Expression StateDatabase::infixToPrefix(const Expression &infix)
 	operators.push(*i);
       } else if (i->getOperator() == ExpressionToken::rparen) {
 	// unstack operators until a matching ( is found
-	while(operators.top().getOperator() != ExpressionToken::lparen) {
+	while((operators.size() > 0) && (operators.top().getOperator() != ExpressionToken::lparen)) {
 	  postfix.push_back(operators.top()); operators.pop();
 	}
 	// discard (
-	operators.pop();
+	if (operators.size() > 0) // handle extra-rparen case
+	  operators.pop();
       } else {
 	while((operators.size() > 0) && (operators.top().getPrecedence() < i->getPrecedence()) && (operators.top().getOperator() != ExpressionToken::lparen)) {
 	  postfix.push_back(operators.top()); operators.pop();
@@ -885,6 +924,10 @@ float StateDatabase::evaluate(Expression e) const
 	evaluationStack.push(tok);
 	break;
       case ExpressionToken::oper:
+	if ((i->getOperator() == ExpressionToken::lparen) ||
+	    (i->getOperator() == ExpressionToken::rparen)) {
+	    break;  // should not have any parens here, skip them
+	}
 	if (evaluationStack.size() == 0) {
 	  // syntax error
 	}
@@ -928,6 +971,9 @@ float StateDatabase::evaluate(Expression e) const
 	break;
     }
   }
+  if (!evaluationStack.size())
+    return 0; // yeah we are screwed. TODO, don't let us get this far
+
   return (float)evaluationStack.top().getNumber();
 }
 
