@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -18,6 +18,7 @@
 
 // system headers
 #include <string>
+#include <string.h>
 #include <algorithm>
 #include <sstream>
 #include <stdarg.h>
@@ -281,9 +282,7 @@ namespace TextUtils
       if (c == escaper) {
 	if (i < len - 1)
 	  destination += text[++i];
-	else
-	  // Should print an error
-	  ;
+	// Should print an error otherwise
       } else {
 	destination += c;
       }
@@ -305,8 +304,8 @@ namespace TextUtils
     }
     return position;
   }
-  
-  // return a copy of a string, truncated to specified length, 
+
+  // return a copy of a string, truncated to specified length,
   //    make last char a '`' if truncation took place
   std::string str_trunc_continued (const std::string &text, int len)
   {
@@ -315,7 +314,7 @@ namespace TextUtils
       retstr[len-1] = '~';
     return retstr;
   }
-    
+
 }
 
 // Local Variables: ***
