@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -48,6 +48,9 @@ bool WordFilter::simpleFilter(char *input) const
       endPosition = line.length();
 
     word = line.substr(startPosition, endPosition-startPosition);
+    // transform to lowercase
+    transform (word.begin(), word.end(), word.begin(), tolower);
+
     findWord.word = word;
     firstchar = (unsigned char)word[0];
     if (filters[firstchar].find(findWord) != \
@@ -774,6 +777,9 @@ unsigned int WordFilter::loadFromFile(const std::string &fileName, bool verbose)
       }
     }
 
+    // convert the word to lowercase
+    transform (filterWord.begin(),filterWord.end(), filterWord.begin(), tolower);
+
     bool added = addToFilter(filterWord, std::string(""));
     if ((!added) && (verbose)) {
 	std::cout << std::endl << "Word is already added: " << filterWord << std::endl;
