@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -33,17 +33,21 @@ const struct GlobalDBItem globalDBItems[] = {
   { "_burrowSpeedAd",		"0.80",				false, StateDatabase::Locked},
   { "_coldetDepth",		"6",				false, StateDatabase::Locked},
   { "_coldetElements",		"4",				false, StateDatabase::Locked},
+  { "_countdownResumeDelay",	"5",				false, StateDatabase::Locked},
   { "_cullDepth",		"6",				false, StateDatabase::Locked},
   { "_cullDist",		"fog",				false, StateDatabase::Locked},
   { "_cullElements",		"16",				false, StateDatabase::Locked},
   { "_cullOccluders",		"0",				false, StateDatabase::Locked},
   { "_disableBots",		"0",				false, StateDatabase::Locked},
+  { "_disableSpeedChecks",	"0",				false, StateDatabase::Locked},
+  { "_disableHeightChecks",	"0",				false, StateDatabase::Locked},
   { "_drawCelestial",		"1",				false, StateDatabase::Locked},
   { "_drawClouds",		"1",				false, StateDatabase::Locked},
   { "_drawGround",		"1",				false, StateDatabase::Locked},
   { "_drawGroundLights",	"1",				false, StateDatabase::Locked},
   { "_drawMountains",		"1",				false, StateDatabase::Locked},
   { "_drawSky",			"1",				false, StateDatabase::Locked},
+  { "_enableDistanceCheck",	"0",				false, StateDatabase::Locked},
   { "_endShotDetection",	"5",				false, StateDatabase::Locked},
   { "_explodeTime",		"5.0",				false, StateDatabase::Locked},
   { "_flagAltitude",		"11.0",				false, StateDatabase::Locked},
@@ -133,6 +137,7 @@ const struct GlobalDBItem globalDBItems[] = {
   { "_spawnSafeRadMod",		"20",				false, StateDatabase::Locked},
   { "_spawnSafeSRMod",		"3",				false, StateDatabase::Locked},
   { "_spawnSafeSWMod",		"1.5",				false, StateDatabase::Locked},
+  { "_speedChecksLogOnly",	"0",				false, StateDatabase::Locked},
   { "_srRadiusMult",		"2.0",				false, StateDatabase::Locked},
   { "_squishFactor",		"1.0",				false, StateDatabase::Locked},
   { "_squishTime",		"1.0",				false, StateDatabase::Locked},
