@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* interface header */
@@ -46,9 +46,9 @@ static int leafNodes = 0;
 static int totalNodes = 0;
 static int totalElements = 0;
 
-static ObsList	FullList;  // the complete list of obstacles
+static ObsList		FullList;  // the complete list of obstacles
 static SplitObsList	SplitList; // the complete split list of obstacles
-static ObsList	FullPad;   // for returning a full list of obstacles
+static ObsList		FullPad;   // for returning a full list of obstacles
 static SplitObsList	SplitPad;  // for returning a split list of obstacles
 
 static ColDetNodeList	RayList;   // for returning a list a ray hit nodes
@@ -388,6 +388,11 @@ void CollisionManager::load ()
   const ObstacleList& pyrs = OBSTACLEMGR.getPyrs();
   const ObstacleList& bases = OBSTACLEMGR.getBases();
   const ObstacleList& teles = OBSTACLEMGR.getTeles();
+  const int boxCount = (int)boxes.size();
+  const int pyrCount = (int)pyrs.size();
+  const int baseCount = (int)bases.size();
+  const int teleCount = (int)teles.size();
+  const int meshCount = (int)meshes.size();
 
   // clean out the cell lists
   clear();
@@ -399,13 +404,28 @@ void CollisionManager::load ()
 
   // determine the total number of obstacles
   int fullCount = 0;
-  const int meshCount = (int)meshes.size();
+  for (i = 0; i < boxCount; i++) {
+    if (!boxes[i]->isPassable()) fullCount++;
+  }
+  for (i = 0; i < pyrCount; i++) {
+    if (!pyrs[i]->isPassable()) fullCount++;
+  }
+  for (i = 0; i < baseCount; i++) {
+    if (!bases[i]->isPassable()) fullCount++;
+  }
+  for (i = 0; i < teleCount; i++) {
+    if (!teles[i]->isPassable()) fullCount++;
+  }
   for (i = 0; i < meshCount; i++) {
     MeshObstacle* mesh = (MeshObstacle*) meshes[i];
-    fullCount += mesh->getFaceCount() + 1; // one for the mesh itself
+    if (!mesh->isPassable()) {
+      for (int f = 0; f < mesh->getFaceCount(); f++) {
+	MeshFace* face = (MeshFace*) mesh->getFace(f);
+	if (!face->isPassable()) fullCount++;
+      }
+      fullCount++; // one for the mesh itself
+    }
   }
-  fullCount += (int)(boxes.size() + bases.size() +
-		     pyrs.size() + (teles.size() * 3)); // 2 MeshFace links
 
   // get the memory for the full list and the scratch pad
   FullPad.list = new Obstacle*[fullCount];
@@ -421,35 +441,31 @@ void CollisionManager::load ()
   // speed of the sorting.
   //
 
-  const int boxCount = (int)boxes.size();
   for (i = (boxCount - 1); i >= 0; i--) {
-    addToFullList(boxes[i]);
+    if (!boxes[i]->isPassable()) addToFullList(boxes[i]);
   }
-  const int pyrCount = (int)pyrs.size();
   for (i = (pyrCount - 1); i >= 0; i--) {
-    addToFullList(pyrs[i]);
+    if (!pyrs[i]->isPassable()) addToFullList(pyrs[i]);
   }
-  const int baseCount = (int)bases.size();
   for (i = (baseCount - 1); i >= 0; i--) {
-    addToFullList(bases[i]);
+    if (!bases[i]->isPassable()) addToFullList(bases[i]);
   }
-  const int teleCount = (int)teles.size();
   for (i = (teleCount - 1); i >= 0; i--) {
-    Teleporter* tele = (Teleporter*) teles[i];
-    addToFullList((Obstacle*) tele);
-    addToFullList((Obstacle*) tele->getBackLink());
-    addToFullList((Obstacle*) tele->getFrontLink());
+    if (!teles[i]->isPassable()) addToFullList(teles[i]);
   }
-  // add the mesh types last
+  // add the mesh types last (faces then meshes)
   for (i = (meshCount - 1); i >= 0; i--) {
     MeshObstacle* mesh = (MeshObstacle*) meshes[i];
-    const int meshFaceCount = mesh->getFaceCount();
-    for (int f = 0; f < meshFaceCount; f++) {
-      addToFullList((Obstacle*) mesh->getFace(f));
+    if (!mesh->isPassable()) {
+      const int meshFaceCount = mesh->getFaceCount();
+      for (int f = 0; f < meshFaceCount; f++) {
+	MeshFace* face = (MeshFace*) mesh->getFace(f);
+	if (!face->isPassable()) addToFullList((Obstacle*) face);
+      }
     }
   }
   for (i = (meshCount - 1); i >= 0; i--) {
-    addToFullList(meshes[i]);
+    if (!meshes[i]->isPassable()) addToFullList(meshes[i]);
   }
 
   // do the type/height sort
@@ -459,30 +475,37 @@ void CollisionManager::load ()
   setExtents (&FullList);
   root = new ColDetNode (0, gridExtents, &FullList);
 
-
+  // tally the stats
   leafNodes = 0;
   totalNodes = 0;
   totalElements = 0;
   root->tallyStats();
 
-  DEBUG2 ("ColDet Octree obstacles = %i\n", FullList.count);
-  for (i = 0; i < 3; i++) {
-    DEBUG2 ("  grid extent[%i] = %f, %f\n", i, gridExtents.mins[i],
-					       gridExtents.maxs[i]);
-  }
-  for (i = 0; i < 3; i++) {
-    DEBUG2 ("  world extent[%i] = %f, %f\n", i,
-	    worldExtents.mins[i], worldExtents.maxs[i]);
-  }
-  DEBUG2 ("ColDet Octree leaf nodes  = %i\n", leafNodes);
-  DEBUG2 ("ColDet Octree total nodes = %i\n", totalNodes);
-  DEBUG2 ("ColDet Octree total elements = %i\n", totalElements);
-
   // setup the ray list
   RayList.list = new ColDetNode*[leafNodes];
   RayList.count = 0;
 
+  // print some statistics
+  logDebugMessage(2,"ColDet Octree obstacles = %i\n", FullList.count);
+  for (i = 0; i < 3; i++) {
+    logDebugMessage(2,"  grid extent[%i] = %f, %f\n", i, gridExtents.mins[i],
+					       gridExtents.maxs[i]);
+  }
+  for (i = 0; i < 3; i++) {
+    logDebugMessage(2,"  world extent[%i] = %f, %f\n", i, worldExtents.mins[i],
+						worldExtents.maxs[i]);
+  }
+  logDebugMessage(2,"ColDet Octree leaf nodes  = %i\n", leafNodes);
+  logDebugMessage(2,"ColDet Octree total nodes = %i\n", totalNodes);
+  logDebugMessage(2,"ColDet Octree total elements = %i\n", totalElements);
+
+  // print the timing info
+  float elapsed = (float)(TimeKeeper::getCurrent() - startTime);
+  logDebugMessage(2,"Collision Octree processed in %.3f seconds.\n", elapsed);
+
+
   // setup the split list
+  // FIXME: currently unused, untested, and incorrect
   Obstacle** listPtr = FullList.list;
   SplitList.named.boxes.list = listPtr;
   SplitList.named.boxes.count = (int)boxes.size();
@@ -496,8 +519,6 @@ void CollisionManager::load ()
   SplitList.named.teles.list = listPtr;
   SplitList.named.teles.count = (int)teles.size();
 
-  float elapsed = TimeKeeper::getCurrent() - startTime;
-  DEBUG2 ("Collision Octree processed in %.3f seconds.\n", elapsed);
 
   return;
 }
@@ -524,7 +545,7 @@ void CollisionManager::setExtents (ObsList *list)
     }
   }
 
-  gridExtents.copy(worldExtents);
+  gridExtents = worldExtents;
 
   // make it a cube, with Z on its minimum
   for (i = 0; i < 2; i++) {
@@ -573,9 +594,9 @@ ColDetNode::ColDetNode(unsigned char _depth,
   fullList.list = (Obstacle**) malloc (listBytes);
 
   // copy the extents, and make the testing extents with margin
-  extents.copy(exts);
+  extents = exts;
   Extents testExts;
-  testExts.copy(exts);
+  testExts = exts;
   testExts.addMargin(testFudge);
 
   // setup some test parameters
@@ -646,7 +667,7 @@ ColDetNode::ColDetNode(unsigned char _depth,
   // return if this is a leaf node
   if (((int)depth >= maxDepth) || (fullList.count <= minElements)) {
     resizeCell();
-    //DEBUG4 ("COLDET LEAF NODE: depth = %d, items = %i\n", depth, count);
+    //logDebugMessage(4, ("COLDET LEAF NODE: depth = %d, items = %i\n", depth, count);
     return;
   }
 
@@ -665,7 +686,7 @@ ColDetNode::ColDetNode(unsigned char _depth,
   free (fullList.list);
   fullList.list = NULL;
 
-  //DEBUG4 ("COLDET BRANCH NODE: depth = %d, children = %i\n", depth, childCount);
+  //logDebugMessage(4, ("COLDET BRANCH NODE: depth = %d, children = %i\n", depth, childCount);
 
   return;
 }
