@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* interface header */
@@ -33,16 +33,39 @@
 
 // NOTE: terminate all strings with '/' or '\\'
 
-static std::string		setupString(std::string dir)
+std::string configDir(bool set, const char *str)
 {
-  std::string name = getConfigDirName();
-  name += dir;
-  name += DirectorySeparator;
-  return name;
+  static std::string customConfigDir = std::string("");
+  if (set) {
+    customConfigDir = std::string(str);
+  }
+  return customConfigDir;
 }
 
+
+void			setCustomConfigDir(const char *str)
+{
+	std::string dir = str;
+	if (dir.size() > 2)
+	{
+		if (*dir.begin() == '"')
+			dir.erase(dir.begin());
+
+		if (*(dir.end()-1) == '"')
+			dir.erase(dir.end()-1);
+
+	}
+  configDir(1, dir.c_str());
+}
+
+
 std::string		getConfigDirName( const char* versionName )
 {
+  std::string customConfigDir = configDir(0, NULL);
+
+  if (customConfigDir.size() > 0)
+    return customConfigDir;
+
 #if defined(_WIN32)
   std::string name("C:");
   char dir[MAX_PATH];
@@ -63,11 +86,11 @@ std::string		getConfigDirName( const char* versionName )
 
   // yes your suposed to have the "my" in front of it. I know it's silly, but it's the MS way.
   name += "\\My BZFlag Files\\";
-	if (versionName)
-	{
-		name += versionName;
-		name += "\\";
-	}
+  if (versionName) {
+    name += versionName;
+    name += "\\";
+  }
+  customConfigDir = name;
   return name;
 
 #elif defined(__APPLE__)
@@ -80,14 +103,14 @@ std::string		getConfigDirName( const char* versionName )
     err = ::FSRefMakePath(&libraryFolder, (UInt8*)buff, sizeof(buff));
     if(err == ::noErr) {
       std::strcat(buff, "/BZFlag/");
-			if (versionName)
-			{
-				std::strcat(buff, versionName);
-				std::strcat(buff,"/");
-			}
+      if (versionName) {
+	std::strcat(buff, versionName);
+	std::strcat(buff, "/");
+      }
      name = buff;
     }
   }
+  customConfigDir = name;
   return name;
 #else
   std::string name;
@@ -97,17 +120,24 @@ std::string		getConfigDirName( const char* versionName )
     name += "/";
   }
   name += ".bzf/";
-	if (versionName)
-	{
-		name+= versionName;
-		name+="/";
-	}
+  if (versionName) {
+    name += versionName;
+    name += "/";
+  }
+  customConfigDir = name;
   return name;
 #endif
 }
 
+static std::string		setupString(std::string dir)
+{
+  std::string name = getConfigDirName();
+  name += dir;
+  name += DirectorySeparator;
+  return name;
+}
 
-extern std::string		getCacheDirName()
+std::string getCacheDirName()
 {
   std::string name = getConfigDirName();
   name += "cache";
@@ -124,23 +154,22 @@ extern std::string		getCacheDirName()
 }
 
 
-extern std::string		getRecordDirName()
+std::string getRecordDirName()
 {
   return setupString("recordings");
 }
 
-
-extern std::string		getScreenShotDirName()
+std::string getScreenShotDirName()
 {
   return setupString("screenshots");
 }
 
-extern std::string		getTempDirName()
+std::string getTempDirName()
 {
 // FIXME: needs something for Windows and maybe other platforms
 #if defined(_WIN32)
-	std::string name = getConfigDirName();
-	name += "temp";
+  std::string name = getConfigDirName();
+  name += "temp";
 #else
   std::string name;
   if (getenv("TMPDIR")) {
@@ -153,7 +182,7 @@ extern std::string		getTempDirName()
   return name;
 }
 
-extern std::string		getWorldDirName()
+std::string getWorldDirName()
 {
   return setupString("worlds");
 }
