@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -16,8 +16,36 @@
 // system headers
 #include <errno.h>
 
+#include "bzfsAPI.h"
+
 const int udpBufSize = 128000;
 
+std::vector<NetworkDataLogCallback*> logCallbacks;
+
+void addNetworkLogCallback(NetworkDataLogCallback * cb )
+{
+  if (cb)
+    logCallbacks.push_back(cb);
+}
+
+void removeNetworkLogCallback(NetworkDataLogCallback * cb )
+{
+  for ( unsigned int i = 0; i < (unsigned int)logCallbacks.size(); i++)
+  {
+    if ( logCallbacks[i] == cb )
+    {
+      logCallbacks.erase(logCallbacks.begin()+i);
+      return;
+    }
+  }
+}
+
+void callNetworkDataLog ( bool send, bool udp,  const unsigned char *data, unsigned int size, void *param = NULL )
+{
+  for ( unsigned int i = 0; i < (unsigned int)logCallbacks.size(); i++)
+    logCallbacks[i]->networkDataLog(send,udp,data,size,param);
+}
+
 bool NetHandler::pendingUDP = false;
 bool NetHandler::initHandlers(struct sockaddr_in addr) {
   // udp socket
@@ -65,9 +93,7 @@ void NetHandler::setFd(fd_set *read_set, fd_set *write_set, int &maxFile) {
   for (int i = 0; i < maxHandlers; i++) {
     NetHandler *player = netPlayer[i];
     if (player && !player->closed) {
-#if !defined(USE_THREADS) || !defined(HAVE_SDL)
       FD_SET((unsigned int)player->fd, read_set);
-#endif
       if (player->outmsgSize > 0) {
 	FD_SET((unsigned int)player->fd, write_set);
       }
@@ -133,7 +159,7 @@ int NetHandler::udpReceive(char *buffer, struct sockaddr_in *uaddr,
     uint8_t index;
     buf = nboUnpackUByte(buf, index);
     if ((index < maxHandlers) && netPlayer[index] && !netPlayer[index]->closed
-	&& !netPlayer[index]->udpin)
+	&& !netPlayer[index]->udpin) {
       if (!memcmp(&netPlayer[index]->uaddr.sin_addr, &uaddr->sin_addr,
 		  sizeof(uaddr->sin_addr))) {
 	id = index;
@@ -141,36 +167,36 @@ int NetHandler::udpReceive(char *buffer, struct sockaddr_in *uaddr,
 	  netPlayer[index]->uaddr.sin_port = uaddr->sin_port;
 	netPlayer[index]->udpin = true;
 	udpLinkRequest = true;
-	DEBUG2("Player %s [%d] inbound UDP up %s:%d actual %d\n",
+	logDebugMessage(2,"Player %s [%d] inbound UDP up %s:%d actual %d\n",
 	       netPlayer[index]->info->getCallSign(), index,
 	       inet_ntoa(uaddr->sin_addr),
 	       ntohs(netPlayer[index]->uaddr.sin_port),
 	       ntohs(uaddr->sin_port));
       } else {
-	DEBUG2
-	  ("Player %s [%d] inbound UDP rejected %s:%d different IP \
+	logDebugMessage(2,"Player %s [%d] inbound UDP rejected %s:%d different IP \
 than %s:%d\n",
 	   netPlayer[index]->info->getCallSign(), index,
 	   inet_ntoa(netPlayer[index]->uaddr.sin_addr),
 	   ntohs(netPlayer[index]->uaddr.sin_port),
 	   inet_ntoa(uaddr->sin_addr), ntohs(uaddr->sin_port));
       }
+    }
   }
 
   if (id == -1) {
     // no match, discard packet
-    DEBUG2("uread() discard packet! %s:%d choices p(l) h:p",
+    logDebugMessage(2,"uread() discard packet! %s:%d choices p(l) h:p",
 	   inet_ntoa(uaddr->sin_addr), ntohs(uaddr->sin_port));
     for (pi = 0; pi < maxHandlers; pi++) {
       if (netPlayer[pi] && !netPlayer[pi]->closed)
-	DEBUG3(" %d(%d-%d) %s:%d", pi, netPlayer[pi]->udpin,
+	logDebugMessage(3," %d(%d-%d) %s:%d", pi, netPlayer[pi]->udpin,
 	       netPlayer[pi]->udpout,
 	       inet_ntoa(netPlayer[pi]->uaddr.sin_addr),
 	       ntohs(netPlayer[pi]->uaddr.sin_port));
     }
-    DEBUG2("\n");
+    logDebugMessage(2,"\n");
   } else {
-    DEBUG4("Player %s [%d] uread() %s:%d len %d from %s:%d on %i\n",
+    logDebugMessage(4,"Player %s [%d] uread() %s:%d len %d from %s:%d on %i\n",
 	   netPlayer[id]->info->getCallSign(), id,
 	   inet_ntoa(netPlayer[id]->uaddr.sin_addr),
 	   ntohs(netPlayer[id]->uaddr.sin_port), n,
@@ -179,10 +205,13 @@ than %s:%d\n",
 #ifdef NETWORK_STATS
     netPlayer[id]->countMessage(code, len, 0);
 #endif
+
+    callNetworkDataLog (false, true, (const unsigned char*)buf,len,netPlayer[id]);
+
     if (code == MsgUDPLinkEstablished) {
       netPlayer[id]->udpout = true;
-      DEBUG2("Player %s [%d] outbound UDP up\n",
-	     netPlayer[id]->info->getCallSign(), id);
+      logDebugMessage(2,"Player %s [%d] outbound UDP up\n",
+	      netPlayer[id]->info->getCallSign(), id);
     }
   }
   return id;
@@ -330,7 +359,7 @@ int NetHandler::bufferedSend(const void *buffer, size_t length) {
       // are the network is down or too unreliable to that player.
       // FIXME -- is 20kB too big?  too small?
       if (newCapacity >= 20 * 1024) {
-	DEBUG2("Player %s [%d] drop, unresponsive with %d bytes queued\n",
+	logDebugMessage(2,"Player %s [%d] drop, unresponsive with %d bytes queued\n",
 	       info->getCallSign(), playerIndex, outmsgSize + length);
 	toBeKicked = true;
 	toBeKickedReason = "send queue too big";
@@ -387,6 +416,8 @@ int NetHandler::pwrite(const void *b, int l) {
   countMessage(code, len, 1);
 #endif
 
+  bool useUDP = false;
+
   // Check if UDP Link is used instead of TCP, if so jump into udpSend
   if (udpout) {
     // only send bulk messages by UDP
@@ -398,13 +429,15 @@ int NetHandler::pwrite(const void *b, int l) {
     case MsgGMUpdate:
     case MsgLagPing:
     case MsgGameTime:
-      udpSend(b, l);
-      return 0;
+		useUDP = true;
+		break;
     }
   }
 
-  // always sent MsgUDPLinkRequest over udp with udpSend
-  if (code == MsgUDPLinkRequest) {
+  callNetworkDataLog (true, useUDP, (const unsigned char*)b,len,this);
+
+  // always sent UDP messages and MsgUDPLinkRequest over udp with udpSend
+  if (useUDP || code == MsgUDPLinkRequest) {
     udpSend(b, l);
     return 0;
   }
@@ -420,14 +453,6 @@ int NetHandler::pflush(fd_set *set) {
 }
 
 RxStatus NetHandler::tcpReceive() {
-  // read more data into player's message buffer
-#if defined(USE_THREADS) && defined(HAVE_SDL)
-  fd_set read_set;
-  FD_ZERO(&read_set);
-  FD_SET((unsigned int)fd, &read_set);
-  select(fd + 1, (fd_set*)&read_set, 0, 0, 0);
-#endif
-
   // read header if we don't have it yet
   RxStatus e = receive(4);
   if (e != ReadAll)
@@ -440,7 +465,7 @@ RxStatus NetHandler::tcpReceive() {
   buf = nboUnpackUShort(buf, len);
   buf = nboUnpackUShort(buf, code);
   if (len > MaxPacketLen) {
-    DEBUG1("Player [%d] sent huge packet length (len=%d), possible attack\n",
+    logDebugMessage(1,"Player [%d] sent huge packet length (len=%d), possible attack\n",
 	   playerIndex, len);
     return ReadHuge;
   }
@@ -454,9 +479,12 @@ RxStatus NetHandler::tcpReceive() {
 #ifdef NETWORK_STATS
   countMessage(code, len, 0);
 #endif
+
+  callNetworkDataLog (false, false, (const unsigned char*)buf,len,this);
+
   if (code == MsgUDPLinkEstablished) {
     udpout = true;
-    DEBUG2("Player %s [%d] outbound UDP up\n", info->getCallSign(),
+    logDebugMessage(2,"Player %s [%d] outbound UDP up\n", info->getCallSign(),
 	   playerIndex);
   }
   return ReadAll;
@@ -567,21 +595,21 @@ void NetHandler::dumpMessageStats() {
   int total;
   int direction;
 
-  DEBUG1("Player connect time: %f\n", info->now - time);
+  logDebugMessage(1,"Player connect time: %f\n", info->now - time);
 
   for (direction = 0; direction <= 1; direction++) {
     total = 0;
-    DEBUG1("Player messages %s:", direction ? "out" : "in");
+    logDebugMessage(1,"Player messages %s:", direction ? "out" : "in");
 
     for (MessageCountMap::iterator i = msg[direction].begin();
 	 i != msg[direction].end(); i++) {
-      DEBUG1(" %c%c:%u(%u)", i->first >> 8, i->first & 0xff,
+      logDebugMessage(1," %c%c:%u(%u)", i->first >> 8, i->first & 0xff,
 	     i->second.count, i->second.maxSize);
       total += i->second.count;
     }
 
-    DEBUG1(" total:%u(%u) ", total, msgBytes[direction]);
-    DEBUG1("max msgs/bytes per second: %u/%u\n",
+    logDebugMessage(1," total:%u(%u) ", total, msgBytes[direction]);
+    logDebugMessage(1,"max msgs/bytes per second: %u/%u\n",
 	perSecondMaxMsg[direction],
 	perSecondMaxBytes[direction]);
   }
@@ -592,7 +620,7 @@ void NetHandler::dumpMessageStats() {
 void NetHandler::udpSend(const void *b, size_t l) {
 #ifdef TESTLINK
   if ((random()%LINKQUALITY) == 0) {
-    DEBUG1("Drop Packet due to Test\n");
+    logDebugMessage(1,"Drop Packet due to Test\n");
     return;
   }
 #endif
