@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -30,7 +30,7 @@ WordFilter *PlayerInfo::filterData	= NULL;
 bool	PlayerInfo::simpleFiltering   = true;
 
 PlayerInfo::PlayerInfo(int _playerIndex) :
-  playerIndex(_playerIndex), state(PlayerInLimbo), flag(-1),
+  playerIndex(_playerIndex), state(PlayerInLimbo), team(NoTeam), flag(-1),
   spamWarns(0), lastMsgTime(now), paused(false),
   pausedSince(TimeKeeper::getNullTime()), autopilot(false), tracker(0)
 {
@@ -42,6 +42,9 @@ PlayerInfo::PlayerInfo(int _playerIndex) :
   clientVersionMajor = -1;
   clientVersionMinor = -1;
   clientVersionRevision = -1;
+  validEnter = false;
+  nextSpawnTime = TimeKeeper::getSunGenesisTime();
+  wantsToSpawn = false;
 }
 
 void PlayerInfo::setFilterParameters(bool	_callSignFiltering,
@@ -81,6 +84,7 @@ void PlayerInfo::signingOn() {
 void PlayerInfo::setAlive() {
   state = PlayerAlive;
   paused = false;
+  wantsToSpawn = false;
   flag = -1;
 }
 
@@ -121,7 +125,7 @@ bool PlayerInfo::unpackEnter(void *buf, uint16_t &rejectCode, char *rejectMsg)
   clientVersion[VersionLen - 1] = '\0';
   cleanEMail();
 
-  DEBUG2("Player %s [%d] sent version string: %s\n",
+  logDebugMessage(2,"Player %s [%d] sent version string: %s\n",
 	 callSign, playerIndex, clientVersion);
   int major, minor, rev;
   if (sscanf(clientVersion, "%d.%d.%d", &major, &minor, &rev) == 3) {
@@ -129,7 +133,7 @@ bool PlayerInfo::unpackEnter(void *buf, uint16_t &rejectCode, char *rejectMsg)
     clientVersionMinor = minor;
     clientVersionRevision = rev;
   }
-  DEBUG4("Player %s version code parsed as:  %i.%i.%i\n", callSign,
+  logDebugMessage(4,"Player %s version code parsed as:  %i.%i.%i\n", callSign,
 	 clientVersionMajor, clientVersionMinor, clientVersionRevision);
 
   // spoof filter holds "SERVER" for robust name comparisons
@@ -138,7 +142,7 @@ bool PlayerInfo::unpackEnter(void *buf, uint16_t &rejectCode, char *rejectMsg)
   }
 
   if (!isCallSignReadable()) {
-    DEBUG2("rejecting unreadable callsign: %s\n", callSign);
+    logDebugMessage(2,"rejecting unreadable callsign: %s\n", callSign);
     rejectCode   = RejectBadCallsign;
     strcpy(rejectMsg, errorString.c_str());
     return false;
@@ -150,7 +154,7 @@ bool PlayerInfo::unpackEnter(void *buf, uint16_t &rejectCode, char *rejectMsg)
     return false;
   }
   if (!isEMailReadable()) {
-    DEBUG2("rejecting unreadable player email: %s (%s)\n", callSign, email);
+    logDebugMessage(2,"rejecting unreadable player email: %s (%s)\n", callSign, email);
     rejectCode   = RejectBadEmail;
     strcpy(rejectMsg, "The e-mail was rejected.  Try a different e-mail.");
     return false;
@@ -158,7 +162,7 @@ bool PlayerInfo::unpackEnter(void *buf, uint16_t &rejectCode, char *rejectMsg)
 
   // make sure the callsign is not obscene/filtered
   if (callSignFiltering) {
-    DEBUG2("checking callsign: %s\n",callSign);
+    logDebugMessage(2,"checking callsign: %s\n",callSign);
 
     char cs[CallSignLen];
     memcpy(cs, callSign, sizeof(char) * CallSignLen);
@@ -172,7 +176,7 @@ bool PlayerInfo::unpackEnter(void *buf, uint16_t &rejectCode, char *rejectMsg)
 
   // make sure the email is not obscene/filtered
   if (callSignFiltering) {
-    DEBUG2("checking email: %s\n", email);
+    logDebugMessage(2,"checking email: %s\n", email);
     char em[EmailLen];
     memcpy(em, email, sizeof(char) * EmailLen);
     if (filterData->filter(em, simpleFiltering)) {
@@ -186,6 +190,7 @@ bool PlayerInfo::unpackEnter(void *buf, uint16_t &rejectCode, char *rejectMsg)
     strcpy(token, "NONE");
   }
 
+  validEnter = true;
   return true;
 }
 
