@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -15,6 +15,7 @@
 
 /* system headers */
 #include <fstream>
+#include <string.h>
 
 // invoke persistent rebuilding for build versioning
 #include "version.h"
@@ -23,6 +24,7 @@
 #include "FileManager.h"
 #include "Protocol.h"
 #include "DirectoryNames.h"
+#include "TextUtils.h"
 
 
 ServerListCache	ServerListCache::globalCache;
@@ -44,66 +46,76 @@ ServerListCache*  ServerListCache::get()
 
 
 // insert a serverItem mapped by the serverAddress
-void ServerListCache::insert(std::string serverAddress,ServerItem& info)
+void ServerListCache::insert(const std::string &serverAddress, const ServerItem &info)
 {
   serverCache.insert(SRV_STR_MAP::value_type(serverAddress,info));
 }
 
 
-SRV_STR_MAP::iterator ServerListCache::find(std::string serverAddress)
+ServerListCache::SRV_STR_MAP::iterator ServerListCache::find(const std::string &serverAddress)
 {
   return serverCache.find(serverAddress);
 }
 
 
-SRV_STR_MAP::iterator ServerListCache::begin()
+ServerListCache::SRV_STR_MAP::iterator ServerListCache::begin()
 {
   return serverCache.begin();
 }
 
 
-SRV_STR_MAP::iterator ServerListCache::end()
+ServerListCache::SRV_STR_MAP::iterator ServerListCache::end()
 {
   return serverCache.end();
 }
 
+bool ServerListCache::isFavorite(const std::string &serverAddress) const
+{
+  SRV_STR_MAP::const_iterator i = serverCache.find(serverAddress);
+  return i!=serverCache.end() && i->second.favorite;
+}
 
-void			ServerListCache::saveCache()
+std::string	     ServerListCache::getCacheFilename(int subrevision) const
 {
   // get a file named e.g. BZFS1910Server.bzs in the cache dir
   // allows separation of server caches by protocol version
   std::string fileName = getCacheDirName();
-  if (fileName == "") return;
+  if (fileName == "") return "";
   std::string verString = getServerVersion();
-#ifdef _WIN32
-  fileName = fileName + "\\" + verString + "-Servers.bzs";
-#else
-  fileName = fileName + "/" + verString + "-Servers.bzs";
-#endif
+  // subrevision to differentiate file formats for same protocol version
+  if (subrevision > 0)
+    verString += TextUtils::format("_%d", subrevision);
+  fileName += verString + "-Servers.bzs";
+  return fileName;
+}
 
-  char buffer[MAX_STRING+1];
+void			ServerListCache::saveCache()
+{
+  const int subrevision = 1;
+  std::string fileName = getCacheFilename(subrevision);
+  if (fileName == "") return;
 
   std::ostream* outFile = FILEMGR.createDataOutStream(fileName, true, true);
-  int lenCpy = MAX_STRING;
+  int lenCpy = max_string;
 
   if (outFile != NULL){
+    char buffer[max_string+1];
     for (SRV_STR_MAP::iterator iter = serverCache.begin(); iter != serverCache.end(); iter++){
 
-      // skip items that are more than 30 days old
-      if (iter->second.getAgeMinutes() > 60*24*30) {
+      // skip items that are more than 30 days old, but always save favorites
+      if (!iter->second.favorite && iter->second.getAgeMinutes() > 60*24*30) {
 	continue;
       }
 
       // write out the index of the map
       memset(buffer, 0, sizeof(buffer));
-      lenCpy = int((iter->first).size() < MAX_STRING ? (iter->first).size() : MAX_STRING);
+      lenCpy = int((iter->first).size() < max_string ? (iter->first).size() : max_string);
       strncpy(buffer, (iter->first.c_str()), lenCpy);
       outFile->write(buffer, sizeof(buffer));
 
       ServerItem x = iter->second;
       // write out the serverinfo -- which is mapped by index
-      (iter->second).writeToFile(*outFile);
-
+      iter->second.writeToFile(*outFile);
     }
     delete outFile;
   }
@@ -112,23 +124,22 @@ void			ServerListCache::saveCache()
 
 void			ServerListCache::loadCache()
 {
-  // get a file named BZFS1910Server.bzs in the cache dir
-  // allows separation of server caches by protocol version
-  std::string fileName = getCacheDirName();
+  int subrevision = 1;
+  std::string fileName = getCacheFilename(subrevision);
   if (fileName == "") return;
-  std::string verString = getServerVersion();
-#ifdef _WIN32
-  fileName = fileName + "\\" + verString + "-Servers.bzs";
-#else
-  fileName = fileName + "/" + verString + "-Servers.bzs";
-#endif
+  std::ifstream inFile(fileName.c_str(), std::ios::in | std::ios::binary);
 
-  char buffer[MAX_STRING+1];
-
-  std::ifstream inFile (fileName.c_str(), std::ios::in | std::ios::binary);
-  bool infoWorked;
+  // could not open, try again with older revision
+  if (!inFile) {
+    subrevision = 0;
+    fileName = getCacheFilename(subrevision);
+    if (fileName == "") return;
+    inFile.clear();
+    inFile.open(fileName.c_str(), std::ios::in | std::ios::binary);
+  }
 
   if (inFile) {
+    char buffer[max_string+1];
     while(inFile) {
       std::string serverIndex;
       ServerItem info;
@@ -137,7 +148,7 @@ void			ServerListCache::loadCache()
       if ((size_t)inFile.gcount() < sizeof(buffer)) break; // failed to read entire string
       serverIndex = buffer;
 
-      infoWorked = info.readFromFile(inFile);
+      bool infoWorked = info.readFromFile(inFile, subrevision);
       // after a while it is doubtful that player counts are accurate
       if (info.getAgeMinutes() > (time_t)30) info.ping.zeroPlayerCounts();
       if (!infoWorked) break;
