@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 // bzflag common header
@@ -46,7 +46,7 @@ BillboardSceneNode::BillboardSceneNode(const GLfloat pos[3]) :
   OpenGLGStateBuilder builder(gstate);
   builder.setBlending();
   builder.setAlphaFunc();
-  builder.enableTextureReplace();
+  //builder.setTextureEnvMode(GL_DECAL);
   gstate = builder.getState();
 
   // prepare light
@@ -198,9 +198,9 @@ void			BillboardSceneNode::setLightScaling(GLfloat s)
   prepLight();
 }
 
-void			BillboardSceneNode::setLightFadeStartTime(float t)
+void			BillboardSceneNode::setLightFadeStartTime(float _t)
 {
-  lightCutoffTime = t;
+  lightCutoffTime = _t;
   prepLight();
 }
 
@@ -284,7 +284,7 @@ void			BillboardSceneNode::setAngle(GLfloat _angle)
 void			BillboardSceneNode::addLight(
 				SceneRenderer& renderer)
 {
-  if (show) { /* && !groundLight) { FIXME - will disable puff ground lights */
+  if (show && lightSource) {
     renderer.addLight(light);
   }
 }
@@ -298,8 +298,7 @@ void			BillboardSceneNode::notifyStyleChange()
     if (hasAlpha) {
       builder.setBlending(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
       builder.setAlphaFunc();
-    }
-    else {
+    } else {
       builder.resetBlending();
       builder.resetAlphaFunc();
     }
@@ -366,6 +365,7 @@ void			BillboardSceneNode::BillboardRenderNode::render()
   d = sceneNode->width / hypotf(dir[0], hypotf(dir[1], dir[2]));
 
   glPushMatrix();
+  {
     glTranslatef(sphere[0] + d * dir[0],
 		 sphere[1] + d * dir[1],
 		 sphere[2] + d * dir[2]);
@@ -384,9 +384,11 @@ void			BillboardSceneNode::BillboardRenderNode::render()
     glTexCoord2f(   u, dv+v);
     glVertex2f  (-sceneNode->width,  sceneNode->height);
     glEnd();
-
+  }
   glPopMatrix();
 
+  addTriangleCount(2);
+
   glDisable(GL_CLIP_PLANE0);
 }
 
