@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 // bzflag common header
@@ -25,6 +25,7 @@
 #include "Intersect.h"
 #include "MeshFace.h"
 #include "MeshSceneNodeGenerator.h"
+#include "BzMaterial.h"
 #include "StateDatabase.h"
 #include "BZDBCache.h"
 #include "SceneRenderer.h"
@@ -44,19 +45,124 @@ MeshFragSceneNode::Geometry::Geometry(MeshFragSceneNode* node)
 {
   style = 0;
   sceneNode = node;
+  list = INVALID_GL_LIST_ID;
+  OpenGLGState::registerContextInitializer (freeContext, initContext, this);
   return;
 }
 
 
 MeshFragSceneNode::Geometry::~Geometry()
 {
-  // do nothing
+  OpenGLGState::unregisterContextInitializer (freeContext, initContext, this);
   return;
 }
 
+
+void MeshFragSceneNode::Geometry::init()
+{
+  initDisplayList();
+  return;
+}
+
+
+void MeshFragSceneNode::Geometry::initDisplayList()
+{
+  if (list != INVALID_GL_LIST_ID) {
+    glDeleteLists(list, 1);
+  }
+  list = INVALID_GL_LIST_ID;
+  if (BZDB.isTrue("meshLists")) {
+    list = glGenLists(1);
+    glNewList(list, GL_COMPILE);
+    drawVTN();
+    glEndList();
+  }
+  return;
+}
+
+
+void MeshFragSceneNode::Geometry::freeDisplayList()
+{
+  if (list != INVALID_GL_LIST_ID) {
+    glDeleteLists(list, 1);
+  }
+  list = INVALID_GL_LIST_ID;
+  return;
+}
+
+
+void MeshFragSceneNode::Geometry::freeContext(void *data)
+{
+  ((MeshFragSceneNode::Geometry*)data)->freeDisplayList();
+  return;
+}
+
+
+void MeshFragSceneNode::Geometry::initContext(void *data)
+{
+  ((MeshFragSceneNode::Geometry*)data)->initDisplayList();
+  return;
+}
+
+
+inline void MeshFragSceneNode::Geometry::drawV() const
+{
+  glDisableClientState(GL_NORMAL_ARRAY);
+  glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+
+  glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
+  glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
+
+  glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+  glEnableClientState(GL_NORMAL_ARRAY);
+
+  return;
+}
+
+
+inline void MeshFragSceneNode::Geometry::drawVT() const
+{
+  glDisableClientState(GL_NORMAL_ARRAY);
+
+  glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
+  glTexCoordPointer(2, GL_FLOAT, 0, sceneNode->texcoords);
+  glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
+
+  glEnableClientState(GL_NORMAL_ARRAY);
+
+  return;
+}
+
+
+inline void MeshFragSceneNode::Geometry::drawVN() const
+{
+  glDisableClientState(GL_TEXTURE_COORD_ARRAY);
+
+  glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
+  glNormalPointer(GL_FLOAT, 0, sceneNode->normals);
+  glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
+
+  glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+
+  return;
+}
+
+
+inline void MeshFragSceneNode::Geometry::drawVTN() const
+{
+  glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
+  glNormalPointer(GL_FLOAT, 0, sceneNode->normals);
+  glTexCoordPointer(2, GL_FLOAT, 0, sceneNode->texcoords);
+  glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
+
+  return;
+}
+
+
 void MeshFragSceneNode::Geometry::render()
 {
-  const bool switchLights = (sceneNode->arrayCount >= minLightDisabling)
+  const int triangles = sceneNode->arrayCount;
+  const bool switchLights = (triangles >= minLightDisabling)
 			    && BZDBCache::lighting;
   if (switchLights) {
     RENDERER.disableLights(sceneNode->extents.mins, sceneNode->extents.maxs);
@@ -65,17 +171,22 @@ void MeshFragSceneNode::Geometry::render()
   // set the color
   sceneNode->setColor();
 
-  if (BZDBCache::lighting) {
-    if (BZDBCache::texture) {
-      drawVTN();
+  if (list != INVALID_GL_LIST_ID) {
+    glCallList(list);
+  }
+  else {
+    if (BZDBCache::lighting) {
+      if (BZDBCache::texture) {
+	drawVTN();
+      } else {
+	drawVN();
+      }
     } else {
-      drawVN();
-    }
-  } else {
-    if (BZDBCache::texture) {
-      drawVT();
-    } else {
-      drawV();
+      if (BZDBCache::texture) {
+	drawVT();
+      } else {
+	drawV();
+      }
     }
   }
 
@@ -83,78 +194,36 @@ void MeshFragSceneNode::Geometry::render()
     RENDERER.reenableLights();
   }
 
+  addTriangleCount(triangles);
+
+  return;
+}
+
+
+void MeshFragSceneNode::Geometry::renderRadar()
+{
+  const int triangles = sceneNode->arrayCount;
+  if (list != INVALID_GL_LIST_ID) {
+    glCallList(list);
+  } else {
+    glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
+    glDrawArrays(GL_TRIANGLES, 0, triangles * 3);
+  }
+  addTriangleCount(triangles);
   return;
 }
 
 
 void MeshFragSceneNode::Geometry::renderShadow()
 {
-  drawV();
-  return;
-}
-
-
-void MeshFragSceneNode::Geometry::drawV() const
-{
-  glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
-  glEnableClientState(GL_VERTEX_ARRAY);
-
-  glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
-
-  glDisableClientState(GL_VERTEX_ARRAY);
-
-  return;
-}
-
-
-void MeshFragSceneNode::Geometry::drawVT() const
-{
-  glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
-  glEnableClientState(GL_VERTEX_ARRAY);
-  glTexCoordPointer(2, GL_FLOAT, 0, sceneNode->texcoords);
-  glEnableClientState(GL_TEXTURE_COORD_ARRAY);
-
-  glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
-
-  glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-  glDisableClientState(GL_VERTEX_ARRAY);
-
-  return;
-}
-
-
-void MeshFragSceneNode::Geometry::drawVN() const
-{
-  glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
-  glEnableClientState(GL_VERTEX_ARRAY);
-  glNormalPointer(GL_FLOAT, 0, sceneNode->normals);
-  glEnableClientState(GL_NORMAL_ARRAY);
-
-  glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
-
-  glDisableClientState(GL_NORMAL_ARRAY);
-  glDisableClientState(GL_VERTEX_ARRAY);
-
-  return;
-}
-
-
-void MeshFragSceneNode::Geometry::drawVTN() const
-{
-
-  glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
-  glEnableClientState(GL_VERTEX_ARRAY);
-  glNormalPointer(GL_FLOAT, 0, sceneNode->normals);
-  glEnableClientState(GL_NORMAL_ARRAY);
-  glTexCoordPointer(2, GL_FLOAT, 0, sceneNode->texcoords);
-  glEnableClientState(GL_TEXTURE_COORD_ARRAY);
-
-  glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
-
-  glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-  glDisableClientState(GL_NORMAL_ARRAY);
-  glDisableClientState(GL_VERTEX_ARRAY);
-
+  const int triangles = sceneNode->arrayCount;
+  if (list != INVALID_GL_LIST_ID) {
+    glCallList(list);
+  } else {
+    glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
+    glDrawArrays(GL_TRIANGLES, 0, triangles * 3);
+  }
+  addTriangleCount(triangles);
   return;
 }
 
@@ -179,6 +248,12 @@ MeshFragSceneNode::MeshFragSceneNode(int _faceCount, const MeshFace** _faces)
   static const float fakePlane[4] = {0.0f, 0.0f, 1.0f, 0.0f};
   setPlane(fakePlane);
 
+  const BzMaterial* bzmat = faces[0]->getMaterial();
+
+  // disable radar and shadows if required
+  noRadar = bzmat->getNoRadar();
+  noShadow = bzmat->getNoShadow();
+
   // set lod info
   setNumLODs(0, NULL /* unused because LOD = 0 */);
 
@@ -266,6 +341,8 @@ MeshFragSceneNode::MeshFragSceneNode(int _faceCount, const MeshFace** _faces)
 
   assert(arrayIndex == (arrayCount * 3));
 
+  renderNode.init(); // setup the display list
+
   return;
 }
 
@@ -334,14 +411,33 @@ void MeshFragSceneNode::addRenderNodes(SceneRenderer& renderer)
 
 void MeshFragSceneNode::addShadowNodes(SceneRenderer& renderer)
 {
-  const GLfloat* dyncol = getDynamicColor();
-  if ((dyncol == NULL) || (dyncol[3] != 0.0f)) {
-    renderer.addShadowNode(&renderNode);
+  if (!noShadow) {
+    const GLfloat* dyncol = getDynamicColor();
+    if ((dyncol == NULL) || (dyncol[3] != 0.0f)) {
+      renderer.addShadowNode(&renderNode);
+    }
   }
   return;
 }
 
 
+void MeshFragSceneNode::renderRadar()
+{
+  if (!noRadar) {
+    renderNode.renderRadar();
+  }
+  return;
+}
+
+
+void MeshFragSceneNode::getRenderNodes(std::vector<RenderSet>& rnodes)
+{
+  RenderSet rs = { &renderNode, getWallGState() };
+  rnodes.push_back(rs);
+  return;
+}
+
+
 // Local Variables: ***
 // mode:C++ ***
 // tab-width: 8 ***
