@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 // bzflag common header
@@ -61,6 +61,7 @@ QuadWallSceneNode::Geometry::Geometry(QuadWallSceneNode* _wall,
       uv[n][1] = vOffset + t * vRepeats;
     }
   }
+  triangles = 2 * (uCount * vCount);
 }
 
 QuadWallSceneNode::Geometry::~Geometry()
@@ -117,7 +118,7 @@ void			QuadWallSceneNode::Geometry::render()
   } else {
     drawV();
   }
-
+  addTriangleCount(triangles);
   return;
 }
 
@@ -130,6 +131,7 @@ void			QuadWallSceneNode::Geometry::renderShadow()
   glVertex3fv(vertex[last + ds]);
   glVertex3fv(vertex[ds]);
   glEnd();
+  addTriangleCount(2);
 }
 
 void			QuadWallSceneNode::Geometry::drawV() const
@@ -183,20 +185,22 @@ void			QuadWallSceneNode::init(const GLfloat base[3],
 				bool makeLODs)
 {
   // record plane and bounding sphere info
-  GLfloat plane[4], sphere[4];
-  plane[0] = uEdge[1] * vEdge[2] - uEdge[2] * vEdge[1];
-  plane[1] = uEdge[2] * vEdge[0] - uEdge[0] * vEdge[2];
-  plane[2] = uEdge[0] * vEdge[1] - uEdge[1] * vEdge[0];
-  plane[3] = -(plane[0] * base[0] + plane[1] * base[1] + plane[2] * base[2]);
-  setPlane(plane);
-  sphere[0] = 0.5f * (uEdge[0] + vEdge[0]);
-  sphere[1] = 0.5f * (uEdge[1] + vEdge[1]);
-  sphere[2] = 0.5f * (uEdge[2] + vEdge[2]);
-  sphere[3] = sphere[0]*sphere[0] + sphere[1]*sphere[1] + sphere[2]*sphere[2];
-  sphere[0] += base[0];
-  sphere[1] += base[1];
-  sphere[2] += base[2];
-  setSphere(sphere);
+  GLfloat myPlane[4], mySphere[4];
+  myPlane[0] = uEdge[1] * vEdge[2] - uEdge[2] * vEdge[1];
+  myPlane[1] = uEdge[2] * vEdge[0] - uEdge[0] * vEdge[2];
+  myPlane[2] = uEdge[0] * vEdge[1] - uEdge[1] * vEdge[0];
+  myPlane[3] = -(myPlane[0] * base[0] + myPlane[1] * base[1]
+		 + myPlane[2] * base[2]);
+  setPlane(myPlane);
+  mySphere[0] = 0.5f * (uEdge[0] + vEdge[0]);
+  mySphere[1] = 0.5f * (uEdge[1] + vEdge[1]);
+  mySphere[2] = 0.5f * (uEdge[2] + vEdge[2]);
+  mySphere[3] = mySphere[0]*mySphere[0] + mySphere[1]*mySphere[1]
+    + mySphere[2]*mySphere[2];
+  mySphere[0] += base[0];
+  mySphere[1] += base[1];
+  mySphere[2] += base[2];
+  setSphere(mySphere);
 
   // get length of sides
   const float uLength = sqrtf(float(uEdge[0] * uEdge[0] +
@@ -328,7 +332,7 @@ QuadWallSceneNode::~QuadWallSceneNode()
   delete shadowNode;
 }
 
-int			QuadWallSceneNode::split(const float* plane,
+int			QuadWallSceneNode::split(const float *_plane,
 				SceneNode*& front, SceneNode*& back) const
 {
   // need to reorder vertices into counterclockwise order
@@ -343,7 +347,7 @@ int			QuadWallSceneNode::split(const float* plane,
     uv[i][0] = nodes[0]->uv[j][0];
     uv[i][1] = nodes[0]->uv[j][1];
   }
-  return WallSceneNode::splitWall(plane, vertex, uv, front, back);
+  return WallSceneNode::splitWall(_plane, vertex, uv, front, back);
 }
 
 void			QuadWallSceneNode::addRenderNodes(
@@ -389,6 +393,23 @@ const GLfloat*	  QuadWallSceneNode::getVertex (int vertex) const
 }
 
 
+void QuadWallSceneNode::getRenderNodes(std::vector<RenderSet>& rnodes)
+{
+  RenderSet rs = { nodes[0], getWallGState() };
+  rnodes.push_back(rs);
+  return;
+}
+
+
+void QuadWallSceneNode::renderRadar()
+{
+  if (plane[2] > 0.0f) {
+    nodes[0]->renderRadar();
+  }
+  return;
+}
+
+
 // Local Variables: ***
 // mode:C++ ***
 // tab-width: 8 ***
