@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 #define _NO_LIST_ID 0xffffffff
 
@@ -20,6 +20,7 @@
 
 // system headers
 #include <math.h>
+#include <string.h>
 
 // common implementation headers
 #include "StateDatabase.h"
@@ -31,7 +32,9 @@
 
 using namespace TankGeometryEnums;
 
-const float MuzzleMaxX = 4.94f;
+static const float MuzzleMaxX = 4.94f;
+static const float maxExplosionVel = 40.0f;
+static const float vertExplosionRatio = 0.5f;
 
 
 // parts: body, turret, barrel, left tread, right tread
@@ -202,7 +205,7 @@ void TankSceneNode::notifyStyleChange()
 
   OpenGLGStateBuilder builder3(jumpJetsGState);
   builder3.setCulling(GL_NONE);
-  builder3.setBlending(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+  builder3.setBlending(GL_SRC_ALPHA, GL_ONE);
   jumpJetsGState = builder3.getState();
 }
 
@@ -217,9 +220,9 @@ void TankSceneNode::addRenderNodes(SceneRenderer& renderer)
   }
 
   // pick level of detail
-  const GLfloat* sphere = getSphere();
+  const GLfloat* mySphere = getSphere();
   const ViewFrustum& view = renderer.getViewFrustum();
-  const float size = sphere[3] *
+  const float size = mySphere[3] *
 		     (view.getAreaFactor() /getDistance(view.getEye()));
 
   // set the level of detail
@@ -249,8 +252,8 @@ void TankSceneNode::addRenderNodes(SceneRenderer& renderer)
   // if drawing in sorted order then decide which order
   if (sort || transparent || narrow) {
     const GLfloat* eye = view.getEye();
-    GLfloat dx = eye[0] - sphere[0];
-    GLfloat dy = eye[1] - sphere[1];
+    GLfloat dx = eye[0] - mySphere[0];
+    GLfloat dy = eye[1] - mySphere[1];
     const float radians = (float)(azimuth * M_PI / 180.0);
     const float cos_val = cosf(radians);
     const float sin_val = sinf(radians);
@@ -261,7 +264,7 @@ void TankSceneNode::addRenderNodes(SceneRenderer& renderer)
     const float leftDot = (-sin_val * dx) + (cos_val * dy);
     const bool left = (leftDot > 0.0f);
 
-    const bool above = eye[2] > sphere[2];
+    const bool above = eye[2] > mySphere[2];
 
     tankRenderNode.sortOrder(above, towards, left);
   }
@@ -286,15 +289,15 @@ void TankSceneNode::addLight(SceneRenderer& renderer)
 {
   if (jumpJetsOn) {
     // the real light
-    jumpJetsRealLight.setColor(jumpJetsScale * 1.0f,
-			       jumpJetsScale * 0.7f,
-			       jumpJetsScale * 0.3f);
+    jumpJetsRealLight.setColor(jumpJetsScale * 1.5f * 2.0f,
+			       jumpJetsScale * 1.0f * 2.0f,
+			       jumpJetsScale * 0.5f * 2.0f);
     renderer.addLight(jumpJetsRealLight);
     // the ground lights
     for (int i = 0; i < 4; i++) {
-      jumpJetsGroundLights[i].setColor(jumpJetsLengths[i] * 1.0f * 0.25f,
-				       jumpJetsLengths[i] * 0.7f * 0.25f,
-				       jumpJetsLengths[i] * 0.3f * 0.25f);
+      jumpJetsGroundLights[i].setColor(jumpJetsLengths[i] * 1.5f * 0.5f,
+				       jumpJetsLengths[i] * 1.0f * 0.5f,
+				       jumpJetsLengths[i] * 0.5f * 0.5f);
       renderer.addLight(jumpJetsGroundLights[i]);
     }
   }
@@ -348,7 +351,7 @@ void TankSceneNode::setThief()
 void TankSceneNode::setDimensions(const float dims[3])
 {
   tankSize = Normal;
-  memcpy (dimensions, dims, sizeof(float[3]));
+  memcpy(dimensions, dims, sizeof(float[3]));
   useDimensions = true;
   return;
 }
@@ -357,6 +360,13 @@ void TankSceneNode::setDimensions(const float dims[3])
 void TankSceneNode::setExplodeFraction(float t)
 {
   explodeFraction = t;
+  if (t != 0.0f) {
+    const float radius = sqrtf(getSphere()[3]);
+    const float radinc = t * maxExplosionVel;
+    const float newrad = radius + radinc;
+    setRadius(newrad * newrad);
+  }
+  return;
 }
 
 
@@ -376,9 +386,9 @@ void TankSceneNode::setJumpJets(float scale)
       const float radians = (float)(azimuth * (M_PI / 180.0));
       const float cos_val = cosf(radians);
       const float sin_val = sinf(radians);
-      const float* scale = TankGeometryMgr::getScaleFactor(tankSize);
+      const float* scaleFactor = TankGeometryMgr::getScaleFactor(tankSize);
       const float* jm = jumpJetsModel[i];
-      const float v[2] = {jm[0] * scale[0], jm[1] * scale[1]};
+      const float v[2] = {jm[0] * scaleFactor[0], jm[1] * scaleFactor[1]};
       float* jetPos = jumpJetsPositions[i];
       jetPos[0] = pos[0] + ((cos_val * v[0]) - (sin_val * v[1]));
       jetPos[1] = pos[1] + ((cos_val * v[1]) + (sin_val * v[0]));
@@ -394,19 +404,17 @@ void TankSceneNode::setJumpJets(float scale)
 }
 
 
-void TankSceneNode::setClipPlane(const GLfloat* plane)
+void TankSceneNode::setClipPlane(const GLfloat* _plane)
 {
-  if (!plane) {
+  if (!_plane) {
     clip = false;
-  }
-  else {
+  } else {
     clip = true;
-    clipPlane[0] = GLdouble(plane[0]);
-    clipPlane[1] = GLdouble(plane[1]);
-    clipPlane[2] = GLdouble(plane[2]);
-    clipPlane[3] = GLdouble(plane[3]);
+    clipPlane[0] = GLdouble(_plane[0]);
+    clipPlane[1] = GLdouble(_plane[1]);
+    clipPlane[2] = GLdouble(_plane[2]);
+    clipPlane[3] = GLdouble(_plane[3]);
   }
-  return;
 }
 
 
@@ -450,9 +458,17 @@ void TankSceneNode::rebuildExplosion()
     // now an angular velocity -- make sure we get at least 2 complete turns
     spin[i][3] = 360.0f * (5.0f * (float)bzfrand() + 2.0f);
 
-    // make arbitrary 2d translation
-    vel[i][0] = 80.0f * ((float)bzfrand() - 0.5f);
-    vel[i][1] = 80.0f * ((float)bzfrand() - 0.5f);
+    // cheezy spheroid explosion pattern
+    const float vhMax = maxExplosionVel;
+    const float vhMag = vhMax * sinf((float)(M_PI * 0.5 * bzfrand()));
+    const float vhAngle = (float)(2.0 * M_PI * bzfrand());
+    vel[i][0] = cosf(vhAngle) * vhMag;
+    vel[i][1] = sinf(vhAngle) * vhMag;
+    const float vz = sqrtf(fabsf((vhMax*vhMax) - (vhMag*vhMag)));
+    vel[i][2] = vz * vertExplosionRatio; // flatten it a little
+    if (bzfrand() > 0.5) {
+      vel[i][2] = -vel[i][2];
+    }
   }
   return;
 }
@@ -461,18 +477,18 @@ void TankSceneNode::rebuildExplosion()
 void TankSceneNode::renderRadar()
 {
   const float angleCopy = azimuth;
-  const float* sphere = getSphere();
+  const float* mySphere = getSphere();
   float posCopy[3];
-  memcpy(posCopy, sphere, sizeof(float[3]));
+  memcpy(posCopy, mySphere, sizeof(float[3]));
 
   // allow negative values for burrowed clipping
   float tankPos[3];
   tankPos[0] = 0.0f;
   tankPos[1] = 0.0f;
-  if (sphere[2] >= 0.0f) {
+  if (mySphere[2] >= 0.0f) {
     tankPos[2] = 0.0f;
   } else {
-    tankPos[2] = sphere[2];
+    tankPos[2] = mySphere[2];
   }
 
   setCenter(tankPos);
@@ -499,6 +515,20 @@ void TankSceneNode::renderRadar()
 }
 
 
+bool TankSceneNode::cullShadow(int planeCount, const float (*planes)[4]) const
+{
+  const float* s = getSphere();
+  for (int i = 0; i < planeCount; i++) {
+    const float* p = planes[i];
+    const float d = (p[0] * s[0]) + (p[1] * s[1]) + (p[2] * s[2]) + p[3];
+    if ((d < 0.0f) && ((d * d) > s[3])) {
+      return true;
+    }
+  }
+  return false;
+}
+
+
 //
 // TankIDLSceneNode
 //
@@ -949,7 +979,6 @@ void TankSceneNode::TankRenderNode::render()
     }
   }
 
-
   // re-enable the dynamic lights
   if (switchLights) {
     RENDERER.reenableLights();
@@ -1018,6 +1047,7 @@ void TankSceneNode::TankRenderNode::renderRightParts()
 
 void TankSceneNode::TankRenderNode::renderNarrowWithDepth()
 {
+  glDepthFunc(GL_LEQUAL);
   // render the middle stuff
   renderPart(Body);
   renderPart(Turret);
@@ -1037,8 +1067,6 @@ void TankSceneNode::TankRenderNode::renderNarrowWithDepth()
   const float offsetFactor = -0.1f;
   const float offsetDepth = -1.0f;
 
-  glDepthFunc(GL_LEQUAL);
-
   glPolygonOffset(1.0f * offsetFactor, 1.0f * offsetDepth);
   if (left) {
     renderPart(LeftCasing);
@@ -1065,13 +1093,12 @@ void TankSceneNode::TankRenderNode::renderNarrowWithDepth()
     renderPart(RightTread);
   }
 
-  glDepthFunc(GL_LESS);
-
   if (usingPolyOffset) {
     glPolygonOffset(factor, units);
   } else {
     glDisable(GL_POLYGON_OFFSET_FILL);
   }
+  glDepthFunc(GL_LESS);
 
   return;
 }
@@ -1135,7 +1162,7 @@ void TankSceneNode::TankRenderNode::renderPart(TankPart part)
     const float* cog = centerOfGravity[part];
     glTranslatef(cog[0] + (explodeFraction * vel[0]),
 		 cog[1] + (explodeFraction * vel[1]),
-		 cog[2]);
+		 cog[2] + (explodeFraction * vel[2]));
     glRotatef(spin[3] * explodeFraction, spin[0], spin[1], spin[2]);
     glTranslatef(-cog[0], -cog[1], -cog[2]);
   }
@@ -1159,6 +1186,10 @@ void TankSceneNode::TankRenderNode::renderPart(TankPart part)
   // draw the part
   glCallList(list);
 
+  // add to the triangle count
+  addTriangleCount(TankGeometryMgr::getPartTriangleCount(
+				      shadow, part, drawSize, drawLOD));
+
   // draw the lights on the turret
   if ((part == Turret) && !isExploding && !isShadow) {
     renderLights();
@@ -1317,6 +1348,8 @@ void TankSceneNode::TankRenderNode::renderLights()
   glPointSize(1.0f);
   sceneNode->gstate.setState();
 
+  addTriangleCount(4);
+
   return;
 }
 
@@ -1378,6 +1411,8 @@ void TankSceneNode::TankRenderNode::renderJumpJets()
 
   glDisable(GL_CLIP_PLANE1);
 
+  addTriangleCount(4);
+
   return;
 }
 
