@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,6 +13,7 @@
 #include "common.h"
 #include "PNGImageFile.h"
 #include <iostream>
+#include <string.h>
 #include "Pack.h"
 #include "bzfio.h"
 #include "../zlib/zconf.h"
@@ -123,7 +124,7 @@ PNGImageFile::PNGImageFile(std::istream* input) : ImageFile(input), palette(NULL
 
   init(channels, myWidth, myHeight);
 
-  DEBUG4("Read PNG: Width %d, Height %d, Bit depth %d, Color type %d, Filter Method %d, "
+  logDebugMessage(4,"Read PNG: Width %d, Height %d, Bit depth %d, Color type %d, Filter Method %d, "
 	 "Interlace Method %d, Channels %d.\n",
 	 myWidth, myHeight, bitDepth, colorDepth, filterMethod, interlaceMethod, channels);
 }
@@ -186,7 +187,7 @@ bool					PNGImageFile::read(void* buffer)
 
   err = inflateInit(&zStream);
   if (err != Z_OK) {
-    DEBUG3("PNGImageFile: inflateInit() error\n");
+    logDebugMessage(3,"PNGImageFile: inflateInit() error\n");
     delete c;
     return false;
   }
@@ -216,8 +217,8 @@ bool					PNGImageFile::read(void* buffer)
       err = inflate(&zStream, Z_SYNC_FLUSH);
     }
 
-    if ((err != Z_STREAM_END) && (err != Z_OK)) {
-      DEBUG3("PNGImageFile: Z_STREAM error\n");
+    if ((err != Z_STREAM_END) && (err != Z_OK) && (zStream.avail_in != 0)) {
+      logDebugMessage(3,"PNGImageFile: Z_STREAM error: %d\n", err);
       delete c;
       return false;
     }
@@ -450,7 +451,7 @@ bool PNGImageFile::filter()
     }
 
     default: {
-      DEBUG3("PNGImageFile: unknown filter type (%s)\n", filterType);
+      logDebugMessage(3,"PNGImageFile: unknown filter type (%s)\n", filterType);
       return false;
     }
   }
