@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #ifndef BZF_SGI_IMAGE_FILE_H
@@ -15,14 +15,18 @@
 
 #include "ImageFile.h"
 
+
+/** This class represents a SGI image file. It implements read() from
+    ImageFile. */
 class SGIImageFile : public ImageFile {
 public:
   SGIImageFile(std::istream*);
   virtual ~SGIImageFile();
 
+  /** This function returns the default extension of SGI image files. */
   static std::string	getExtension();
 
-  // ImageFile overrides
+  /** This function reads image data from a SGI image file. */
   virtual bool		read(void* buffer);
 
 protected:
