@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -17,6 +17,15 @@
 
 #define	ADV(_b, _t)	((void*)(((char*)(_b)) + sizeof(_t)))
 
+//
+// Unions
+//
+
+union floatintuni {
+  float floatval;
+  uint32_t intval;
+};
+
 
 //
 // Buffer Overrun Checks
@@ -93,23 +102,27 @@ void*			nboPackUInt(void* b, uint32_t v)
 void*			nboPackFloat(void* b, float v)
 {
   // hope that float is a 4 byte IEEE 754 standard encoding
-  uint32_t x = htonl(*((uint32_t*)&v));
-  ::memcpy(b, &x, sizeof(float));
-  return ADV(b, float);
+  floatintuni u;
+  u.floatval = v;
+
+  uint32_t x = (uint32_t)htonl(u.intval);
+  ::memcpy(b, &x, sizeof(uint32_t));
+  return ADV(b, uint32_t);
 }
 
 void*			nboPackVector(void* b, const float *v)
 {
   // hope that float is a 4 byte IEEE 754 standard encoding
-  uint32_t  data[3];
-  uint32_t *pV = (uint32_t *)v;
-  uint32_t *pB = (uint32_t *)data;
+  floatintuni u;
+  uint32_t data[3];
 
-  *(pB++) = htonl(*(pV++));
-  *(pB++) = htonl(*(pV++));
-  *pB = htonl(*pV);
-  ::memcpy( b, data, 3*sizeof(float));
-  return (void*) (((char*)b)+3*sizeof(float));
+  for (int i=0; i<3; i++) {
+    u.floatval = v[i];
+    data[i] = (uint32_t)htonl(u.intval);
+  }
+
+  ::memcpy( b, data, 3*sizeof(uint32_t));
+  return (void*) (((char*)b)+3*sizeof(uint32_t));
 }
 
 void*			nboPackString(void* b, const void* m, int len)
@@ -229,9 +242,10 @@ void*			nboUnpackFloat(void* b, float& v)
   // hope that float is a 4 byte IEEE 754 standard encoding
   uint32_t x;
   ::memcpy(&x, b, sizeof(uint32_t));
-  const uint32_t y = (uint32_t)ntohl(x);
-  v = *((float*)&y);
-  return ADV(b, float);
+  floatintuni u;
+  u.intval = (uint32_t)ntohl(x);
+  v = u.floatval;
+  return ADV(b, uint32_t);
 }
 
 void*			nboUnpackVector(void* b, float *v)
@@ -247,13 +261,14 @@ void*			nboUnpackVector(void* b, float *v)
   }
   // hope that float is a 4 byte IEEE 754 standard encoding
   uint32_t data[3];
-  ::memcpy( data, b, 3*sizeof(float));
-  uint32_t *pV = (uint32_t *)v;
-  uint32_t *pB = (uint32_t *)data;
+  floatintuni u;
+  ::memcpy( data, b, 3*sizeof(uint32_t));
+
+  for (int i=0; i<3; i++) {
+    u.intval = (uint32_t)ntohl(data[i]);
+    v[i] = u.floatval;
+  }
 
-  *(pV++) = (uint32_t)ntohl(*(pB++));
-  *(pV++) = (uint32_t)ntohl(*(pB++));
-  *pV = (uint32_t)ntohl(*pB);
   return (void *) (((char*)b) + 3*sizeof(float));
 }
 
