@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* interface header */
@@ -105,7 +105,7 @@ bool			PingPacket::waitForReply(int fd,
   TimeKeeper currentTime = startTime;
   do {
     // prepare timeout
-    const float timeLeft = blockTime - (currentTime - startTime);
+    const float timeLeft = float(blockTime - (currentTime - startTime));
     struct timeval timeout;
     timeout.tv_sec = long(floorf(timeLeft));
     timeout.tv_usec = long(1.0e+6f * (timeLeft - floorf(timeLeft)));
@@ -113,7 +113,7 @@ bool			PingPacket::waitForReply(int fd,
     // wait for input
     fd_set read_set;
     FD_ZERO(&read_set);
-    _FD_SET(fd, &read_set);
+    FD_SET((unsigned int)fd, &read_set);
     int nfound = select(fd+1, (fd_set*)&read_set, NULL, NULL, &timeout);
 
     // if got a message read it.  if a ping packet and from right
