@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #include <math.h>
@@ -214,14 +214,14 @@ void OpenGLLight::calculateImportance(const ViewFrustum& frustum)
 		   (p[2] * pos[2]) + p[3];
 
   // cull against the frustum planes
-  // (right, left, up, and down)
   if (fd > 0.0f) {
     sphereCull = false; // don't need a sphere cull
-    for (int i = 1; i < 5; i++) {
-      const float* p = frustum.getSide(i);
-      const float len = (p[0] * pos[0]) +
-			(p[1] * pos[1]) +
-			(p[2] * pos[2]) + p[3];
+    const int planeCount = frustum.getPlaneCount();
+    for (int i = 1; i < planeCount; i++) {
+      const float* plane = frustum.getSide(i);
+      const float len = (plane[0] * pos[0]) +
+			(plane[1] * pos[1]) +
+			(plane[2] * pos[2]) + plane[3];
       if (len < -maxDist) {
 	importance = -1.0f;
 	return;
@@ -267,8 +267,13 @@ void OpenGLLight::enableLight(int index, bool on) // const
 }
 
 
-void OpenGLLight::execute(int index) const
+void OpenGLLight::execute(int index, bool useList) const
 {
+  if (!useList) {
+    genLight((GLenum)(GL_LIGHT0 + index));
+    return;
+  }
+
   // setup the light parameters (buffered in
   // a display list), but do not turn it on.
   if (lists[index] != INVALID_GL_LIST_ID) {
