@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -27,11 +27,6 @@ BzfWindow::~BzfWindow()
 {
 }
 
-void BzfWindow::setFullscreen(bool on) {
-  if (on)
-    setFullscreen();
-}
-
 void			BzfWindow::callExposeCallbacks() const
 {
   const int count = exposeCallbacks.size();
