@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2005 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 #include "common.h"
@@ -38,16 +38,16 @@ SDLDisplay::SDLDisplay() : fullScreen(false), base_width(640),
     printf("Could not Get available video modes: %s.\n", SDL_GetError());
 
   int defaultResolutionIndex = 0;
-  ResInfo** resolutions;
-  int numResolutions = 1;
+  ResInfo** _resolutions;
+  int _numResolutions = 1;
   // No modes available or All resolutions available
   if ((modeList != (SDL_Rect **) 0) && (modeList != (SDL_Rect **) -1)) {
       for (int i = 1; modeList[i]; i++)
 	if ((modeList[i - 1]->w != modeList[i]->w)
 	    || (modeList[i - 1]->h != modeList[i]->h))
-	  numResolutions++;
+	  _numResolutions++;
   };
-  resolutions = new ResInfo*[numResolutions];
+  _resolutions = new ResInfo*[_numResolutions];
 
   if ((modeList != (SDL_Rect **) 0) && (modeList != (SDL_Rect **) -1)) {
     char name[80];
@@ -69,7 +69,7 @@ SDLDisplay::SDLDisplay() : fullScreen(false), base_width(640),
 	if ((modeList[i - 1]->w == w) && (modeList[i - 1]->h == h))
 	  continue;
       sprintf(name, "%dx%d    ", w, h);
-      resolutions[j] = new ResInfo(name, w, h, 0);
+      _resolutions[j] = new ResInfo(name, w, h, 0);
 #ifdef WIN32
       // use a safe default resolution because there are so many screwy drivers out there
       if ((w == defaultWidth) && (h == defaultHeight))
@@ -79,14 +79,15 @@ SDLDisplay::SDLDisplay() : fullScreen(false), base_width(640),
     }
   } else {
     // if no modes then make default
-    resolutions[0] = new ResInfo ("default", 640, 480, 0);
+    _resolutions[0] = new ResInfo ("default", 640, 480, 0);
   }
 
   // limit us to the main display
-  putenv("SDL_SINGLEDISPLAY=1");
+  static char singleDisplayEnv[] = "SDL_SINGLEDISPLAY=1";
+  putenv(singleDisplayEnv);
 
   // register modes
-  initResolutions(resolutions, numResolutions, defaultResolutionIndex);
+  initResolutions(_resolutions, _numResolutions, defaultResolutionIndex);
 
   SDL_EnableUNICODE(1);
 
@@ -100,13 +101,13 @@ SDLDisplay::SDLDisplay() : fullScreen(false), base_width(640),
 SDLDisplay::~SDLDisplay()
 {
   SDL_QuitSubSystem(SDL_INIT_VIDEO);
-};
+}
 
 
 bool SDLDisplay::isEventPending() const
 {
   return (SDL_PollEvent(NULL) == 1);
-};
+}
 
 
 bool SDLDisplay::getEvent(BzfEvent& _event) const
@@ -116,7 +117,7 @@ bool SDLDisplay::getEvent(BzfEvent& _event) const
     return false;
 
   return setupEvent(_event, event);
-};
+}
 
 
 bool SDLDisplay::peekEvent(BzfEvent& _event) const
@@ -289,13 +290,15 @@ bool SDLDisplay::setupEvent(BzfEvent& _event, const SDL_Event& event) const
       } else {
 	_event.type = BzfEvent::Map;
       }
+    else
+      return false;
     break;
 
   default:
     return false;
   }
   return true;
-};
+}
 
 
 void SDLDisplay::getModState(bool &shift, bool &ctrl, bool &alt)
@@ -474,7 +477,7 @@ bool SDLDisplay::getKey(const SDL_Event& sdlEvent, BzfKeyEvent& key) const
       key.button = BzfKeyEvent::NoButton;
   }
 
-  if (key.button == BzfKeyEvent::NoButton)
+  if (key.button == BzfKeyEvent::NoButton) {
     if (unicode) {
       if ((unicode & 0xFF80))
 	return false;
@@ -489,6 +492,7 @@ bool SDLDisplay::getKey(const SDL_Event& sdlEvent, BzfKeyEvent& key) const
       else
 	return false;
     }
+  }
 
   key.shift = 0;
   if (mod & KMOD_SHIFT)
@@ -528,7 +532,11 @@ bool SDLDisplay::createWindow() {
     OpenGLGState::initContext();
     return true;
   }
-};
+
+//   /* Enable vsync */
+//   long sync = 1;
+//   CGLSetParameter (ctx, kCGLCPSwapInterval, &sync);
+}
 
 void SDLDisplay::setFullscreen(bool on) {
   fullScreen = on;
@@ -556,7 +564,7 @@ void SDLDisplay::getWindowSize(int& width, int& height) {
     width  = base_width;
     height = base_height;
   }
-};
+}
 
 void SDLDisplay::enableGrabMouse(bool on) {
   canGrabMouse = on;
@@ -568,7 +576,7 @@ void SDLDisplay::enableGrabMouse(bool on) {
 
 void SDLVisual::setDoubleBuffer(bool on) {
   SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, on ? 1 : 0);
-};
+}
 
 void SDLVisual::setRGBA(int minRed, int minGreen,
 			int minBlue, int minAlpha) {
@@ -576,53 +584,53 @@ void SDLVisual::setRGBA(int minRed, int minGreen,
   SDL_GL_SetAttribute(SDL_GL_GREEN_SIZE, minGreen);
   SDL_GL_SetAttribute(SDL_GL_BLUE_SIZE,  minBlue);
   SDL_GL_SetAttribute(SDL_GL_ALPHA_SIZE, minAlpha);
-};
+}
 
 void SDLVisual::setDepth(int minDepth) {
   SDL_GL_SetAttribute(SDL_GL_DEPTH_SIZE, minDepth);
-};
+}
 
 void SDLVisual::setStencil(int minDepth) {
   SDL_GL_SetAttribute(SDL_GL_STENCIL_SIZE, minDepth);
-};
+}
 
 void SDLVisual::setStereo(bool on) {
   SDL_GL_SetAttribute(SDL_GL_STEREO, on ? 1 : 0);
-};
+}
 
 SDLWindow::SDLWindow(const SDLDisplay* _display, SDLVisual*)
   : BzfWindow(_display), x(-1), y(-1), hasGamma(true)
 {
-};
+}
 
 void SDLWindow::setTitle(const char * title) {
   SDL_WM_SetCaption(title, title);
-};
+}
 
 void SDLWindow::setFullscreen(bool on) {
   ((SDLDisplay *)getDisplay())->setFullscreen(on);
-};
+}
 
 void SDLWindow::iconify(void) {
   SDL_WM_IconifyWindow();
-};
+}
 
-void SDLWindow::warpMouse(int x, int y) {
-  SDL_WarpMouse(x, y);
-};
+void SDLWindow::warpMouse(int _x, int _y) {
+  SDL_WarpMouse(_x, _y);
+}
 
-void SDLWindow::getMouse(int& x, int& y) const {
-  x = mx;
-  y = my;
-};
+void SDLWindow::getMouse(int& _x, int& _y) const {
+  _x = mx;
+  _y = my;
+}
 
 void SDLWindow::setSize(int width, int height) {
   ((SDLDisplay *)getDisplay())->setWindowSize(width, height);
-};
+}
 
 void SDLWindow::getSize(int& width, int& height) const {
   ((SDLDisplay *)getDisplay())->getWindowSize(width, height);
-};
+}
 
 void SDLWindow::setGamma(float gamma) {
   int result = SDL_SetGamma(gamma, gamma, gamma);
@@ -630,7 +638,7 @@ void SDLWindow::setGamma(float gamma) {
     printf("Could not set Gamma: %s.\n", SDL_GetError());
     hasGamma = false;
   }
-};
+}
 
 // Code taken from SDL (not available through the headers)
 static float CalculateGammaFromRamp(Uint16 ramp[256]) {
@@ -670,26 +678,26 @@ float SDLWindow::getGamma() const {
     gamma = (red + green + blue) / 3.0;
   }
   return gamma;
-};
+}
 
 bool SDLWindow::hasGammaControl() const {
   return hasGamma;
-};
+}
 
 void SDLWindow::swapBuffers() {
   SDL_GL_SwapBuffers();
-};
+}
 
 bool SDLWindow::create(void) {
   if (!((SDLDisplay *)getDisplay())->createWindow()) {
     return false;
   }
   return true;
-};
+}
 
 void SDLWindow::enableGrabMouse(bool on) {
   ((SDLDisplay *)getDisplay())->enableGrabMouse(on);
-};
+}
 
 #endif
 
