@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -25,6 +25,7 @@ class SDLMedia : public BzfMedia {
 			SDLMedia();
 			~SDLMedia() {};
 
+    void		setMediaDirectory(const std::string&);
     double		stopwatch(bool);
     bool		openAudio();
     void		closeAudio();
@@ -57,10 +58,8 @@ class SDLMedia : public BzfMedia {
   private:
     bool		audioReady;
     int			audioOutputRate;
-    int			audioBufferSize;
 
-    short*		outputBuffer;
-    int		 sampleToSend;  // next sample to send on outputBuffer
+    bool		outputBufferEmpty;
 
     Uint32		stopwatchTime;
 
@@ -68,6 +67,7 @@ class SDLMedia : public BzfMedia {
     int		 cmdFill;	// from 0 to cmdFill
 
     bool		(*userCallback)(void);
+    SDL_AudioCVT	convert;
 };
 
 #endif // BZF_SDLMEDIA_H
@@ -79,4 +79,3 @@ class SDLMedia : public BzfMedia {
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
