@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993 - 2008 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -220,7 +220,7 @@ void ZSceneDatabase::makeCuller()
   octree->addNodes (staticList, staticCount, cullDepth, cullElements);
 
   float elapsed = (float)(TimeKeeper::getCurrent() - startTime);
-  DEBUG2 ("SceneNode Octree processed in %.3f seconds.\n", elapsed);
+  logDebugMessage(2,"SceneNode Octree processed in %.3f seconds.\n", elapsed);
 
   if (culledList != staticList) {
     delete culledList;
