@@ -1,23 +1,23 @@
 /* gzio.c -- IO on .gz files
- * Copyright (C) 1995-2002 Jean-loup Gailly.
+ * Copyright (C) 1995-2005 Jean-loup Gailly.
  * For conditions of distribution and use, see copyright notice in zlib.h
  *
- * Compile this file with -DNO_DEFLATE to avoid the compression code.
+ * Compile this file with -DNO_GZCOMPRESS to avoid the compression code.
  */
 
-/* @(#) $Id: gzio.c,v 2.1 2005/01/17 23:53:11 brlcad Exp $ */
+/* @(#) $Id: gzio.c 17845 2008-06-25 20:28:39Z timriker $ */
 
-#ifdef __MINGW32__
-#undef __STRICT_ANSI__
-#endif
 #include <stdio.h>
-#ifdef __MINGW32__
-#define __STRICT_ANSI__
-#endif
 
 #include "zutil.h"
 
+#ifdef NO_DEFLATE       /* for compatibility with old definition */
+#  define NO_GZCOMPRESS
+#endif
+
+#ifndef NO_DUMMY_DECL
 struct internal_state {int dummy;}; /* for buggy compilers */
+#endif
 
 #ifndef Z_BUFSIZE
 #  ifdef MAXSEG_64K
@@ -30,10 +30,20 @@ struct internal_state {int dummy;}; /* for buggy compilers */
 #  define Z_PRINTF_BUFSIZE 4096
 #endif
 
+#ifdef __MVS__
+#  pragma map (fdopen , "\174\174FDOPEN")
+   FILE *fdopen(int, const char *);
+#endif
+
+#ifndef STDC
+extern voidp  malloc OF((uInt size));
+extern void   free   OF((voidpf ptr));
+#endif
+
 #define ALLOC(size) malloc(size)
 #define TRYFREE(p) {if (p) free(p);}
 
-static int gz_magic[2] = {0x1f, 0x8b}; /* gzip magic header */
+static int const gz_magic[2] = {0x1f, 0x8b}; /* gzip magic header */
 
 /* gzip flag byte */
 #define ASCII_FLAG   0x01 /* bit 0 set: file probably ascii text */
@@ -55,7 +65,11 @@ typedef struct gz_stream {
     char     *path;   /* path name for debugging only */
     int      transparent; /* 1 if input file is not a .gz file */
     char     mode;    /* 'w' or 'r' */
-    long     startpos; /* start of compressed data in file (header skipped) */
+    z_off_t  start;   /* start of compressed data in file (header skipped) */
+    z_off_t  in;      /* bytes into deflate or inflate */
+    z_off_t  out;     /* bytes out of deflate or inflate */
+    int      back;    /* one character push-back */
+    int      last;    /* true if push-back is last character */
 } gz_stream;
 
 
@@ -71,7 +85,7 @@ local uLong  getLong      OF((gz_stream *s));
      Opens a gzip (.gz) file for reading or writing. The mode parameter
    is as in fopen ("rb" or "wb"). The file is given either by file descriptor
    or path name (if fd == -1).
-     gz_open return NULL if the file could not be opened or if there was
+     gz_open returns NULL if the file could not be opened or if there was
    insufficient memory to allocate the (de)compression state; errno
    can be checked to distinguish the two cases (if errno is zero, the
    zlib error is Z_MEM_ERROR).
@@ -103,6 +117,9 @@ local gzFile gz_open (path, mode, fd)
     s->file = NULL;
     s->z_err = Z_OK;
     s->z_eof = 0;
+    s->in = 0;
+    s->out = 0;
+    s->back = EOF;
     s->crc = crc32(0L, Z_NULL, 0);
     s->msg = NULL;
     s->transparent = 0;
@@ -123,6 +140,8 @@ local gzFile gz_open (path, mode, fd)
 	  strategy = Z_FILTERED;
 	} else if (*p == 'h') {
 	  strategy = Z_HUFFMAN_ONLY;
+	} else if (*p == 'R') {
+	  strategy = Z_RLE;
 	} else {
 	    *m++ = *p; /* copy the mode */
 	}
@@ -130,7 +149,7 @@ local gzFile gz_open (path, mode, fd)
     if (s->mode == '\0') return destroy(s), (gzFile)Z_NULL;
 
     if (s->mode == 'w') {
-#ifdef NO_DEFLATE
+#ifdef NO_GZCOMPRESS
 	err = Z_STREAM_ERROR;
 #else
 	err = deflateInit2(&(s->stream), level,
@@ -169,15 +188,15 @@ local gzFile gz_open (path, mode, fd)
 	 */
 	fprintf(s->file, "%c%c%c%c%c%c%c%c%c%c", gz_magic[0], gz_magic[1],
 	     Z_DEFLATED, 0 /*flags*/, 0,0,0,0 /*time*/, 0 /*xflags*/, OS_CODE);
-	s->startpos = 10L;
+	s->start = 10L;
 	/* We use 10L instead of ftell(s->file) to because ftell causes an
 	 * fflush on some systems. This version of the library doesn't use
-	 * startpos anyway in write mode, so this initialization is not
+	 * start anyway in write mode, so this initialization is not
 	 * necessary.
 	 */
     } else {
 	check_header(s); /* skip the .gz header */
-	s->startpos = (ftell(s->file) - s->stream.avail_in);
+	s->start = ftell(s->file) - s->stream.avail_in;
     }
 
     return (gzFile)s;
@@ -201,7 +220,7 @@ gzFile ZEXPORT gzdopen (fd, mode)
     int fd;
     const char *mode;
 {
-    char name[20];
+    char name[46];      /* allow for up to 128-bit integers */
 
     if (fd < 0) return (gzFile)Z_NULL;
     sprintf(name, "<fd:%d>", fd); /* for debugging */
@@ -245,7 +264,7 @@ local int get_byte(s)
     if (s->z_eof) return EOF;
     if (s->stream.avail_in == 0) {
 	errno = 0;
-	s->stream.avail_in = fread(s->inbuf, 1, Z_BUFSIZE, s->file);
+	s->stream.avail_in = (uInt)fread(s->inbuf, 1, Z_BUFSIZE, s->file);
 	if (s->stream.avail_in == 0) {
 	    s->z_eof = 1;
 	    if (ferror(s->file)) s->z_err = Z_ERRNO;
@@ -274,19 +293,33 @@ local void check_header(s)
     uInt len;
     int c;
 
-    /* Check the gzip magic header */
-    for (len = 0; len < 2; len++) {
-	c = get_byte(s);
-	if (c != gz_magic[len]) {
-	    if (len != 0) s->stream.avail_in++, s->stream.next_in--;
-	    if (c != EOF) {
-		s->stream.avail_in++, s->stream.next_in--;
-		s->transparent = 1;
-	    }
-	    s->z_err = s->stream.avail_in != 0 ? Z_OK : Z_STREAM_END;
+    /* Assure two bytes in the buffer so we can peek ahead -- handle case
+       where first byte of header is at the end of the buffer after the last
+       gzip segment */
+    len = s->stream.avail_in;
+    if (len < 2) {
+	if (len) s->inbuf[0] = s->stream.next_in[0];
+	errno = 0;
+	len = (uInt)fread(s->inbuf + len, 1, Z_BUFSIZE >> len, s->file);
+	if (len == 0 && ferror(s->file)) s->z_err = Z_ERRNO;
+	s->stream.avail_in += len;
+	s->stream.next_in = s->inbuf;
+	if (s->stream.avail_in < 2) {
+	    s->transparent = s->stream.avail_in;
 	    return;
 	}
     }
+
+    /* Peek ahead to check the gzip magic header */
+    if (s->stream.next_in[0] != gz_magic[0] ||
+	s->stream.next_in[1] != gz_magic[1]) {
+	s->transparent = 1;
+	return;
+    }
+    s->stream.avail_in -= 2;
+    s->stream.next_in += 2;
+
+    /* Check the rest of the gzip header */
     method = get_byte(s);
     flags = get_byte(s);
     if (method != Z_DEFLATED || (flags & RESERVED) != 0) {
@@ -330,7 +363,7 @@ local int destroy (s)
 
     if (s->stream.state != NULL) {
 	if (s->mode == 'w') {
-#ifdef NO_DEFLATE
+#ifdef NO_GZCOMPRESS
 	    err = Z_STREAM_ERROR;
 #else
 	    err = deflateEnd(&(s->stream));
@@ -376,6 +409,19 @@ int ZEXPORT gzread (file, buf, len)
     s->stream.next_out = (Bytef*)buf;
     s->stream.avail_out = len;
 
+    if (s->stream.avail_out && s->back != EOF) {
+	*next_out++ = s->back;
+	s->stream.next_out++;
+	s->stream.avail_out--;
+	s->back = EOF;
+	s->out++;
+	start++;
+	if (s->last) {
+	    s->z_err = Z_STREAM_END;
+	    return 1;
+	}
+    }
+
     while (s->stream.avail_out != 0) {
 
 	if (s->transparent) {
@@ -391,19 +437,19 @@ int ZEXPORT gzread (file, buf, len)
 		s->stream.avail_in  -= n;
 	    }
 	    if (s->stream.avail_out > 0) {
-		s->stream.avail_out -= fread(next_out, 1, s->stream.avail_out,
-					     s->file);
+		s->stream.avail_out -=
+		    (uInt)fread(next_out, 1, s->stream.avail_out, s->file);
 	    }
 	    len -= s->stream.avail_out;
-	    s->stream.total_in  += (uLong)len;
-	    s->stream.total_out += (uLong)len;
+	    s->in  += len;
+	    s->out += len;
 	    if (len == 0) s->z_eof = 1;
 	    return (int)len;
 	}
 	if (s->stream.avail_in == 0 && !s->z_eof) {
 
 	    errno = 0;
-	    s->stream.avail_in = fread(s->inbuf, 1, Z_BUFSIZE, s->file);
+	    s->stream.avail_in = (uInt)fread(s->inbuf, 1, Z_BUFSIZE, s->file);
 	    if (s->stream.avail_in == 0) {
 		s->z_eof = 1;
 		if (ferror(s->file)) {
@@ -413,7 +459,11 @@ int ZEXPORT gzread (file, buf, len)
 	    }
 	    s->stream.next_in = s->inbuf;
 	}
+	s->in += s->stream.avail_in;
+	s->out += s->stream.avail_out;
 	s->z_err = inflate(&(s->stream), Z_NO_FLUSH);
+	s->in -= s->stream.avail_in;
+	s->out -= s->stream.avail_out;
 
 	if (s->z_err == Z_STREAM_END) {
 	    /* Check CRC and original size */
@@ -424,18 +474,13 @@ int ZEXPORT gzread (file, buf, len)
 		s->z_err = Z_DATA_ERROR;
 	    } else {
 		(void)getLong(s);
-		/* The uncompressed length returned by above getlong() may
-		 * be different from s->stream.total_out) in case of
-		 * concatenated .gz files. Check for such files:
+		/* The uncompressed length returned by above getlong() may be
+		 * different from s->out in case of concatenated .gz files.
+		 * Check for such files:
 		 */
 		check_header(s);
 		if (s->z_err == Z_OK) {
-		    uLong total_in = s->stream.total_in;
-		    uLong total_out = s->stream.total_out;
-
 		    inflateReset(&(s->stream));
-		    s->stream.total_in = total_in;
-		    s->stream.total_out = total_out;
 		    s->crc = crc32(0L, Z_NULL, 0);
 		}
 	    }
@@ -444,6 +489,9 @@ int ZEXPORT gzread (file, buf, len)
     }
     s->crc = crc32(s->crc, start, (uInt)(s->stream.next_out - start));
 
+    if (len == s->stream.avail_out &&
+	(s->z_err == Z_DATA_ERROR || s->z_err == Z_ERRNO))
+	return -1;
     return (int)(len - s->stream.avail_out);
 }
 
@@ -461,6 +509,25 @@ int ZEXPORT gzgetc(file)
 }
 
 
+/* ===========================================================================
+      Push one byte back onto the stream.
+*/
+int ZEXPORT gzungetc(c, file)
+    int c;
+    gzFile file;
+{
+    gz_stream *s = (gz_stream*)file;
+
+    if (s == NULL || s->mode != 'r' || c == EOF || s->back != EOF) return EOF;
+    s->back = c;
+    s->out--;
+    s->last = (s->z_err == Z_STREAM_END);
+    if (s->last) s->z_err = Z_OK;
+    s->z_eof = 0;
+    return c;
+}
+
+
 /* ===========================================================================
       Reads bytes from the compressed file until len-1 characters are
    read, or a newline character is read and transferred to buf, or an
@@ -484,14 +551,14 @@ char * ZEXPORT gzgets(file, buf, len)
 }
 
 
-#ifndef NO_DEFLATE
+#ifndef NO_GZCOMPRESS
 /* ===========================================================================
      Writes the given number of uncompressed bytes into the compressed file.
    gzwrite returns the number of bytes actually written (0 in case of error).
 */
 int ZEXPORT gzwrite (file, buf, len)
     gzFile file;
-    const voidp buf;
+    voidpc buf;
     unsigned len;
 {
     gz_stream *s = (gz_stream*)file;
@@ -512,7 +579,11 @@ int ZEXPORT gzwrite (file, buf, len)
 	    }
 	    s->stream.avail_out = Z_BUFSIZE;
 	}
+	s->in += s->stream.avail_in;
+	s->out += s->stream.avail_out;
 	s->z_err = deflate(&(s->stream), Z_NO_FLUSH);
+	s->in -= s->stream.avail_in;
+	s->out -= s->stream.avail_out;
 	if (s->z_err != Z_OK) break;
     }
     s->crc = crc32(s->crc, (const Bytef *)buf, len);
@@ -520,6 +591,7 @@ int ZEXPORT gzwrite (file, buf, len)
     return (int)(len - s->stream.avail_in);
 }
 
+
 /* ===========================================================================
      Converts, formats, and writes the args to the compressed file under
    control of the format string, as in fprintf. gzprintf returns the number of
@@ -534,16 +606,30 @@ int ZEXPORTVA gzprintf (gzFile file, const char *format, /* args */ ...)
     va_list va;
     int len;
 
+    buf[sizeof(buf) - 1] = 0;
     va_start(va, format);
-#ifdef HAS_vsnprintf
-    (void)vsnprintf(buf, sizeof(buf), format, va);
-#else
+#ifdef NO_vsnprintf
+#  ifdef HAS_vsprintf_void
     (void)vsprintf(buf, format, va);
-#endif
     va_end(va);
-    len = strlen(buf); /* some *sprintf don't return the nb of bytes written */
-    if (len <= 0) return 0;
-
+    for (len = 0; len < sizeof(buf); len++)
+	if (buf[len] == 0) break;
+#  else
+    len = vsprintf(buf, format, va);
+    va_end(va);
+#  endif
+#else
+#  ifdef HAS_vsnprintf_void
+    (void)vsnprintf(buf, sizeof(buf), format, va);
+    va_end(va);
+    len = strlen(buf);
+#  else
+    len = vsnprintf(buf, sizeof(buf), format, va);
+    va_end(va);
+#  endif
+#endif
+    if (len <= 0 || len >= (int)sizeof(buf) || buf[sizeof(buf) - 1] != 0)
+	return 0;
     return gzwrite(file, buf, (unsigned)len);
 }
 #else /* not ANSI C */
@@ -558,16 +644,29 @@ int ZEXPORTVA gzprintf (file, format, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10,
     char buf[Z_PRINTF_BUFSIZE];
     int len;
 
-#ifdef HAS_snprintf
-    snprintf(buf, sizeof(buf), format, a1, a2, a3, a4, a5, a6, a7, a8,
-	     a9, a10, a11, a12, a13, a14, a15, a16, a17, a18, a19, a20);
-#else
+    buf[sizeof(buf) - 1] = 0;
+#ifdef NO_snprintf
+#  ifdef HAS_sprintf_void
     sprintf(buf, format, a1, a2, a3, a4, a5, a6, a7, a8,
 	    a9, a10, a11, a12, a13, a14, a15, a16, a17, a18, a19, a20);
+    for (len = 0; len < sizeof(buf); len++)
+	if (buf[len] == 0) break;
+#  else
+    len = sprintf(buf, format, a1, a2, a3, a4, a5, a6, a7, a8,
+		a9, a10, a11, a12, a13, a14, a15, a16, a17, a18, a19, a20);
+#  endif
+#else
+#  ifdef HAS_snprintf_void
+    snprintf(buf, sizeof(buf), format, a1, a2, a3, a4, a5, a6, a7, a8,
+	     a9, a10, a11, a12, a13, a14, a15, a16, a17, a18, a19, a20);
+    len = strlen(buf);
+#  else
+    len = snprintf(buf, sizeof(buf), format, a1, a2, a3, a4, a5, a6, a7, a8,
+		 a9, a10, a11, a12, a13, a14, a15, a16, a17, a18, a19, a20);
+#  endif
 #endif
-    len = strlen(buf); /* old sprintf doesn't return the nb of bytes written */
-    if (len <= 0) return 0;
-
+    if (len <= 0 || len >= sizeof(buf) || buf[sizeof(buf) - 1] != 0)
+	return 0;
     return gzwrite(file, buf, len);
 }
 #endif
@@ -627,7 +726,9 @@ local int do_flush (file, flush)
 	    s->stream.avail_out = Z_BUFSIZE;
 	}
 	if (done) break;
+	s->out += s->stream.avail_out;
 	s->z_err = deflate(&(s->stream), flush);
+	s->out -= s->stream.avail_out;
 
 	/* Ignore the second of two consecutive flushes: */
 	if (len == 0 && s->z_err == Z_BUF_ERROR) s->z_err = Z_OK;
@@ -653,7 +754,7 @@ int ZEXPORT gzflush (file, flush)
     fflush(s->file);
     return  s->z_err == Z_STREAM_END ? Z_OK : s->z_err;
 }
-#endif /* NO_DEFLATE */
+#endif /* NO_GZCOMPRESS */
 
 /* ===========================================================================
       Sets the starting position for the next gzread or gzwrite on the given
@@ -676,17 +777,18 @@ z_off_t ZEXPORT gzseek (file, offset, whence)
     }
 
     if (s->mode == 'w') {
-#ifdef NO_DEFLATE
+#ifdef NO_GZCOMPRESS
 	return -1L;
 #else
 	if (whence == SEEK_SET) {
-	    offset -= s->stream.total_in;
+	    offset -= s->in;
 	}
 	if (offset < 0) return -1L;
 
 	/* At this point, offset is the number of zero bytes to write. */
 	if (s->inbuf == Z_NULL) {
 	    s->inbuf = (Byte*)ALLOC(Z_BUFSIZE); /* for seeking */
+	    if (s->inbuf == Z_NULL) return -1L;
 	    zmemzero(s->inbuf, Z_BUFSIZE);
 	}
 	while (offset > 0)  {
@@ -698,30 +800,31 @@ z_off_t ZEXPORT gzseek (file, offset, whence)
 
 	    offset -= size;
 	}
-	return (z_off_t)s->stream.total_in;
+	return s->in;
 #endif
     }
     /* Rest of function is for reading only */
 
     /* compute absolute position */
     if (whence == SEEK_CUR) {
-	offset += s->stream.total_out;
+	offset += s->out;
     }
     if (offset < 0) return -1L;
 
     if (s->transparent) {
 	/* map to fseek */
+	s->back = EOF;
 	s->stream.avail_in = 0;
 	s->stream.next_in = s->inbuf;
 	if (fseek(s->file, offset, SEEK_SET) < 0) return -1L;
 
-	s->stream.total_in = s->stream.total_out = (uLong)offset;
+	s->in = s->out = offset;
 	return offset;
     }
 
     /* For a negative seek, rewind and use positive seek */
-    if ((uLong)offset >= s->stream.total_out) {
-	offset -= s->stream.total_out;
+    if (offset >= s->out) {
+	offset -= s->out;
     } else if (gzrewind(file) < 0) {
 	return -1L;
     }
@@ -729,6 +832,13 @@ z_off_t ZEXPORT gzseek (file, offset, whence)
 
     if (offset != 0 && s->outbuf == Z_NULL) {
 	s->outbuf = (Byte*)ALLOC(Z_BUFSIZE);
+	if (s->outbuf == Z_NULL) return -1L;
+    }
+    if (offset && s->back != EOF) {
+	s->back = EOF;
+	s->out++;
+	offset--;
+	if (s->last) s->z_err = Z_STREAM_END;
     }
     while (offset > 0)  {
 	int size = Z_BUFSIZE;
@@ -738,7 +848,7 @@ z_off_t ZEXPORT gzseek (file, offset, whence)
 	if (size <= 0) return -1L;
 	offset -= size;
     }
-    return (z_off_t)s->stream.total_out;
+    return s->out;
 }
 
 /* ===========================================================================
@@ -753,17 +863,14 @@ int ZEXPORT gzrewind (file)
 
     s->z_err = Z_OK;
     s->z_eof = 0;
+    s->back = EOF;
     s->stream.avail_in = 0;
     s->stream.next_in = s->inbuf;
     s->crc = crc32(0L, Z_NULL, 0);
-
-    if (s->startpos == 0) { /* not a compressed file */
-	rewind(s->file);
-	return 0;
-    }
-
-    (void) inflateReset(&s->stream);
-    return fseek(s->file, s->startpos, SEEK_SET);
+    if (!s->transparent) (void)inflateReset(&s->stream);
+    s->in = 0;
+    s->out = 0;
+    return fseek(s->file, s->start, SEEK_SET);
 }
 
 /* ===========================================================================
@@ -786,7 +893,25 @@ int ZEXPORT gzeof (file)
 {
     gz_stream *s = (gz_stream*)file;
 
-    return (s == NULL || s->mode != 'r') ? 0 : s->z_eof;
+    /* With concatenated compressed files that can have embedded
+     * crc trailers, z_eof is no longer the only/best indicator of EOF
+     * on a gz_stream. Handle end-of-stream error explicitly here.
+     */
+    if (s == NULL || s->mode != 'r') return 0;
+    if (s->z_eof) return 1;
+    return s->z_err == Z_STREAM_END;
+}
+
+/* ===========================================================================
+     Returns 1 if reading and doing so transparently, otherwise zero.
+*/
+int ZEXPORT gzdirect (file)
+    gzFile file;
+{
+    gz_stream *s = (gz_stream*)file;
+
+    if (s == NULL || s->mode != 'r') return 0;
+    return s->transparent;
 }
 
 /* ===========================================================================
@@ -828,33 +953,38 @@ local uLong getLong (s)
 int ZEXPORT gzclose (file)
     gzFile file;
 {
-    int err;
     gz_stream *s = (gz_stream*)file;
 
     if (s == NULL) return Z_STREAM_ERROR;
 
     if (s->mode == 'w') {
-#ifdef NO_DEFLATE
+#ifdef NO_GZCOMPRESS
 	return Z_STREAM_ERROR;
 #else
-	err = do_flush (file, Z_FINISH);
-	if (err != Z_OK) return destroy((gz_stream*)file);
+	if (do_flush (file, Z_FINISH) != Z_OK)
+	    return destroy((gz_stream*)file);
 
 	putLong (s->file, s->crc);
-	putLong (s->file, s->stream.total_in);
+	putLong (s->file, (uLong)(s->in & 0xffffffff));
 #endif
     }
     return destroy((gz_stream*)file);
 }
 
+#ifdef STDC
+#  define zstrerror(errnum) strerror(errnum)
+#else
+#  define zstrerror(errnum) ""
+#endif
+
 /* ===========================================================================
-     Returns the error message for the last error which occured on the
+     Returns the error message for the last error which occurred on the
    given compressed file. errnum is set to zlib error number. If an
-   error occured in the file system and not in the compression library,
+   error occurred in the file system and not in the compression library,
    errnum is set to Z_ERRNO and the application may consult errno
    to get the exact error code.
 */
-const char*  ZEXPORT gzerror (file, errnum)
+const char * ZEXPORT gzerror (file, errnum)
     gzFile file;
     int *errnum;
 {
@@ -868,14 +998,29 @@ const char*  ZEXPORT gzerror (file, errnum)
     *errnum = s->z_err;
     if (*errnum == Z_OK) return (const char*)"";
 
-    m =  (char*)(*errnum == Z_ERRNO ? zstrerror(errno) : s->stream.msg);
+    m = (char*)(*errnum == Z_ERRNO ? zstrerror(errno) : s->stream.msg);
 
     if (m == NULL || *m == '\0') m = (char*)ERR_MSG(s->z_err);
 
     TRYFREE(s->msg);
     s->msg = (char*)ALLOC(strlen(s->path) + strlen(m) + 3);
+    if (s->msg == Z_NULL) return (const char*)ERR_MSG(Z_MEM_ERROR);
     strcpy(s->msg, s->path);
     strcat(s->msg, ": ");
     strcat(s->msg, m);
     return (const char*)s->msg;
 }
+
+/* ===========================================================================
+     Clear the error and end-of-file flags, and do the same for the real file.
+*/
+void ZEXPORT gzclearerr (file)
+    gzFile file;
+{
+    gz_stream *s = (gz_stream*)file;
+
+    if (s == NULL) return;
+    if (s->z_err != Z_STREAM_END) s->z_err = Z_OK;
+    s->z_eof = 0;
+    clearerr(s->file);
+}
